{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Fetching and Cleaning HTML Text"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "### NLP 2016 - HW1"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "November 2015 - [NLP16](http://www.cs.bgu.ac.il/~elhadad/nlp16.html)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "We will compare two different methods to clean raw HTML text into text.\n",
    "HTML pages contain many \"non textual\" elements, in the form of HTML tags, jscript code, lots of advertisement and in general repetitive content which we will refer to as \"boilerplate\" content (menus, navigation etc).\n",
    "\n",
    "We are intersted in extracting from a random HTML page the non-boilerplate textual content.\n",
    "\n",
    "We will compare two libraries that achieve this.\n",
    "\n",
    "First, let us get raw HTML from a URL:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "import requests\n",
    "\n",
    "url = \"http://www.bbc.com/news/technology-26415021\"\n",
    "html = requests.get(url).text"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let us inspect the resulting raw HTML string we obtained:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "<!DOCTYPE html>\n",
      "<html lang=\"en\" id=\"responsive-news\" prefix=\"og: http://ogp.me/ns#\">\n",
      "<head >\n",
      "    <meta charset=\"utf-8\">\n",
      "    <meta http-equiv=\"X-UA-Compatible\" content=\"IE=edge,chrome=1\">\n",
      "    <title>An\n"
     ]
    }
   ],
   "source": [
    "print(html[:200])"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Too many white spaces and empty lines, let us clean it up a bit:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "import re\n",
    "\n",
    "html = re.sub(\"[\\r\\n]+\", \"\\n\", html)\n",
    "html = re.sub(\"[\\n]+\", \"\\n\", html)\n",
    "html = re.sub(\"[\\t, ]+\",\" \", html)\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "'<!DOCTYPE html>\\n<html lang=\"en\" id=\"responsive-news\" prefix=\"og: http://ogp.me/ns#\">\\n<head >\\n <meta charset=\"utf-8\">\\n <meta http-equiv=\"X-UA-Compatible\" content=\"IE=edge chrome=1\">\\n <title>An hour to catch the coding bug - BBC News</title>\\n <meta name=\"description\" content=\"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\">\\n <link rel=\"dns-prefetch\" href=\"https://ssl.bbc.co.uk/\">\\n <link rel=\"dns-prefetch\" href=\"http://sa.bbc.co.uk/\">\\n <link rel=\"dns-prefetch\" href=\"http://ichef-1.bbci.co.uk/\">\\n <link rel=\"dns-prefetch\" href=\"http://ichef.bbci.co.uk/\">\\n <meta name=\"x-country\" content=\"il\">\\n <meta name=\"x-audience\" content=\"International\">\\n <meta name=\"CPS_AUDIENCE\" content=\"International\">\\n <meta name=\"CPS_CHANGEQUEUEID\" content=\"\">\\n <link rel=\"canonical\" href=\"http://www.bbc.com/news/technology-26415021\">\\n <link rel=\"alternate\" hreflang=\"en-gb\" href=\"http://www.bbc.co.uk/news/technology-26415021\">\\n <link rel=\"alternate\" hreflang=\"en\" href=\"http://www.bbc.com/news/technology-26415021\">\\n <meta property=\"og:title\" content=\"An hour to catch the coding bug - BBC News\" />\\n <meta property=\"og:type\" content=\"article\" />\\n <meta property=\"og:description\" content=\"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\" />\\n <meta property=\"og:site_name\" content=\"BBC News\" />\\n <meta property=\"og:locale\" content=\"en_GB\" />\\n <meta property=\"og:article:author\" content=\"BBC News\" />\\n <meta property=\"og:article:section\" content=\"Technology\" />\\n <meta property=\"og:url\" content=\"http://www.bbc.com/news/technology-26415021\" />\\n <meta property=\"og:image\" content=\"http://ichef-1.bbci.co.uk/news/1024/media/images/73325000/jpg/_73325451_hourofcode.jpg\" />\\n <meta name=\"twitter:card\" content=\"summary_large_image\">\\n <meta name=\"twitter:site\" content=\"@BBCWorld\">\\n <meta name=\"twitter:title\" content=\"An hour to catch the coding bug - BBC News\">\\n <meta name=\"twitter:description\" content=\"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\">\\n <meta name=\"twitter:creator\" content=\"@BBCWorld\">\\n <meta name=\"twitter:image:src\" content=\"http://ichef-1.bbci.co.uk/news/560/media/images/73325000/jpg/_73325451_hourofcode.jpg\">\\n <meta name=\"twitter:domain\" content=\"www.bbc.com\">\\n <script type=\"application/ld+json\">\\n {\\n \"@context\": \"http://schema.org\"\\n \"@type\": \"Article\"\\n \\n \"url\": \"http://www.bbc.com/news/technology-26415021\"\\n \"publisher\": {\\n \"@type\": \"Organization\" \\n \"name\": \"BBC News\" \\n \"logo\": \"http://www.bbc.co.uk/news/special/2015/newsspec_10857/bbc_news_logo.png?cb=1\"\\n }\\n \\n \"headline\": \"An hour to catch the coding bug\"\\n \"author\": \"Mark Ward\"\\n \"mainEntityOfPage\": \"http://www.bbc.com/news/technology-26415021\"\\n \"articleBody\": \"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\"\\n \\n \"image\": {\\n \"@list\": [\\n \"http://ichef-1.bbci.co.uk/news/560/media/images/73325000/jpg/_73325163_olly009.jpg\"\\n \"http://ichef.bbci.co.uk/news/560/media/images/73325000/jpg/_73325167_hourofcode.jpg\"\\n \"http://ichef.bbci.co.uk/news/560/media/images/73325000/jpg/_73325169_appinventor.jpg\"\\n ]\\n }\\n \"datePublished\": \"2014-03-03T10:22:55+00:00\"\\n }\\n </script>\\n \\n \\n <meta name=\"apple-mobile-web-app-title\" content=\"BBC News\">\\n <link rel=\"apple-touch-icon-precomposed\" sizes=\"57x57\" href=\"http://static.bbci.co.uk/news/1.99.0479/apple-touch-icon-57x57-precomposed.png\">\\n <link rel=\"apple-touch-icon-precomposed\" sizes=\"72x72\" href=\"http://static.bbci.co.uk/news/1.99.0479/apple-touch-icon-72x72-precomposed.png\">\\n <link rel=\"apple-touch-icon-precomposed\" sizes=\"114x114\" href=\"http://static.bbci.co.uk/news/1.99.0479/apple-touch-icon-114x114-precomposed.png\">\\n <link rel=\"apple-touch-icon-precomposed\" sizes=\"144x144\" href=\"http://static.bbci.co.uk/news/1.99.0479/apple-touch-icon.png\">\\n <link rel=\"apple-touch-icon\" href=\"http://static.bbci.co.uk/news/1.99.0479/apple-touch-icon.png\">\\n <meta name=\"application-name\" content=\"BBC News\">\\n <meta name=\"msapplication-TileImage\" content=\"http://static.bbci.co.uk/news/1.99.0479/windows-eight-icon-144x144.png\">\\n <meta name=\"msapplication-TileColor\" content=\"#bb1919\">\\n <meta http-equiv=\"cleartype\" content=\"on\">\\n <meta name=\"mobile-web-app-capable\" content=\"yes\">\\n <meta name=\"robots\" content=\"NOODP NOYDIR\" />\\n <meta name=\"theme-color\" content=\"#bb1919\">\\n <script type=\"text/javascript\">var _sf_startpt=(new Date()).getTime()</script>\\n <script>\\n (function() {\\n if (navigator.userAgent.match(/IEMobile\\\\/10\\\\.0/)) {\\n var msViewportStyle = document.createElement(\"style\");\\n msViewportStyle.appendChild(\\n document.createTextNode(\"@-ms-viewport{width:auto!important}\")\\n );\\n document.getElementsByTagName(\"head\")[0].appendChild(msViewportStyle);\\n }\\n })();\\n </script>\\n \\n <script>window.fig = window.fig || {}; window.fig.async = true;</script>\\n <meta name=\"viewport\" content=\"width=device-width initial-scale=1.0\" /> <meta property=\"fb:admins\" content=\"100004154058350\" /> <script type=\"text/javascript\">window.bbcredirection={geo:true}</script> <!--orb.ws.require.lib--> <script type=\"text/javascript\">/*<![CDATA[*/ if (typeof window.define !== \\'function\\' || typeof window.require !== \\'function\\') { document.write(\\'<script class=\"js-require-lib\" src=\"http://static.bbci.co.uk/frameworks/requirejs/lib.js\"><\\'+\\'/script>\\'); } /*]]>*/</script> <script type=\"text/javascript\"> bbcRequireMap = {\"jquery-1\":\"http://static.bbci.co.uk/frameworks/jquery/0.3.0/sharedmodules/jquery-1.7.2\" \"jquery-1.4\":\"http://static.bbci.co.uk/frameworks/jquery/0.3.0/sharedmodules/jquery-1.4\" \"jquery-1.9\":\"http://static.bbci.co.uk/frameworks/jquery/0.3.0/sharedmodules/jquery-1.9.1\" \"swfobject-2\":\"http://static.bbci.co.uk/frameworks/swfobject/0.1.10/sharedmodules/swfobject-2\" \"demi-1\":\"http://static.bbci.co.uk/frameworks/demi/0.10.0/sharedmodules/demi-1\" \"gelui-1\":\"http://static.bbci.co.uk/frameworks/gelui/0.9.13/sharedmodules/gelui-1\" \"cssp!gelui-1/overlay\":\"http://static.bbci.co.uk/frameworks/gelui/0.9.13/sharedmodules/gelui-1/overlay.css\" \"istats-1\":\"http://static.bbci.co.uk/frameworks/istats/0.28.4/modules/istats-1\" \"relay-1\":\"http://static.bbci.co.uk/frameworks/relay/0.2.6/sharedmodules/relay-1\" \"clock-1\":\"http://static.bbci.co.uk/frameworks/clock/0.1.9/sharedmodules/clock-1\" \"canvas-clock-1\":\"http://static.bbci.co.uk/frameworks/clock/0.1.9/sharedmodules/canvas-clock-1\" \"cssp!clock-1\":\"http://static.bbci.co.uk/frameworks/clock/0.1.9/sharedmodules/clock-1.css\" \"jssignals-1\":\"http://static.bbci.co.uk/frameworks/jssignals/0.3.6/modules/jssignals-1\" \"jcarousel-1\":\"http://static.bbci.co.uk/frameworks/jcarousel/0.1.10/modules/jcarousel-1\" \"bump-3\":\"//emp.bbci.co.uk/emp/bump-3/bump-3\"}; require({ baseUrl: \\'http://static.bbci.co.uk/\\' paths: bbcRequireMap waitSeconds: 30 }); </script> <script type=\"text/javascript\">/*<![CDATA[*/ if (typeof bbccookies_flag === \\'undefined\\') { bbccookies_flag = \\'ON\\'; } showCTA_flag = true; cta_enabled = (showCTA_flag && (bbccookies_flag === \\'ON\\')); (function(){var e=\"ckns_policy\" m=\"Thu 01 Jan 1970 00:00:00 GMT\" k={ads:true personalisation:true performance:true necessary:true};function f(p){if(f.cache[p]){return f.cache[p]}var o=p.split(\"/\") q=[\"\"];do{q.unshift((o.join(\"/\")||\"/\"));o.pop()}while(q[0]!==\"/\");f.cache[p]=q;return q}f.cache={};function a(p){if(a.cache[p]){return a.cache[p]}var q=p.split(\".\") o=[];while(q.length&&\"|co.uk|com|\".indexOf(\"|\"+q.join(\".\")+\"|\")===-1){if(q.length){o.push(q.join(\".\"))}q.shift()}f.cache[p]=o;return o}a.cache={};function i(o t p){var z=[\"\"].concat(a(window.location.hostname)) w=f(window.location.pathname) y=\"\" r x;for(var s=0 v=z.length;s<v;s++){r=z[s];for(var q=0 u=w.length;q<u;q++){x=w[q];y=o+\"=\"+t+\";\"+(r?\"domain=\"+r+\";\":\"\")+(x?\"path=\"+x+\";\":\"\")+(p?\"expires=\"+p+\";\":\"\");bbccookies.set(y true)}}}window.bbccookies={POLICY_REFRESH_DATE_MILLIS:new Date(2015 4 21 0 0 0 0).getTime() POLICY_EXPIRY_COOKIENAME:\"ckns_policy_exp\" _setEverywhere:i cookiesEnabled:function(){var o=\"ckns_testcookie\"+Math.floor(Math.random()*100000);this.set(o+\"=1\");if(this.get().indexOf(o)>-1){g(o);return true}return false} set:function(o){return document.cookie=o} get:function(){return document.cookie} getCrumb:function(o){if(!o){return null}return decodeURIComponent(document.cookie.replace(new RegExp(\"(?:(?:^|.*;)\\\\\\\\s*\"+encodeURIComponent(o).replace(/[\\\\-\\\\.\\\\+\\\\*]/g \"\\\\\\\\$&\")+\"\\\\\\\\s*\\\\\\\\=\\\\\\\\s*([^;]*).*$)|^.*$\") \"$1\"))||null} policyRequiresRefresh:function(){var p=new Date();p.setHours(0);p.setMinutes(0);p.setSeconds(0);p.setMilliseconds(0);if(bbccookies.POLICY_REFRESH_DATE_MILLIS<=p.getTime()){var o=bbccookies.getCrumb(bbccookies.POLICY_EXPIRY_COOKIENAME);if(o){o=new Date(parseInt(o));o.setYear(o.getFullYear()-1);return bbccookies.POLICY_REFRESH_DATE_MILLIS>=o.getTime()}else{return true}}else{return false}} _setPolicy:function(o){return h.apply(this arguments)} readPolicy:function(){return b.apply(this arguments)} _deletePolicy:function(){i(e \"\" m)} isAllowed:function(){return true} _isConfirmed:function(){return c()!==null} _acceptsAll:function(){var o=b();return o&&!(j(o).indexOf(\"0\")>-1)} _getCookieName:function(){return d.apply(this arguments)} _showPrompt:function(){var o=((!this._isConfirmed()||this.policyRequiresRefresh())&&window.cta_enabled&&this.cookiesEnabled()&&!window.bbccookies_disable);return(window.orb&&window.orb.fig)?o&&(window.orb.fig(\"no\")||window.orb.fig(\"ck\")):o}};bbccookies._getPolicy=bbccookies.readPolicy;function d(p){var o=(\"\"+p).match(/^([^=]+)(?==)/);return(o&&o.length?o[0]:\"\")}function j(o){return\"\"+(o.ads?1:0)+(o.personalisation?1:0)+(o.performance?1:0)}function h(s){if(typeof s===\"undefined\"){s=k}if(typeof arguments[0]===\"string\"){var p=arguments[0] r=arguments[1];if(p===\"necessary\"){r=true}s=b();s[p]=r}else{if(typeof arguments[0]===\"object\"){s.necessary=true}}var q=new Date();q.setYear(q.getFullYear()+1);bbccookies.set(e+\"=\"+j(s)+\";domain=bbc.co.uk;path=/;expires=\"+q.toUTCString()+\";\");bbccookies.set(e+\"=\"+j(s)+\";domain=bbc.com;path=/;expires=\"+q.toUTCString()+\";\");var o=new Date(q.getTime());o.setMonth(o.getMonth()+1);bbccookies.set(bbccookies.POLICY_EXPIRY_COOKIENAME+\"=\"+q.getTime()+\";domain=bbc.co.uk;path=/;expires=\"+o.toUTCString()+\";\");bbccookies.set(bbccookies.POLICY_EXPIRY_COOKIENAME+\"=\"+q.getTime()+\";domain=bbc.com;path=/;expires=\"+o.toUTCString()+\";\");return s}function l(o){if(o===null){return null}var p=o.split(\"\");return{ads:!!+p[0] personalisation:!!+p[1] performance:!!+p[2] necessary:true}}function c(){var o=new RegExp(\"(?:^|; ?)\"+e+\"=(\\\\\\\\d\\\\\\\\d\\\\\\\\d)($|;)\") p=document.cookie.match(o);if(!p){return null}return p[1]}function b(o){var p=l(c());if(!p){p=k}if(o){return p[o]}else{return p}}function g(o){return document.cookie=o+\"=;expires=\"+m+\";\"}function n(){var o=\\'<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/frameworks/bbccookies/0.6.15/script/bbccookies.js\"><\\\\/script>\\';if(window.bbccookies_flag===\"ON\"&&!bbccookies._acceptsAll()&&!window.bbccookies_disable){document.write(o)}}n()})(); /*]]>*/</script> <script type=\"text/javascript\">/*<![CDATA[*/\\n(function(){window.fig=window.fig||{};window.fig.manager={include:function(a){a=a||window;var e=a.document g=e.cookie b=g.match(/(?:^|; ?)ckns_orb_fig=([^;]+)/);if(!b&&g.indexOf(\"ckns_orb_nofig=1\")>-1){this.setFig(a {no:1})}else{if(b){b=this.deserialise(decodeURIComponent(RegExp.$1));this.setFig(a b)}e.write(\\'<script src=\"https://fig.bbc.co.uk/frameworks/fig/1/fig.js\"><\\'+\"/script>\")}} confirm:function(a){a=a||window;if(a.orb&&a.orb.fig&&a.orb.fig(\"no\")){this.setNoFigCookie(a)}if(a.orb===undefined||a.orb.fig===undefined){this.setFig(a {no:1});this.setNoFigCookie(a)}} setNoFigCookie:function(a){a.document.cookie=\"ckns_orb_nofig=1; expires=\"+new Date(new Date().getTime()+1000*60*10).toGMTString()+\";\"} setFig:function(a b){(function(){var c=b;a.orb=a.orb||{};a.orb.fig=function(d){return(arguments.length)?c[d]:c}})()} deserialise:function(b){var a={};b.replace(/([a-z]{2}):([0-9]+)/g function(){a[RegExp.$1]=+RegExp.$2});return a}}})();fig.manager.include();/*]]>*/</script>\\n \\n<!--[if (gt IE 8) | (IEMobile)]><!-->\\n<link rel=\"stylesheet\" href=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/style/orb.min.css\">\\n<!--<![endif]-->\\n<!--[if (lt IE 9) & (!IEMobile)]>\\n<link rel=\"stylesheet\" href=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/style/orb-ie.min.css\">\\n<![endif]-->\\n <script type=\"text/javascript\">/*<![CDATA[*/ (function(undefined){if(!window.bbc){window.bbc={}}var ROLLING_PERIOD_DAYS=30;window.bbc.Mandolin=function(id segments opts){var now=new Date().getTime() storedItem DEFAULT_START=now DEFAULT_RATE=1 COOKIE_NAME=\"ckpf_mandolin\";opts=opts||{};this._id=id;this._segmentSet=segments;this._store=new window.window.bbc.Mandolin.Storage(COOKIE_NAME);this._opts=opts;this._rate=(opts.rate!==undefined)?+opts.rate:DEFAULT_RATE;this._startTs=(opts.start!==undefined)?new Date(opts.start).getTime():new Date(DEFAULT_START).getTime();this._endTs=(opts.end!==undefined)?new Date(opts.end).getTime():daysFromNow(ROLLING_PERIOD_DAYS);this._signupEndTs=(opts.signupEnd!==undefined)?new Date(opts.signupEnd).getTime():this._endTs;this._segment=null;if(typeof id!==\"string\"){throw new Error(\"Invalid Argument: id must be defined and be a string\")}if(Object.prototype.toString.call(segments)!==\"[object Array]\"){throw new Error(\"Invalid Argument: Segments are required.\")}if(opts.rate!==undefined&&(opts.rate<0||opts.rate>1)){throw new Error(\"Invalid Argument: Rate must be between 0 and 1.\")}if(this._startTs>this._endTs){throw new Error(\"Invalid Argument: end date must occur after start date.\")}if(!(this._startTs<this._signupEndTs&&this._signupEndTs<=this._endTs)){throw new Error(\"Invalid Argument: SignupEnd must be between start and end date\")}removeExpired.call(this now);var overrides=window.bbccookies.get().match(/ckns_mandolin_setSegments=([^;]+)/);if(overrides!==null){eval(\"overrides = \"+decodeURIComponent(RegExp.$1)+\";\");if(overrides[this._id]&&this._segmentSet.indexOf(overrides[this._id])==-1){throw new Error(\"Invalid Override: overridden segment should exist in segments array\")}}if(overrides!==null&&overrides[this._id]){this._segment=overrides[this._id]}else{if((storedItem=this._store.getItem(this._id))){this._segment=storedItem.segment}else{if(this._startTs<=now&&now<this._signupEndTs&&now<=this._endTs&&this._store.isEnabled()===true){this._segment=pick(segments this._rate);if(opts.end===undefined){this._store.setItem(this._id {segment:this._segment})}else{this._store.setItem(this._id {segment:this._segment end:this._endTs})}log.call(this \"mandolin_segment\")}}}log.call(this \"mandolin_view\")};window.bbc.Mandolin.prototype.getSegment=function(){return this._segment};function log(actionType params){var that=this;require([\"istats-1\"] function(istats){istats.log(actionType that._id+\":\"+that._segment params?params:{})})}function removeExpired(expires){var items=this._store.getItems() expiresInt=+expires;for(var key in items){if(items[key].end!==undefined&&+items[key].end<expiresInt){this._store.removeItem(key)}}}function getLastExpirationDate(data){var winner=0 rollingExpire=daysFromNow(ROLLING_PERIOD_DAYS);for(var key in data){if(data[key].end===undefined&&rollingExpire>winner){winner=rollingExpire}else{if(+data[key].end>winner){winner=+data[key].end}}}return(winner)?new Date(winner):new Date(rollingExpire)}window.bbc.Mandolin.prototype.log=function(params){log.call(this \"mandolin_log\" params)};window.bbc.Mandolin.prototype.convert=function(params){log.call(this \"mandolin_convert\" params);this.convert=function(){}};function daysFromNow(n){var endDate;endDate=new Date().getTime()+(n*60*60*24)*1000;return endDate}function pick(segments rate){var picked min=0 max=segments.length-1;if(typeof rate===\"number\"&&Math.random()>rate){return null}do{picked=Math.floor(Math.random()*(max-min+1))+min}while(picked>max);return segments[picked]}window.bbc.Mandolin.Storage=function(name){validateCookieName(name);this._cookieName=name;this._isEnabled=(bbccookies.isAllowed(this._cookieName)===true&&bbccookies.cookiesEnabled()===true)};window.bbc.Mandolin.Storage.prototype.setItem=function(key value){var storeData=this.getItems();storeData[key]=value;this.save(storeData);return value};window.bbc.Mandolin.Storage.prototype.isEnabled=function(){return this._isEnabled};window.bbc.Mandolin.Storage.prototype.getItem=function(key){var storeData=this.getItems();return storeData[key]};window.bbc.Mandolin.Storage.prototype.removeItem=function(key){var storeData=this.getItems();delete storeData[key];this.save(storeData)};window.bbc.Mandolin.Storage.prototype.getItems=function(){return deserialise(this.readCookie(this._cookieName)||\"\")};window.bbc.Mandolin.Storage.prototype.save=function(data){window.bbccookies.set(this._cookieName+\"=\"+encodeURIComponent(serialise(data))+\"; expires=\"+getLastExpirationDate(data).toUTCString()+\";\")};window.bbc.Mandolin.Storage.prototype.readCookie=function(name){var nameEq=name+\"=\" ca=window.bbccookies.get().split(\"; \") i c;validateCookieName(name);for(i=0;i<ca.length;i++){c=ca[i];if(c.indexOf(nameEq)===0){return decodeURIComponent(c.substring(nameEq.length c.length))}}return null};function serialise(o){var str=\"\";for(var p in o){if(o.hasOwnProperty(p)){str+=\\'\"\\'+p+\\'\"\\'+\":\"+(typeof o[p]===\"object\"?(o[p]===null?\"null\":\"{\"+serialise(o[p])+\"}\"):\\'\"\\'+o[p].toString()+\\'\"\\')+\" \"}}return str.replace(/ \\\\}/g \"}\").replace(/ $/g \"\")}function deserialise(str){var o;str=\"{\"+str+\"}\";if(!validateSerialisation(str)){throw\"Invalid input provided for deserialisation.\"}eval(\"o = \"+str);return o}var validateSerialisation=(function(){var OBJECT_TOKEN=\"<Object>\" ESCAPED_CHAR=\\'\"\\\\\\\\n\\\\\\\\r\\\\\\\\u2028\\\\\\\\u2029\\\\\\\\u000A\\\\\\\\u000D\\\\\\\\u005C\\' ALLOWED_CHAR=\"([^\"+ESCAPED_CHAR+\"]|\\\\\\\\\\\\\\\\[\"+ESCAPED_CHAR+\"])\" KEY=\\'\"\\'+ALLOWED_CHAR+\\'+\"\\' VALUE=\\'(null|\"\\'+ALLOWED_CHAR+\\'*\"|\\'+OBJECT_TOKEN+\")\" KEY_VALUE=KEY+\":\"+VALUE KEY_VALUE_SEQUENCE=\"(\"+KEY_VALUE+\" )*\"+KEY_VALUE OBJECT_LITERAL=\"({}|{\"+KEY_VALUE_SEQUENCE+\"})\" objectPattern=new RegExp(OBJECT_LITERAL \"g\");return function(str){if(str.indexOf(OBJECT_TOKEN)!==-1){return false}while(str.match(objectPattern)){str=str.replace(objectPattern OBJECT_TOKEN)}return str===OBJECT_TOKEN}})();function validateCookieName(name){if(name.match(/ ;/)){throw\"Illegal name provided must be valid in browser cookie.\"}}})(); /*]]>*/</script> <script type=\"text/javascript\"> document.documentElement.className += (document.documentElement.className? \\' \\' : \\'\\') + \\'orb-js\\'; fig.manager.confirm(); </script> <script src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/script/orb/api.min.js\"></script> <script type=\"text/javascript\"> var blq = { environment: function() { return \\'live\\'; } } </script> <script type=\"text/javascript\"> /*<![CDATA[*/ function oqsSurveyManager(w flag) { if (flag !== \\'OFF\\') { w.document.write(\\'<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/script/vendor/edr.js\"><\\'+\\'/script>\\'); } } oqsSurveyManager(window \\'ON\\'); /*]]>*/ </script> <!-- BBCDOTCOM template: responsive webservice -->\\n <!-- BBCDOTCOM head --><script type=\"text/javascript\"> /*<![CDATA[*/ var _sf_startpt = (new Date()).getTime(); /*]]>*/ </script><style type=\"text/css\">.bbccom_display_none{display:none;}</style><script type=\"text/javascript\"> /*<![CDATA[*/ var bbcdotcomConfig googletag = googletag || {}; googletag.cmd = googletag.cmd || []; var bbcdotcom = false; (function(){ if(typeof require !== \\'undefined\\') { require({ paths:{ \"bbcdotcom\":\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script\" } }); } })(); /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ var bbcdotcom = { adverts: { keyValues: { set: function() {} } } advert: { write: function () {} show: function () {} isActive: function () { return false; } layout: function() { return { reset: function() {} } } } config: { init: function() {} isActive: function() {} setSections: function() {} isAdsEnabled: function() {} setAdsEnabled: function() {} isAnalyticsEnabled: function() {} setAnalyticsEnabled: function() {} setAssetPrefix: function() {} setVersion: function () {} setJsPrefix: function() {} setSwfPrefix: function() {} setCssPrefix: function() {} setConfig: function() {} getAssetPrefix: function() {} getJsPrefix: function () {} getSwfPrefix: function () {} getCssPrefix: function () {} } survey: { init: function(){ return false; } } data: {} init: function() {} objects: function(str) { return false; } locale: { set: function() {} get: function() {} } setAdKeyValue: function() {} utils: { addEvent: function() {} addHtmlTagClass: function() {} log: function () {} } addLoadEvent: function() {} }; /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ (function(){ if (typeof orb !== \\'undefined\\' && typeof orb.fig === \\'function\\') { if (orb.fig(\\'ad\\') && orb.fig(\\'uk\\') == 0) { bbcdotcom.data = { ads: (orb.fig(\\'ad\\') ? 1 : 0) stats: (orb.fig(\\'uk\\') == 0 ? 1 : 0) statsProvider: orb.fig(\\'ap\\') }; } } else { document.write(\\'<script type=\"text/javascript\" src=\"\\'+(\\'https:\\' == document.location.protocol ? \\'https://ssl.bbc.com\\' : \\'http://tps.bbc.com\\')+\\'/wwscripts/data\">\\\\x3C/script>\\'); } })(); /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ (function(){ if (typeof orb === \\'undefined\\' || typeof orb.fig !== \\'function\\') { bbcdotcom.data = { ads: bbcdotcom.data.a stats: bbcdotcom.data.b statsProvider: bbcdotcom.data.c }; } if (bbcdotcom.data.ads == 1) { document.write(\\'<script type=\"text/javascript\" src=\"\\'+(\\'https:\\' == document.location.protocol ? \\'https://ssl.bbc.co.uk\\' : \\'http://www.bbc.co.uk\\')+\\'/wwscripts/flag\">\\\\x3C/script>\\'); } })(); /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ (function(){ if (window.bbcdotcom && (typeof bbcdotcom.flag == \\'undefined\\' || (typeof bbcdotcom.data.ads !== \\'undefined\\' && bbcdotcom.flag.a != 1))) { bbcdotcom.data.ads = 0; } if (/[?|&]ads/.test(window.location.href) || /(^|; )ads=on; /.test(document.cookie) || /; ads=on(; |$)/.test(document.cookie)) { bbcdotcom.data.ads = 1; bbcdotcom.data.stats = 1; } if (window.bbcdotcom && (bbcdotcom.data.ads == 1 || bbcdotcom.data.stats == 1)) { bbcdotcom.assetPrefix = \"http://static.bbci.co.uk/bbcdotcom/0.3.344/\"; if (/(sandbox|int)(.dev)*.bbc.co*/.test(window.location.href) || /[?|&]ads-debug/.test(window.location.href) || document.cookie.indexOf(\\'ads-debug=\\') !== -1) { document.write(\\'<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script/orb/individual.js\">\\\\x3C/script>\\'); } else { document.write(\\'<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script/orb/bbcdotcom.js\">\\\\x3C/script>\\'); } if(/[\\\\\\\\?&]ads=([^&#]*)/.test(window.location.href)) { document.write(\\'<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script/orb/adverts/adSuites.js\">\\\\x3C/script>\\'); } } })(); /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ (function(){ if (window.bbcdotcom && (bbcdotcom.data.ads == 1 || bbcdotcom.data.stats == 1)) { bbcdotcomConfig = {\"adFormat\":\"standard\" \"adKeyword\":\"\" \"adMode\":\"smart\" \"adsEnabled\":true \"appAnalyticsSections\":\"news>technology\" \"asyncEnabled\":true \"disableInitialLoad\":false \"advertInfoPageUrl\":\"http:\\\\/\\\\/www.bbc.co.uk\\\\/faqs\\\\/online\\\\/adverts_general\" \"advertisementText\":\"Advertisement\" \"analyticsEnabled\":true \"appName\":\"tabloid\" \"assetPrefix\":\"http:\\\\/\\\\/static.bbci.co.uk\\\\/bbcdotcom\\\\/0.3.344\\\\/\" \"continuousPlayEnabled\":false \"customAdParams\":[] \"customStatsParams\":[] \"headline\":\"An hour to catch the coding bug\" \"id\":\"26415021\" \"inAssociationWithText\":\"in association with\" \"keywords\":\"\" \"language\":\"\" \"orbTransitional\":false \"outbrainEnabled\":true \"palEnv\":\"live\" \"productName\":\"\" \"sections\":[] \"siteCatalystEnabled\":true \"comScoreEnabled\":true \"slots\":\"\" \"sponsoredByText\":\"is sponsored by\" \"adsByGoogleText\":\"Ads by Google\" \"summary\":\"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\" \"type\":\"STORY\" \"staticBase\":\"\\\\/bbcdotcom\" \"staticHost\":\"http:\\\\/\\\\/static.bbci.co.uk\" \"staticVersion\":\"0.3.344\" \"staticPrefix\":\"http:\\\\/\\\\/static.bbci.co.uk\\\\/bbcdotcom\\\\/0.3.344\" \"dataHttp\":\"tps.bbc.com\" \"dataHttps\":\"ssl.bbc.com\" \"flagHttp\":\"www.bbc.co.uk\" \"flagHttps\":\"ssl.bbc.co.uk\" \"analyticsHttp\":\"sa.bbc.com\" \"analyticsHttps\":\"ssa.bbc.com\"}; bbcdotcom.config.init(bbcdotcomConfig bbcdotcom.data window.location window.document); bbcdotcom.config.setAssetPrefix(\"http://static.bbci.co.uk/bbcdotcom/0.3.344/\"); bbcdotcom.config.setVersion(\"0.3.344\"); document.write(\\'<!--[if IE 7]><script type=\"text/javascript\">bbcdotcom.config.setIE7(true);\\\\x3C/script><![endif]-->\\'); document.write(\\'<!--[if IE 8]><script type=\"text/javascript\">bbcdotcom.config.setIE8(true);\\\\x3C/script><![endif]-->\\'); document.write(\\'<!--[if IE 9]><script type=\"text/javascript\">bbcdotcom.config.setIE9(true);\\\\x3C/script><![endif]-->\\'); if (/[?|&]ex-dp/.test(window.location.href) || document.cookie.indexOf(\\'ex-dp=\\') !== -1) { bbcdotcom.utils.addHtmlTagClass(\\'bbcdotcom-ex-dp\\'); } } })(); /*]]>*/ </script> <script type=\"text/javascript\">/*<![CDATA[*/\\n window.bbcFlagpoles_istats = \\'ON\\';\\n window.orb = window.orb || {};\\n if (bbccookies.isAllowed(\\'s1\\')) {\\n var istatsTrackingUrl = \\'//sa.bbc.co.uk/bbc/bbc/s?name=news.technology.story.26415021.page&cps_asset_id=26415021&page_type=Story&section=%2Fnews%2Ftechnology&first_pub=2014-03-03T07%3A36%3A59%2B00%3A00&last_editorial_update=2014-03-03T10%3A22%3A55%2B00%3A00&title=An+hour+to+catch+the+coding+bug&for_nation=il&app_version=1.99.0&bbc_site=news&pal_route=asset&ml_name=barlesque&app_type=responsive&language=en-GB&ml_version=0.28.4&pal_webapp=tabloid&prod_name=news&app_name=news\\';\\n require([\\'istats-1\\'] function (istats) {\\n istats.addCollector({\\'name\\': \\'default\\' \\'url\\': \\'//sa.bbc.co.uk/bbc/bbc/s\\' \\'separator\\': \\'&\\' });\\n var counterName = (window.istats_countername) ? window.istats_countername : istatsTrackingUrl.match(/[\\\\?&]name=([^&]*)/i)[1];\\n istats.setCountername(counterName);\\n if (/\\\\bIDENTITY=/.test(document.cookie)) {\\n istats.addLabels({\\'bbc_identity\\': \\'1\\'});\\n }\\n if (/\\\\bckns_policy=\\\\d\\\\d0/.test(document.cookie)) {\\n istats.addLabels({\\'ns_nc\\': \\'1\\'});\\n }\\n var c = (document.cookie.match(/\\\\bckns_policy=(\\\\d\\\\d\\\\d)/) || []).pop() || \\'\\';\\n var screenWidthAndHeight = \\'unavailable\\';\\n if (window.screen && screen.width && screen.height) {\\n screenWidthAndHeight = screen.width + \\'x\\' + screen.height;\\n }\\n istats.addLabels(\\'cps_asset_id=26415021&page_type=Story&section=%2Fnews%2Ftechnology&first_pub=2014-03-03T07%3A36%3A59%2B00%3A00&last_editorial_update=2014-03-03T10%3A22%3A55%2B00%3A00&title=An+hour+to+catch+the+coding+bug&for_nation=il&app_version=1.99.0&bbc_site=news&pal_route=asset&ml_name=barlesque&app_type=responsive&language=en-GB&ml_version=0.28.4&pal_webapp=tabloid&prod_name=news&app_name=news\\');\\n istats.addLabels({\\n \\'blq_s\\': \\'4d\\' \\n \\'blq_r\\': \\'2.7\\' \\n \\'blq_v\\': \\'default\\' \\n \\'blq_e\\': \\'pal\\' \\n \\'bbc_mc\\': (c ? \\'ad\\' + c.charAt(0) + \\'ps\\' + c.charAt(1) + \\'pf\\' + c.charAt(2) : \\'not_set\\') \\n \\'screen_resolution\\': screenWidthAndHeight \\n \\'ns_referrer\\': encodeURI(((window.orb.referrer) ? window.orb.referrer : document.referrer))\\n }\\n );\\n });\\n }\\n /*]]>*/</script>\\n <script type=\"text/javascript\"> /* <![CDATA[ */ define(\\'id-statusbar-config\\' { \\'translation_signedout\\': \"Sign in\" \\'translation_signedin\\': \"Your account\" \\'use_overlay\\' : false \\'signin_url\\' : \"https://ssl.bbc.com/id/signin?ptrt=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021\" \\'locale\\' : \"en-GB\" \\'policyname\\' : \"\" \\'ptrt\\' : \"http://www.bbc.com/news/technology-26415021\" }); var map = {}; map[\\'idcta/statusbar\\'] = \\'http://static.bbci.co.uk/id/0.32.25/modules/idcta/statusbar\\'; require({paths: map}); /* ]]> */ </script> <script type=\"text/javascript\"> require([\\'istats-1\\'] function(istats){ if (typeof(document) != \\'undefined\\' && typeof(document.cookie) != \\'undefined\\') { var cookieAphidMatch = document.cookie.match(/ckpf_APHID=([^;]*)/); if (cookieAphidMatch && typeof(cookieAphidMatch[1]) == \\'string\\') { istats.addLabels({\\'bbc_hid\\': cookieAphidMatch[1]}); } } })(); </script> <script type=\"text/javascript\"> (function () { if (! window.require) { throw new Error(\\'idcta: could not find require module\\'); } var map = {}; map[\\'idapp-1\\'] = \\'http://static.bbci.co.uk/idapp/0.71.76/modules/idapp/idapp-1\\'; map[\\'idcta/idcta-1\\'] = \\'http://static.bbci.co.uk/id/0.32.25/modules/idcta/idcta-1\\'; map[\\'idcta/idCookie\\'] = \\'http://static.bbci.co.uk/id/0.32.25/modules/idcta/idCookie\\'; map[\\'idcta/overlayManager\\'] = \\'http://static.bbci.co.uk/id/0.32.25/modules/idcta/overlayManager\\'; require({paths: map}); define(\\'id-config\\' {\"idapp\":{\"version\":\"0.71.76\" \"hostname\":\"ssl.bbc.com\" \"insecurehostname\":\"www.bbc.com\" \"tld\":\"bbc.com\"} \"idtranslations\":{\"version\":\"0.33.27\"} \"identity\":{\"baseUrl\":\"https:\\\\/\\\\/talkback.live.bbc.co.uk\\\\/identity\" \"cookieAgeDays\":730 \"accessTokenCookieName\":\"ckns_IDA-ATKN\"} \"pathway\":{\"name\":null \"staticAssetUrl\":\"http:\\\\/\\\\/static.bbci.co.uk\\\\/idapp\\\\/0.71.76\\\\/modules\\\\/idapp\\\\/idapp-1\\\\/View.css\"} \"idpurl\":\"https:\\\\/\\\\/idp.api.bbc.co.uk\\\\/idp\\\\/oauth2\\\\/authorize?client_id=bbc-co-uk&response_type=code&scope=openid+play.bbcstore.r+plays.any.w+plays.any.r+follows.any.w+follows.any.r+favourites.any.w+favourites.any.r+idm.basic.r&module=bbc-co-uk&state=ptrt%3Dhttp%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021%26locale%3Den-GB&redirect_uri=https%3A%2F%2Fssl.bbc.com%2Fid%2Foauth2%2Fconsume%2Fidp.bbc.co.uk\"}); })(); </script> <script type=\"text/javascript\"> require([\\'idcta/idCookie\\'] function(idCookie){ if (typeof(document) != \\'undefined\\' && typeof(document.cookie) != \\'undefined\\') { var idCookieInstance = idCookie.getInstance(); /* Timestamp in milliseconds for the 6am on 27th of October 2015 */ var timestamp27thOct = 1445925600000; /* Only select users who signed in before the dooms day and were not downgraded yet */ if (idCookieInstance.hasCookie() && idCookieInstance.timestamp != \\'\\' && parseInt(idCookieInstance.timestamp) > 0 && parseInt(idCookieInstance.timestamp) < timestamp27thOct && !idCookieInstance.isDowngraded()) { /* iPlayer uplift is session cookie so downgrade based on this cookie missed 20% users. To cover all the users with our fix ut is nor uncoditional: all users that have not been downgraded before will now be downgraded */ idCookieInstance.downgrade(); } } }); </script> \\n <link type=\"text/css\" rel=\"stylesheet\" href=\"http://static.bbci.co.uk/news/1.99.0479/stylesheets/services/news/core.css\">\\n <!--[if lt IE 9]>\\n <link type=\"text/css\" rel=\"stylesheet\" href=\"http://static.bbci.co.uk/news/1.99.0479/stylesheets/services/news/old-ie.css\">\\n <script src=\"http://static.bbci.co.uk/news/1.99.0479/js/vendor/html5shiv/html5shiv.js\"></script>\\n <![endif]-->\\n <script id=\"news-loader\"> if (document.getElementById(\"responsive-news\")) { window.bbcNewsResponsive = true; } var isIE = (function() { var undef v = 3 div = document.createElement(\\'div\\') all = div.getElementsByTagName(\\'i\\'); while ( div.innerHTML = \\'<!--[if gt IE \\' + (++v) + \\']><i></i><![endif]-->\\' all[0] ); return v > 4 ? v : undef; }()); var modernDevice = \\'querySelector\\' in document && \\'localStorage\\' in window && \\'addEventListener\\' in window forceCore = document.cookie.indexOf(\\'ckps_force_core\\') !== -1; window.cutsTheMustard = modernDevice && !forceCore; if (window.cutsTheMustard) { document.documentElement.className += \\' ctm\\'; var insertPoint = document.getElementById(\\'news-loader\\') config = {\"asset\":{\"asset_id\":\"26415021\" \"asset_uri\":\"\\\\/news\\\\/technology-26415021\" \"first_created\":{\"date\":\"2014-03-03 07:36:59\" \"timezone_type\":3 \"timezone\":\"Europe\\\\/London\"} \"last_updated\":{\"date\":\"2014-03-03 10:22:55\" \"timezone_type\":3 \"timezone\":\"Europe\\\\/London\"} \"options\":{\"allowHeadline\":true \"allowDateStamp\":true \"allowRelatedStoriesBox\":true \"allowRightHandSide\":true \"includeComments\":false \"isIgorSeoTagsEnabled\":false \"allowPrintingSharingLinks\":true \"allowAdvertising\":true} \"section\":{\"name\":\"Technology\" \"id\":\"99113\" \"uri\":\"\\\\/news\\\\/technology\" \"urlIdentifier\":\"\\\\/news\\\\/technology\"} \"edition\":\"International\" \"audience\":null \"iStats_counter_name\":\"news.technology.story.26415021.page\" \"type\":\"STY\" \"length\":5362 \"byline\":{\"name\":\"By Mark Ward\" \"persons\":{\"0\":{\"name\":\"Mark Ward\" \"function\":\"Technology correspondent BBC News\"}} \"title\":\"Technology correspondent BBC News\"} \"headline\":\"An hour to catch the coding bug\" \"mediaType\":null} \"smpBrand\":null \"staticHost\":\"http:\\\\/\\\\/static.bbci.co.uk\" \"environment\":\"live\" \"locatorVersion\":\"0.46.3\" \"pathPrefix\":\"\\\\/news\" \"staticPrefix\":\"http:\\\\/\\\\/static.bbci.co.uk\\\\/news\\\\/1.99.0479\" \"jsPath\":\"http:\\\\/\\\\/static.bbci.co.uk\\\\/news\\\\/1.99.0479\\\\/js\" \"cssPath\":\"http:\\\\/\\\\/static.bbci.co.uk\\\\/news\\\\/1.99.0479\\\\/stylesheets\\\\/services\\\\/news\" \"cssPostfix\":\"\" \"dynamic\":null \"features\":{\"localnews\":true \"video\":true \"liveeventcomponent\":true \"mediaassetpage\":true \"travel\":true \"gallery\":true \"rollingnews\":true \"rumanalytics\":true \"sportstories\":true \"radiopromo\":true \"fromothernewssites\":true \"locallive\":true \"weather\":true} \"features2\":{\"svg_brand\":true \"chartbeat\":true \"connected_stream\":true \"connected_stream_promo\":true \"nav\":true \"pulse_survey\":false \"local_survey\":true \"correspondents\":true \"blogs\":true \"open_graph\":true \"follow_us\":true \"marketdata_markets\":true \"marketdata_shares\":true \"nations_pseudo_nav\":true \"politics_election2015_topic_pages\":true \"politics_election2016_az_pages\":true \"politics_election2016_council_police_pages\":true \"politics_election2016_ni_results_page\":true \"responsive_breaking_news\":true \"live_event\":true \"most_popular\":true \"most_popular_tabs\":true \"most_popular_by_day\":true \"routing\":true \"rum\":true \"radiopromonownext\":true \"config_based_layout\":true \"orb\":true \"enhanced_gallery\":true \"map_most_watched\":true \"top_stories_promo\":true \"features_and_analysis\":true \"section_labels\":true \"index_title\":true \"share_tools\":true \"local_live_promo\":true \"adverts\":true \"adverts_async\":true \"adexpert\":true \"igor_geo_redirect\":true \"igor_device_redirect\":true \"live\":true \"comscore_mmx\":true \"find_local_news\":true \"comments\":true \"comments_enhanced\":true \"browser_notify\":true \"stream_grid_promo\":true \"breaking_news\":false \"top_stories_max_volume\":true \"record_livestats\":true \"contact_form\":true \"channel_page\":true \"portlet_global_variants\":true \"suppress_lep_timezone\":true \"story_recommendations\":true \"cedexis\":true \"mpulse\":true \"story_single_column_layout\":true \"story_image_copyright_labels\":true \"ovp_resolve_primary_media_vpids\":false \"media_player\":true \"travel\":true} \"configuration\":{\"showtimestamp\":\"1\" \"showweather\":\"1\" \"showsport\":\"1\" \"showolympics\":\"1\" \"showfeaturemain\":\"1\" \"showsitecatalyst\":\"1\" \"candyplatform\":\"EnhancedMobile\" \"showwatchlisten\":\"1\" \"showspecialreports\":\"\" \"videotopiccandyid\":\"\" \"showvideofeedsections\":\"1\" \"showstorytopstories\":\"\" \"showstoryfeaturesandanalysis\":\"1\" \"showstorymostpopular\":\"\" \"showgallery\":\"1\" \"cms\":\"cps\" \"channelpagecandyid\":\"10318089\"} \"pollingHost\":\"http:\\\\/\\\\/polling.bbc.co.uk\" \"service\":\"news\" \"locale\":\"en-GB\" \"locatorHost\":null \"locatorFlagPole\":true \"local\":{\"allowLocationLookup\":true} \"isWorldService\":false \"rumAnalytics\":{\"server\":\"http:\\\\/\\\\/ingest.rum.bbc.co.uk\" \"key\":\"news\" \"sample_rate\":0.1 \"url_params\":null \"edition\":\"international\"} \"isChannelPage\":false \"suitenameMap\":\"\" \"languageVariant\":\"\" \"commentsHost\":\"http:\\\\/\\\\/feeds.bbci.co.uk\" \"search\":null \"comscoreAnalytics\":null}; config.configuration[\\'get\\'] = function (key) { return this[key.toLowerCase()]; }; var bootstrapUI=function(){var e=function(){if(navigator.userAgent.match(/(Android (2.0|2.1))|(Nokia)|(OSRE\\\\/)|(Opera (Mini|Mobi))|(w(eb)?OSBrowser)|(UCWEB)|(Windows Phone)|(XBLWP)|(ZuneWP)/))return!1;if(navigator.userAgent.match(/MSIE 10.0/))return!0;var e t=document n=t.head||t.getElementsByTagName(\"head\")[0] r=t.createElement(\"style\") s=t.implementation||{hasFeature:function(){return!1}};r.type=\"text/css\" n.insertBefore(r n.firstChild) e=r.sheet||r.styleSheet;var i=s.hasFeature(\"CSS2\" \"\")?function(t){if(!e||!t)return!1;var n=!1;try{e.insertRule(t 0) n=!/unknown/i.test(e.cssRules[0].cssText) e.deleteRule(e.cssRules.length-1)}catch(r){}return n}:function(t){return e&&t?(e.cssText=t 0!==e.cssText.length&&!/unknown/i.test(e.cssText)&&0===e.cssText.replace(/\\\\r+|\\\\n+/g \"\").indexOf(t.split(\" \")[0])):!1};return i(\\'@font-face{ font-family:\"font\";src:\"font.ttf\"; }\\')}();e&&(document.getElementsByTagName(\"html\")[0].className+=\" ff\") function(){var e=document.documentElement.style;(\"flexBasis\"in e||\"WebkitFlexBasis\"in e||\"msFlexBasis\"in e)&&(document.documentElement.className+=\" flex\")}();var t n r s i a o={} u=function(){var e=document.documentElement.clientWidth r=document.documentElement.clientHeight s=window.innerWidth i=window.innerHeight a=s>1.5*e;t=a?e:s n=a?r:i} c=function(e){var t=document.createElement(\"link\");t.setAttribute(\"rel\" \"stylesheet\") t.setAttribute(\"type\" \"text/css\") t.setAttribute(\"href\" r+e+s+\".css\") t.setAttribute(\"media\" a[e]) i.parentNode.insertBefore(t i) delete a[e]} l=function(e r s){r&&!s&&(t>=r||n>=r)&&c(e) s&&!r&&(s>=t||s>=n)&&c(e) r&&s&&(t>=r||n>=r)&&(s>=t||s>=n)&&c(e)} f=function(e){if(o[e])return o[e];var t=e.match(/\\\\(min\\\\-width:[\\\\s]*([\\\\s]*[0-9\\\\.]+)(px|em)[\\\\s]*\\\\)/) n=e.match(/\\\\(max\\\\-width:[\\\\s]*([\\\\s]*[0-9\\\\.]+)(px|em)[\\\\s]*\\\\)/) r=t&&parseFloat(t[1])||null s=n&&parseFloat(n[1])||null;return o[e]=[r s] o[e]} m=function(){var e=0;for(var t in a)e++;return e} d=function(){m()||window.removeEventListener(\"resize\" h !1);for(var e in a){var t=a[e] n=f(t);l(e n[0] n[1])}} h=function(){u() d()} v=function(e t){a=e r=t.path+(\"/\"!==t.path.substr(-1)?\"/\":\"\") s=t.postfix i=t.insertBefore u() d() window.addEventListener(\"resize\" h !1)};return{stylesheetLoaderInit:v}}(); var stylesheets = {\"compact\":\"(max-width: 599px)\" \"tablet\":\"(min-width: 600px)\" \"wide\":\"(min-width: 1008px)\"}; bootstrapUI.stylesheetLoaderInit(stylesheets { path: \\'http://static.bbci.co.uk/news/1.99.0479/stylesheets/services/news\\' postfix: \\'\\' insertBefore: insertPoint }); var loadRequire = function(){ var js_paths = {\"jquery-1.9\":\"vendor\\\\/jquery-1\\\\/jquery\" \"jquery-1\":\"http:\\\\/\\\\/static.bbci.co.uk\\\\/frameworks\\\\/jquery\\\\/0.3.0\\\\/sharedmodules\\\\/jquery-1.7.2\" \"demi-1\":\"http:\\\\/\\\\/static.bbci.co.uk\\\\/frameworks\\\\/demi\\\\/0.10.0\\\\/sharedmodules\\\\/demi-1\" \"swfobject-2\":\"http:\\\\/\\\\/static.bbci.co.uk\\\\/frameworks\\\\/swfobject\\\\/0.1.10\\\\/sharedmodules\\\\/swfobject-2\" \"jquery\":\"vendor\\\\/jquery-2\\\\/jquery.min\" \"domReady\":\"vendor\\\\/require\\\\/domReady\" \"translation\":\"module\\\\/translations\\\\/en-GB\" \"bump-3\":\"\\\\/\\\\/emp.bbci.co.uk\\\\/emp\\\\/bump-3\\\\/bump-3\"}; js_paths.navigation = \\'module/nav/navManager\\'; requirejs.config({ baseUrl: \\'http://static.bbci.co.uk/news/1.99.0479/js\\' map: { \\'vendor/locator\\': { \\'module/bootstrap\\': \\'vendor/locator/bootstrap\\' \\'locator/stats\\': \\'vendor/locator/stats\\' \\'locator/locatorView\\': \\'vendor/locator/locatorView\\' } } paths: js_paths waitSeconds: 30 }); define(\\'config\\' function () { return config; }); require([\"compiled\\\\/all\"] function() {\\n require([\\'domReady\\'] function (domReady) { domReady(function () { require([\"module\\\\/dotcom\\\\/handlerAdapter\" \"module\\\\/rumAdaptor\" \"module\\\\/stats\\\\/statsSubscriberAdapter\" \"module\\\\/alternativeJsStrategy\\\\/controller\" \"module\\\\/iconLoaderAdapter\" \"module\\\\/polyfill\\\\/location.origin\" \"module\\\\/components\\\\/breakingNewsAdapter\" \"module\\\\/indexTitleAdaptor\" \"module\\\\/navigation\\\\/handlerAdaptor\" \"module\\\\/noTouchDetectionForCss\" \"module\\\\/components\\\\/responsiveImage\" \"module\\\\/components\\\\/timestampAdaptor\" \"module\\\\/tableScrollAdapter\" \"module\\\\/components\\\\/mediaPlayer\\\\/mainAdapter\" \"module\\\\/stats\\\\/statsBindingAdapter\" \"module\\\\/hotspot\\\\/handlerAdapter\"] function() { require([\"module\\\\/strategiserAdaptor\"]); }); }); }); });\\n }; loadRequire(); } else { var l = document.createElement(\\'link\\'); l.href = \\'http://static.bbci.co.uk/news/1.99.0479/icons/generated/icons.fallback.css\\'; l.rel = \\'stylesheet\\'; document.getElementsByTagName(\\'head\\')[0].appendChild(l); } </script> <script type=\"text/javascript\"> /*<![CDATA[*/ bbcdotcom.init({adsToDisplay:[\\'leaderboard\\' \\'sponsor_section\\' \\'mpu\\' \\'outbrain_ar_5\\' \\'outbrain_ar_7\\' \\'outbrain_ar_8\\' \\'outbrain_ar_9\\' \\'native\\' \\'mpu_bottom\\' \\'adsense\\' \\'inread\\']}); /*]]>*/ </script> <noscript><link href=\"http://static.bbci.co.uk/news/1.99.0479/icons/generated/icons.fallback.css\" rel=\"stylesheet\"></noscript>\\n \\n <meta name=\"viewport\" content=\"width=device-width initial-scale=1 user-scalable=1\">\\n</head>\\n<!--[if IE]><body id=\"asset-type-sty\" class=\"ie device--feature\"><![endif]-->\\n<!--[if !IE]>--><body id=\"asset-type-sty\" class=\"device--feature\"><!--<![endif]-->\\n <div class=\"direction\" >\\n \\n <!-- BBCDOTCOM bodyFirst --><div id=\"bbccom_interstitial_ad\" class=\"bbccom_display_none\"></div><div id=\"bbccom_interstitial\" class=\"bbccom_display_none\"><script type=\"text/javascript\"> /*<![CDATA[*/ (function() { if (window.bbcdotcom && bbcdotcom.config.isActive(\\'ads\\')) { googletag.cmd.push(function() { googletag.display(\\'bbccom_interstitial\\'); }); } }()); /*]]>*/ </script></div><div id=\"bbccom_wallpaper_ad\" class=\"bbccom_display_none\"></div><div id=\"bbccom_wallpaper\" class=\"bbccom_display_none\"><script type=\"text/javascript\"> /*<![CDATA[*/ (function() { var wallpaper; if (window.bbcdotcom && bbcdotcom.config.isActive(\\'ads\\')) { if (bbcdotcom.config.isAsync()) { googletag.cmd.push(function() { googletag.display(\\'bbccom_wallpaper\\'); }); } else { googletag.display(\"wallpaper\"); } wallpaper = bbcdotcom.adverts.adRegister.getAd(\\'wallpaper\\'); if (wallpaper !== null && wallpaper !== undefined) { wallpaper.setDomElement(\\'bbccom_wallpaper\\'); } } }()); /*]]>*/ </script></div><script type=\"text/javascript\"> /*<![CDATA[*/ (function() { if (window.bbcdotcom && bbcdotcom.config.isActive(\\'ads\\')) { document.write(unescape(\\'%3Cscript id=\"gnlAdsEnabled\" class=\"bbccom_display_none\"%3E%3C/script%3E\\')); } if (window.bbcdotcom && bbcdotcom.config.isActive(\\'analytics\\')) { document.write(unescape(\\'%3Cscript id=\"gnlAnalyticsEnabled\" class=\"bbccom_display_none\"%3E%3C/script%3E\\')); } if (window.bbcdotcom && bbcdotcom.config.isActive(\\'continuousPlay\\')) { document.write(unescape(\\'%3Cscript id=\"gnlContinuousPlayEnabled\" class=\"bbccom_display_none\"%3E%3C/script%3E\\')); } }()); /*]]>*/ </script> <div id=\"blq-global\"> <div id=\"blq-pre-mast\"> </div> </div> <script type=\"text/html\" id=\"blq-bbccookies-tmpl\"><![CDATA[ <section> <div id=\"bbccookies\" class=\"bbccookies-banner orb-banner-wrapper bbccookies-d\"> <div id=\"bbccookies-prompt\" class=\"orb-banner b-g-p b-r b-f\"> <h2 class=\"orb-banner-title\"> Cookies on the BBC website </h2> <p class=\"orb-banner-content\" dir=\"ltr\"> The BBC has updated its cookie policy. We use cookies to ensure that we give you the best experience on our website. This includes cookies from third party social media websites if you visit a page which contains embedded content from social media. Such third party cookies may track your use of the BBC website.<span class=\"bbccookies-international-message\"> We and our partners also use cookies to ensure we show you advertising that is relevant to you.</span> If you continue without changing your settings we\\'ll assume that you are happy to receive all cookies on the BBC website. However you can change your cookie settings at any time. </p> <ul class=\"orb-banner-options\"> <li id=\"bbccookies-continue\"> <button type=\"button\" id=\"bbccookies-continue-button\">Continue</button> </li> <li id=\"bbccookies-settings\"> <a href=\"/privacy/cookies/managing/cookie-settings.html\">Change settings</a> </li> <li id=\"bbccookies-more\"><a href=\"/privacy/cookies/bbc\">Find out more</a></li></ul> </div> </div> </section> ]]></script> <script type=\"text/javascript\">/*<![CDATA[*/ (function(){if(bbccookies._showPrompt()){var g=document b=g.getElementById(\"blq-pre-mast\") e=g.getElementById(\"blq-bbccookies-tmpl\") a f;if(b&&g.createElement){a=g.createElement(\"div\");f=e.innerHTML;f=f.replace(\"<\"+\"![CDATA[\" \"\").replace(\"]]\"+\">\" \"\");a.innerHTML=f;b.appendChild(a);blqCookieContinueButton=g.getElementById(\"bbccookies-continue-button\");blqCookieContinueButton.onclick=function(){a.parentNode.removeChild(a);return false};bbccookies._setPolicy(bbccookies.readPolicy())}var c=g.getElementById(\"bbccookies\");if(c&&!window.orb.fig(\"uk\")){c.className=c.className.replace(/\\\\bbbccookies-d\\\\b/ \"\");c.className=c.className+(\" bbccookies-w\")}}})(); /*]]>*/</script> <script type=\"text/javascript\">/*<![CDATA[*/ if (bbccookies.isAllowed(\\'s1\\')) { require([\\'istats-1\\'] function (istats) { istats.invoke(); }); } /*]]>*/</script> <!-- Begin iStats 20100118 (UX-CMC 1.1009.3) --> <script type=\"text/javascript\">/*<![CDATA[*/ if (bbccookies.isAllowed(\\'s1\\')) { (function () { require([\\'istats-1\\'] function (istats) { istatsTrackingUrl = istats.getDefaultURL(); if (istats.isEnabled() && bbcFlagpoles_istats === \\'ON\\') { sitestat(istatsTrackingUrl); } else { window.ns_pixelUrl = istatsTrackingUrl; /* used by Flash library to track */ } function sitestat(n) { var j = document f = j.location b = \"\"; if (j.cookie.indexOf(\"st_ux=\") != -1) { var k = j.cookie.split(\";\"); var e = \"st_ux\" h = document.domain a = \"/\"; if (typeof ns_ != \"undefined\" && typeof ns_.ux != \"undefined\") { e = ns_.ux.cName || e; h = ns_.ux.cDomain || h; a = ns_.ux.cPath || a } for (var g = 0 f = k.length; g < f; g++) { var m = k[g].indexOf(\"st_ux=\"); if (m != -1) { b = \"&\" + decodeURI(k[g].substring(m + 6)) } } bbccookies.set(e + \"=; expires=\" + new Date(new Date().getTime() - 60).toGMTString() + \"; path=\" + a + \"; domain=\" + h); } window.ns_pixelUrl = n; } }); })(); } else { window.istats = {enabled: false}; } /*]]>*/</script> <noscript><p style=\"position: absolute; top: -999em;\"><img src=\"//sa.bbc.co.uk/bbc/bbc/s?name=news.technology.story.26415021.page&amp;cps_asset_id=26415021&amp;page_type=Story&amp;section=%2Fnews%2Ftechnology&amp;first_pub=2014-03-03T07%3A36%3A59%2B00%3A00&amp;last_editorial_update=2014-03-03T10%3A22%3A55%2B00%3A00&amp;title=An+hour+to+catch+the+coding+bug&amp;for_nation=il&amp;app_version=1.99.0&amp;bbc_site=news&amp;pal_route=asset&amp;ml_name=barlesque&amp;app_type=responsive&amp;language=en-GB&amp;ml_version=0.28.4&amp;pal_webapp=tabloid&amp;prod_name=news&amp;app_name=news&amp;blq_js_enabled=0&amp;blq_s=4d&amp;blq_r=2.7&amp;blq_v=default&amp;blq_e=pal \" height=\"1\" width=\"1\" alt=\"\"/></p></noscript> <!-- End iStats (UX-CMC) --> \\n <!--[if (gt IE 8) | (IEMobile)]><!--> <header id=\"orb-banner\" role=\"banner\"> <!--<![endif]--> <!--[if (lt IE 9) & (!IEMobile)]> <![if (IE 8)]> <header id=\"orb-banner\" role=\"banner\" class=\"orb-old-ie orb-ie8\"> <![endif]> <![if (IE 7)]> <header id=\"orb-banner\" role=\"banner\" class=\"orb-old-ie orb-ie7\"> <![endif]> <![if (IE 6)]> <header id=\"orb-banner\" role=\"banner\" class=\"orb-old-ie orb-ie6\"> <![endif]> <![endif]--> <div id=\"orb-header\" class=\"orb-nav-pri orb-nav-pri-white b-header--white--black orb-nav-empty\" > <div class=\"orb-nav-pri-container b-r b-g-p\"> <div class=\"orb-nav-section orb-nav-blocks\"> <a href=\"/\"> <img src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/img/bbc-blocks-dark.png\" width=\"84\" height=\"24\" alt=\"BBC\" /> </a> </div> <section> <div class=\"orb-skip-links\"> <h2>Accessibility links</h2> <ul> <li><a href=\"#page\">Skip to content</a></li> <li><a id=\"orb-accessibility-help\" href=\"/accessibility/\">Accessibility Help</a></li> </ul> </div> </section> <div class=\"orb-nav-section orb-nav-id orb-nav-focus orb-nav-id-default\"> <div id=\"idcta-statusbar\" class=\"orb-nav-section orb-nav-focus\"> <a id=\"idcta-link\" href=\"https://ssl.bbc.com/id/status?ptrt=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021\"> <img id=\"idcta-image\" src=\"http://static.bbci.co.uk/id/0.32.25/img/bbcid_orb_signin_dark.png\" alt=\"\" width=\"18\" height=\"18\" > <span id=\"idcta-username\">BBC iD</span> </a> </div> <script type=\"text/javascript\"> require([\\'idcta/statusbar\\'] function(statusbar) { new statusbar.Statusbar({\"id\":\"idcta-statusbar\" \"publiclyCacheable\":true}); }); </script> </div> <nav role=\"navigation\" class=\"orb-nav\"> <div class=\"orb-nav-section orb-nav-links orb-nav-focus\" id=\"orb-nav-links\"> <h2>BBC navigation</h2> <ul> <li class=\"orb-nav-news orb-d\" > <a href=\"http://www.bbc.co.uk/news/\">News</a> </li> <li class=\"orb-nav-newsdotcom orb-w\" > <a href=\"http://www.bbc.com/news/\">News</a> </li> <li class=\"orb-nav-sport\" > <a href=\"/sport/\">Sport</a> </li> <li class=\"orb-nav-weather\" > <a href=\"/weather/\">Weather</a> </li> <li class=\"orb-nav-shop orb-w\" > <a href=\"http://shop.bbc.com/\">Shop</a> </li> <li class=\"orb-nav-earthdotcom orb-w\" > <a href=\"http://www.bbc.com/earth/\">Earth</a> </li> <li class=\"orb-nav-travel-dotcom orb-w\" > <a href=\"http://www.bbc.com/travel/\">Travel</a> </li> <li class=\"orb-nav-capital orb-w\" > <a href=\"http://www.bbc.com/capital/\">Capital</a> </li> <li class=\"orb-nav-iplayer orb-d\" > <a href=\"/iplayer/\">iPlayer</a> </li> <li class=\"orb-nav-culture orb-w\" > <a href=\"http://www.bbc.com/culture/\">Culture</a> </li> <li class=\"orb-nav-autos orb-w\" > <a href=\"http://www.bbc.com/autos/\">Autos</a> </li> <li class=\"orb-nav-future orb-w\" > <a href=\"http://www.bbc.com/future/\">Future</a> </li> <li class=\"orb-nav-tv\" > <a href=\"/tv/\">TV</a> </li> <li class=\"orb-nav-radio\" > <a href=\"/radio/\">Radio</a> </li> <li class=\"orb-nav-cbbc\" > <a href=\"/cbbc\">CBBC</a> </li> <li class=\"orb-nav-cbeebies\" > <a href=\"/cbeebies\">CBeebies</a> </li> <li class=\"orb-nav-food\" > <a href=\"/food/\">Food</a> </li> <li class=\"orb-nav-arts orb-d\" > <a href=\"/arts/\">Arts</a> </li> <li class=\"orb-nav-makeitdigital\" > <a href=\"/makeitdigital\">Make It Digital</a> </li> <li > <a href=\"/iwonder\">iWonder</a> </li> <li > <a href=\"/education\">Bitesize</a> </li> <li class=\"orb-nav-music\" > <a href=\"/music/\">Music</a> </li> <li class=\"orb-nav-nature orb-w\" > <a href=\"/nature/\">Nature</a> </li> <li class=\"orb-nav-earth orb-d\" > <a href=\"http://www.bbc.com/earth/\">Earth</a> </li> <li class=\"orb-nav-local\" > <a href=\"/local/\">Local</a> </li> <li class=\"orb-nav-travel orb-d\" > <a href=\"/travel/\">Travel</a> </li> <li id=\"orb-nav-more\"><a href=\"#orb-footer\" data-alt=\"More\">Menu<span class=\"orb-icon orb-icon-arrow\"></span></a></li> </ul> </div> </nav> <div class=\"orb-nav-section orb-nav-search\"> <a href=\"http://search.bbc.co.uk/search\"> <img src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/img/orb-search-dark.png\" width=\"18\" height=\"18\" alt=\"Search the BBC\" /> </a> <form class=\"b-f\" id=\"orb-search-form\" role=\"search\" method=\"get\" action=\"http://search.bbc.co.uk/search\" accept-charset=\"utf-8\"> <div> <input type=\"hidden\" name=\"uri\" value=\"/news/technology-26415021\" /> <label for=\"orb-search-q\">Search the BBC</label> <input id=\"orb-search-q\" type=\"text\" name=\"q\" placeholder=\"Search\" /> <input type=\"image\" id=\"orb-search-button\" src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/img/orb-search-dark.png\" width=\"17\" height=\"17\" alt=\"Search the BBC\" /> <input type=\"hidden\" name=\"suggid\" id=\"orb-search-suggid\" /> </div> </form> </div> </div> <div id=\"orb-panels\" > <script type=\"text/template\" id=\"orb-panel-template\"><![CDATA[ <div id=\"orb-panel-<%= panelname %>\" class=\"orb-panel\" aria-labelledby=\"orb-nav-<%= panelname %>\"> <div class=\"orb-panel-content b-g-p b-r\"> <%= panelcontent %> </div> </div> ]]></script> </div> </div> </header> <!-- Styling hook for shared modules only --> <div id=\"orb-modules\"> \\n <div id=\"site-container\">\\n <!--[if lt IE 9]>\\n<div class=\"browser-notify\">\\n <div class=\"browser-notify__banner\">\\n <div class=\"browser-notify__icon\"></div>\\n <span>This site is optimised for modern web browsers and does not fully support your version of Internet Explorer</span>\\n </div>\\n</div>\\n<![endif]-->\\n <div class=\"site-brand site-brand--height\" role=\"banner\" aria-label=\"News\">\\n <div class=\"site-brand-inner site-brand-inner--height\">\\n <div class=\"navigation navigation--primary\">\\n <a href=\"/news\" id=\"brand\">\\n <svg class=\"brand__svg\" aria-label=\"BBC News\">\\n <title>BBC News</title>\\n <image xlink:href=\"http://static.bbci.co.uk/news/1.99.0479/img/brand/generated/news-light.svg\" src=\"http://static.bbci.co.uk/news/1.99.0479/img/brand/generated/news-light.png\" width=\"100%\" height=\"100%\"/>\\n </svg>\\n </a>\\n <h2 class=\"navigation__heading off-screen\">News navigation</h2>\\n <a href=\"#core-navigation\" class=\"navigation__section navigation__section--core\" data-event=\"header\">\\n Sections </a>\\n </div>\\n </div>\\n \\n<div class=\"navigation navigation--wide\">\\n <ul class=\"navigation-wide-list\" role=\"navigation\" aria-label=\"News\" data-panel-id=\"js-navigation-panel-primary\">\\n <li>\\n <a href=\"/news\" class=\"navigation-wide-list__link\">\\n <span>Home</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/video_and_audio/international\" class=\"navigation-wide-list__link\">\\n <span>Video</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/world\" data-panel-id=\"js-navigation-panel-World\" class=\"navigation-wide-list__link\">\\n <span>World</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/uk\" data-panel-id=\"js-navigation-panel-UK\" class=\"navigation-wide-list__link\">\\n <span>UK</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/business\" data-panel-id=\"js-navigation-panel-Business\" class=\"navigation-wide-list__link\">\\n <span>Business</span>\\n </a>\\n </li>\\n <li class=\"selected\">\\n <a href=\"/news/technology\" class=\"navigation-wide-list__link navigation-arrow--open\">\\n <span>Tech</span>\\n </a>\\n <span class=\"off-screen\">selected</span> </li>\\n <li>\\n <a href=\"/news/science_and_environment\" class=\"navigation-wide-list__link\">\\n <span>Science</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/magazine\" class=\"navigation-wide-list__link\">\\n <span>Magazine</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/entertainment_and_arts\" class=\"navigation-wide-list__link\">\\n <span>Entertainment &amp; Arts</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/health\" class=\"navigation-wide-list__link\">\\n <span>Health</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/in_pictures\" class=\"navigation-wide-list__link\">\\n <span>In Pictures</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/also_in_the_news\" class=\"navigation-wide-list__link\">\\n <span>Also in the News</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/special_reports\" class=\"navigation-wide-list__link\">\\n <span>Special Reports</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/explainers\" class=\"navigation-wide-list__link\">\\n <span>Explainers</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/the_reporters\" class=\"navigation-wide-list__link\">\\n <span>The Reporters</span>\\n </a>\\n </li>\\n <li>\\n <a href=\"/news/have_your_say\" class=\"navigation-wide-list__link navigation-wide-list__link--last\">\\n <span>Have Your Say</span>\\n </a>\\n </li>\\n </ul>\\n</div>\\n </div>\\n \\n \\n \\n<div id=\"bbccom_leaderboard_1_2_3_4\" class=\"bbccom_slot \" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'leaderboard\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n <div id=\"breaking-news-container\" data-polling-url=\"http://polling.bbc.co.uk/news/latest_breaking_news?audience=International\" aria-live=\"polite\"></div>\\n <div class=\"container-width-only\">\\n <span class=\"index-title index-title--redundant \" id=\"comp-index-title\" data-index-title-meta=\"{&quot;id&quot;:&quot;comp-index-title&quot; &quot;type&quot;:&quot;index-title&quot; &quot;handler&quot;:&quot;indexTitle&quot; &quot;deviceGroups&quot;:null &quot;opts&quot;:{&quot;alwaysVisible&quot;:false &quot;onFrontPage&quot;:false} &quot;template&quot;:&quot;index-title&quot;}\">\\n <span class=\"index-title__container\">\\n <a href=\"/news/technology\">Technology</a>\\n </span>\\n </span>\\n \\n<div id=\"bbccom_sponsor_section_1_2_3_4\" class=\"bbccom_slot \" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'sponsor_section\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n </div>\\n \\n <div id=\"page\" class=\"configurable story \" data-story-id=\"technology-26415021\"> <div role=\"main\"> <div class=\"container-width-only\"> <span class=\"index-title index-title--redundant \" id=\"comp-index-title\" data-index-title-meta=\"{&quot;id&quot;:&quot;comp-index-title&quot; &quot;type&quot;:&quot;index-title&quot; &quot;handler&quot;:&quot;indexTitle&quot; &quot;deviceGroups&quot;:null &quot;opts&quot;:{&quot;alwaysVisible&quot;:false &quot;onFrontPage&quot;:false} &quot;template&quot;:&quot;index-title&quot;}\">\\n <span class=\"index-title__container\">\\n <a href=\"/news/technology\">Technology</a>\\n </span>\\n </span>\\n \\n<div id=\"bbccom_sponsor_section_1_2_3_4\" class=\"bbccom_slot \" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'sponsor_section\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n </div> <div class=\"container\"> <div class=\"container--primary-and-secondary-columns column-clearfix\"> <div class=\"column--primary\">\\n <div class=\"story-body\">\\n <h1 class=\"story-body__h1\">An hour to catch the coding bug</h1>\\n <div class=\"byline\">\\n <span class=\"byline__name\">By Mark Ward</span>\\n <span class=\"byline__title\">Technology correspondent BBC News</span>\\n </div>\\n \\n <div class=\"story-body__mini-info-list-and-share\">\\n <ul class=\"mini-info-list\">\\n <li class=\"mini-info-list__item\"> <div class=\"date date--v2\" data-seconds=\"1393842175\" data-datetime=\"3 March 2014\">3 March 2014</div>\\n</li>\\n <li class=\"mini-info-list__item\"><span class=\"mini-info-list__section-desc off-screen\">From the section </span><a href=\"/news/technology\" class=\"mini-info-list__section\" data-entityid=\"section-label\">Technology</a></li>\\n</ul>\\n </div>\\n <div class=\"story-body__inner\" property=\"articleBody\">\\n <figure class=\"media-landscape has-caption full-width lead\">\\n <span class=\"image-and-copyright-container\">\\n \\n <img class=\"js-image-replace\" alt=\"Child with computer\" src=\"http://ichef.bbci.co.uk/news/320/media/images/73325000/jpg/_73325163_olly009.jpg\" width=\"512\" height=\"320\">\\n \\n \\n \\n </span>\\n \\n <figcaption class=\"media-caption\">\\n <span class=\"off-screen\">Image caption</span>\\n <span class=\"media-caption__text\">\\n We did our Hour of Code on a lazy Sunday morning\\n </span>\\n </figcaption>\\n \\n </figure><p class=\"story-body__introduction\">Okay 60 minutes and counting. Here we go.</p><p>I\\'ve got an hour to convince my kids that programming is for them.</p><p>Well sort of.</p><p>I\\'m putting my twin 10-year-old boys Toby and Callum through the Hour of Code - a campaign that seeks to ignite an interest in programming - the part we\\'re doing using specially created web-based exercises. </p><p>The campaign begun in the US has landed in the UK where it also coincides with government calls for as many children as possible to get coding.</p><div id=\"bbccom_mpu_1_2_3\" class=\"bbccom_slot mpu-ad\" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /**/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'mpu\\' [1 2 3]);\\n }\\n })();\\n /**/\\n </script>\\n </div>\\n</div><p>Programming is being pushed because in an ever more technological world it can only be a good thing to give people a peep into what goes on behind the touch screen cash point and website. </p><p>The Hour of Code is supposed to be the start of that journey and I like many other parents feel it\\'s one my children should be embarking on. I do feel like a clock somewhere is ticking and unless they get started with this essential skill they\\'ll be left behind. </p><p>\"In the future kids are going to be doing programming \" said Callum when I asked him why it was worth learning how to code. \"We need to learn so we can do stuff with the computer otherwise it will be a blank page and never work.\"</p><h2 class=\"story-body__crosshead\">Zombie dance</h2><figure class=\"media-landscape has-caption full-width\">\\n <span class=\"image-and-copyright-container\">\\n \\n \\n <div class=\"js-delayed-image-load\" data-alt=\"Screenshot from the hour of code\" data-src=\"http://ichef-1.bbci.co.uk/news/320/media/images/73325000/jpg/_73325167_hourofcode.jpg\" data-width=\"512\" data-height=\"288\"></div>\\n \\n \\n </span>\\n \\n <figcaption class=\"media-caption\">\\n <span class=\"off-screen\">Image caption</span>\\n <span class=\"media-caption__text\">\\n The coding exercises involve familiar characters such as the Angry Birds\\n </span>\\n </figcaption>\\n \\n </figure> <div id=comp-story-recommendations\\n class=\"hidden\"\\n data-comp-meta=\"{&quot;id&quot;:&quot;comp-story-recommendations&quot; &quot;type&quot;:&quot;recommendations&quot; &quot;handler&quot;:&quot;default&quot; &quot;deviceGroups&quot;:null &quot;opts&quot;:{&quot;conditions&quot;:{&quot;feature_toggle&quot;:&quot;story_recommendations&quot; &quot;uri_contains&quot;:{&quot;show_if&quot;:&quot;\\\\/technology-&quot;}} &quot;id&quot;:&quot;story-recommendations&quot; &quot;loading_strategy&quot;:&quot;post_load&quot; &quot;link_location&quot;:&quot;news_recommendation&quot; &quot;hotspot&quot;:true &quot;asset_id&quot;:&quot;technology-26415021&quot; &quot;position_info&quot;:{&quot;instanceNo&quot;:1 &quot;positionInRegion&quot;:3 &quot;lastInRegion&quot;:false &quot;lastOnPage&quot;:false &quot;column&quot;:&quot;primary_column&quot;}}}\">\\n </div> <p>It\\'s the getting started for both parents and their offspring that the Hour is intended to help with. I\\'m probably like most parents in that I have no significant qualification in computer science. All I can offer my boys is a lifetime of tinkering backed up over the past 18 months with online courses in Python HTML CSS Javascript and the like. </p><p>There\\'s good precedents for the value of something like the Hour of Code. I\\'ve quizzed every chief technology officer (CTO) developer or IT worker I\\'ve met in the past couple of weeks about what got them started and every one knew exactly the moment they got it. Their eyes lit up as they talked about typing in code listings from magazines working through every Dos command or designing their own blocky 8-bit game characters.</p><p>And finally at the back of my mind are all those statistics about the shortages of skilled IT staff and my hope that if this works then their future career options will be much wider than they would be without this skill.</p><p>So no pressure then.</p><p>Yesterday morning we gave it a go. I was keen for it to be fun rather than feel like school as there\\'s nothing more likely to turn them off than for it to be sold as good for them. I think we struck the right note of informality - Cal did it in his onesie. </p><p>It went OK no better than that. Pretty good. We worked through all the exercises getting angry birds to mash pigs and zombies to chomp sunflowers. The coding is done by dragging blocks representing different commands into a work area and building the blocks into a tower of coherent instructions.</p><p>The block-building system is based on the Scratch programming language build by MIT\\'s Mitch Resnick. </p><p>The exercises start easy - just getting an angry bird to hop on to a pig. By the end we were using \"If… else\" statements and loops to help a zombie navigate a tricky maze to reach the sunflower.</p><p>This went down well with Callum. \"Cool! It\\'s scanning for a path \" he said as the zombie worked its way towards the hapless flower.</p><p>Mistakes were made but we learned from them we debated over which way to make the birds and zombies turn and the time went really fast. </p><p>Toby was surprised to find that this counted as programming.</p><p>\"I thought coding was just a lot of people tapping in letter and numbers until they got it right \" he said. </p><h2 class=\"story-body__crosshead\">Next steps</h2><p>And yet I felt it was a bit too easy. I wanted to make the coding connection to real life more tangible. So as we had about 15 minutes of our Hour of Code left we went further.</p><p>This time we used the MIT App Inventor to build a basic program that would run on the tablets they own. </p><p>The app inventor uses the same \"drag the block\" method to build a program and following the instructions we had soon created an app that turned anything typed in text into speech. </p><figure class=\"media-landscape has-caption body-narrow-width\">\\n <span class=\"image-and-copyright-container\">\\n \\n \\n <div class=\"js-delayed-image-load\" data-alt=\"Screenshot from MIT App Inventor\" data-src=\"http://ichef-1.bbci.co.uk/news/320/media/images/73325000/jpg/_73325169_appinventor.jpg\" data-width=\"448\" data-height=\"287\"></div>\\n \\n \\n </span>\\n \\n <figcaption class=\"media-caption\">\\n <span class=\"off-screen\">Image caption</span>\\n <span class=\"media-caption__text\">\\n The App Inventor uses the same block dragging system as the Hour of Code exercises\\n </span>\\n </figcaption>\\n \\n </figure><p>We got it working on Cal\\'s tablet and soon they were getting that gadget to call out lots of phrases. Almost inevitably as they are 10 years old a lot of these phrases involved the words \"willy\" and \"bum\". </p><p>But they had a lot of fun with it and it brought home to them how straight-forward coding can be. In just over an hour they went from being pretty much novices to creating an Android app - a basic one that trades on the expertise of the people that built the coding tools but it was an accomplishment nonetheless.</p><p>Did they catch the coding bug as a result? </p><p>Maybe later in the day they were programming each other after one of their regular wrestling matches left Toby lying exhausted on the floor. Suddenly Cal called out commands such as \"roll left\" and Toby started obeying even to the point of crashing into the sofa when too many roll commands were given. </p><p>Then Toby had his turn and did the same they even worked out that they had to compensate for the changes in left and right as they rolled. </p><p>So I think that hour started something. Both with them and with me. Building that Android app made me realise that it is straight-forward. That my lack of formal qualifications do not matter as much as I thought. And maybe that\\'s the point of the hour. Making people realise that it is not scary and difficult. You just have to find an hour and give it a try. You can even do it in your onesie.</p>\\n </div>\\n</div>\\n <div class=\"share share--lightweight show ghost-column\">\\n <a name=\"share-tools\"></a>\\n <h2 class=\"share__title share__title--lightweight\">\\n Share this story <a href=\"http://www.bbc.co.uk/help/web/sharing.shtml\">About&nbsp;sharing</a>\\n </h2>\\n <ul class=\"share__tools share__tools--lightweight\">\\n <li class=\"share__tool share__tool--email\">\\n <a href=\"mailto:?subject=Shared%20from%20BBC%20News&body=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021\" >\\n <span>Email</span>\\n </a>\\n </li>\\n <li class=\"share__tool share__tool--facebook\">\\n <a href=\"http://www.facebook.com/dialog/feed?app_id=58567469885&redirect_uri=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021&link=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021%3FSThisFB\" >\\n <span>Facebook</span>\\n </a>\\n </li>\\n <li class=\"share__tool share__tool--twitter\">\\n <a href=\"https://twitter.com/intent/tweet?text=BBC%20News%20-%20An%20hour%20to%20catch%20the%20coding%20bug&url=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021\" class=shortenUrl data-social-url=https://twitter.com/intent/tweet?text=BBC+News+-+An+hour+to+catch+the+coding+bug&amp;url= data-target-url=http://www.bbc.com/news/technology-26415021>\\n <span>Twitter</span>\\n </a>\\n </li>\\n <li class=\"share__tool share__tool--whatsapp\">\\n <a href=\"whatsapp://send?text=BBC%20News%20%7C%20An%20hour%20to%20catch%20the%20coding%20bug%20-%20http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021%3Focid%3Dwsnews.chat-apps.in-app-msg.whatsapp.trial.link1_.auin\" >\\n <span>WhatsApp</span>\\n </a>\\n </li>\\n <li class=\"share__tool share__tool--linkedin\">\\n <a href=\"https://www.linkedin.com/shareArticle?mini=true&url=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021&title=An%20hour%20to%20catch%20the%20coding%20bug&summary=Is%20it%20possible%20to%20get%20children%20interested%20in%20computer%20programming%20in%20just%2060%20minutes%3F%20The%20Hour%20of%20Code%20has%20been%20designed%20to%20do%20just%20that.&source=BBC\" >\\n <span>Linkedin</span>\\n </a>\\n </li>\\n </ul>\\n</div>\\n <div class=\"story-more\">\\n <div class=\"group story-alsos more-on-this-story\"> <div class=\"group__header\"> <h2 class=\"group__title\">More on this story</h2> </div> <div class=\"group__body\"> <ul class=\"units-list \"> <li class=\"unit unit--regular\" data-entityid=\"more-on-this-story#1\" > <a href=\"/news/education-25648769\" class=\"unit__link-wrapper\"> <div class=\"unit__body\"> <div class=\"unit__header\"> <div class=\"unit__title\"> \\n <span class=\"icon-new icon-new--video-square-red\"><span class=\"off-screen\"> Video</span></span>\\n \\n \\n <span class=\"cta\"> Computer coding taught in Estonian primary schools </span> </div> <div class=\"unit__meta\"> <div class=\"date date--v1\" data-seconds=\"1389169705\" data-datetime=\"8 January 2014\">8 January 2014</div> </div> </div> </div> </a> </li> <li class=\"unit unit--regular\" data-entityid=\"more-on-this-story#2\" > <a href=\"/news/technology-26150717\" class=\"unit__link-wrapper\"> <div class=\"unit__body\"> <div class=\"unit__header\"> <div class=\"unit__title\"> <span class=\"cta\"> Year of Code - PR fiasco or vital mission? </span> </div> <div class=\"unit__meta\"> <div class=\"date date--v1\" data-seconds=\"1392196197\" data-datetime=\"12 February 2014\">12 February 2014</div> </div> </div> </div> </a> </li> <li class=\"unit unit--regular\" data-entityid=\"more-on-this-story#3\" > <a href=\"/news/technology-25857276\" class=\"unit__link-wrapper\"> <div class=\"unit__body\"> <div class=\"unit__header\"> <div class=\"unit__title\"> <span class=\"cta\"> Are teachers ready for the coding revolution? </span> </div> <div class=\"unit__meta\"> <div class=\"date date--v1\" data-seconds=\"1390468159\" data-datetime=\"23 January 2014\">23 January 2014</div> </div> </div> </div> </a> </li> </ul> </div> </div> </div>\\n \\n<div class=\"story-more\">\\n <div class=\"group related-links--external more-on-this-story\"> <div class=\"group__header\"> <h2 class=\"group__title\">Related Internet links</h2> </div> <div class=\"group__body\"> <ul class=\"units-list \"> <li class=\"unit unit--headline\" data-entityid=\"more-on-this-story#1\" > <div class=\"unit__body\"> <div class=\"unit__header\"> <a class=\"unit__link-wrapper\" href=\"http://uk.code.org/\"> <div class=\"unit__title\"> <span class=\"cta\">UK Hour of Code</span> </div> </a> </div> </div> </li> <li class=\"unit unit--headline\" data-entityid=\"more-on-this-story#2\" > <div class=\"unit__body\"> <div class=\"unit__header\"> <a class=\"unit__link-wrapper\" href=\"http://appinventor.mit.edu/explore/\"> <div class=\"unit__title\"> <span class=\"cta\">MIT App Inventor</span> </div> </a> </div> </div> </li> <li class=\"unit unit--headline\" data-entityid=\"more-on-this-story#3\" > <div class=\"unit__body\"> <div class=\"unit__header\"> <a class=\"unit__link-wrapper\" href=\"http://scratch.mit.edu/\"> <div class=\"unit__title\"> <span class=\"cta\">MIT Scratch</span> </div> </a> </div> </div> </li> </ul> </div> </div> \\n <p class=\"unit__meta\">The BBC is not responsible for the content of external Internet sites</p>\\n</div>\\n <div id=comp-pattern-library\\n class=\"hidden\"\\n data-post-load-url=\"/news/pattern-library-components?options%5Bcontainer_class%5D=container-more-from-this-index&amp;options%5Bdata%5D%5Bsource%5D=candy_parent_index&amp;options%5Bdata%5D%5Bsource_params%5D%5Bsection_title%5D=1&amp;options%5Bcomponents%5D%5B0%5D%5Bname%5D=sparrow&amp;options%5Bcomponents%5D%5B0%5D%5Blimit%5D=3&amp;options%5Bloading_strategy%5D=post_load&amp;options%5Bstats%5D%5Blink_location%5D=more-section&amp;options%5Basset_id%5D=technology-26415021&amp;presenter=pattern-library-presenter\">\\n </div> <div id=comp-from-other-news-sites\\n class=\"hidden\"\\n data-comp-meta=\"{&quot;id&quot;:&quot;comp-from-other-news-sites&quot; &quot;type&quot;:&quot;from-other-news-sites&quot; &quot;handler&quot;:&quot;default&quot; &quot;deviceGroups&quot;:null &quot;opts&quot;:{&quot;conditions&quot;:[&quot;is_local_page&quot;] &quot;loading_strategy&quot;:&quot;post_load&quot; &quot;asset_id&quot;:&quot;technology-26415021&quot; &quot;position_info&quot;:{&quot;instanceNo&quot;:1 &quot;positionInRegion&quot;:10 &quot;lastInRegion&quot;:true &quot;lastOnPage&quot;:false &quot;column&quot;:&quot;primary_column&quot;}} &quot;template&quot;:&quot;\\\\/component\\\\/from-other-news-sites&quot;}\">\\n </div> \\n<div id=\"bbccom_outbrain_ar_5_1_2_3_4\" class=\"bbccom_slot outbrain-ad\" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'outbrain_ar_5\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n<div id=\"bbccom_outbrain_ar_7_1_2_3_4\" class=\"bbccom_slot outbrain-ad\" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'outbrain_ar_7\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n<div id=\"bbccom_outbrain_ar_8_1_2_3_4\" class=\"bbccom_slot outbrain-ad\" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'outbrain_ar_8\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n </div>\\n <div class=\"column--secondary\" role=\"complementary\">\\n <div id=\"comp-top-stories-promo\" class=\"top-stories-promo\">\\n <h2 class=\"top-stories-promo__title\">Top Stories</h2>\\n <a href=\"/news/world-europe-34933608\" class=\"top-stories-promo-story\" data-asset-id=\"/news/world-europe-34933608\"data-entityid=\"top-stories#1\">\\n <strong class=\"top-stories-promo-story__title\">Russia \\'plans sanctions against Turkey\\'</strong>\\n <p class=\"top-stories-promo-story__summary top-stories-promo-story__summary--none\">Russia is preparing wide-ranging economic sanctions against Turkey after the downing of one of its jets Prime Minister Dmitry Medvedev says.</p>\\n <div class=\"date date--v2\" data-seconds=\"1448556072\" data-datetime=\"26 November 2015\">26 November 2015</div>\\n </a>\\n <a href=\"/news/world-europe-34933500\" class=\"top-stories-promo-story\" data-asset-id=\"/news/world-europe-34933500\"data-entityid=\"top-stories#3\">\\n <strong class=\"top-stories-promo-story__title\">Brussels threat level reduced</strong>\\n <div class=\"date date--v2\" data-seconds=\"1448556876\" data-datetime=\"26 November 2015\">26 November 2015</div>\\n </a>\\n <a href=\"/news/world-us-canada-34930042\" class=\"top-stories-promo-story\" data-asset-id=\"/news/world-us-canada-34930042\"data-entityid=\"top-stories#5\">\\n <strong class=\"top-stories-promo-story__title\">Trump mocks disabled reporter</strong>\\n <div class=\"date date--v2\" data-seconds=\"1448528751\" data-datetime=\"26 November 2015\">26 November 2015</div>\\n </a>\\n </div> \\n<div id=\"bbccom_mpu_4\" class=\"bbccom_slot mpu-ad\" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'mpu\\' [4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n <div class=\"hotspot hotspot--empty hotspot--hidden\"></div>\\n \\n<div class=\"features-and-analysis\" id=\"comp-features-and-analysis\" >\\n <h2 class=\"features-and-analysis__title\">\\n \\n Features &amp; Analysis\\n </h2>\\n <div class=\"features-and-analysis__stories promo-unit-spacer\">\\n \\n <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#1\">\\n <a href=\"/news/magazine-34928547\" class=\"bold-image-promo\">\\n <div class=\"bold-image-promo__image\">\\n <div class=\"responsive-image responsive-image--16by9\">\\n <div class=\"responsive-image__inner-for-label\">\\n <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/4D9C/production/_86886891__73250751_020647244-1.jpg\" data-width=\"976\" data-height=\"549\" data-alt=\"Fighters from the so called Islamic State (ISIS) in Raqqa\"></div>\\n <!--[if lt IE 9]>\\n <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/4D9C/production/_86886891__73250751_020647244-1.jpg\" class=\"js-image-replace\" alt=\"Fighters from the so called Islamic State (ISIS) in Raqqa\" width=\"976\" height=\"549\" />\\n <![endif]-->\\n \\n <div class=\"responsive-image__label\" aria-hidden=\"true\">\\n <span class=\"icon video\"><span class=\"off-screen\"> Video</span></span>\\n \\n \\n \\n <span class=\"responsive-image__label-text\">3:23</span>\\n </div>\\n </div>\\n </div>\\n </div>\\n <h3 class=\"bold-image-promo__title\">Silent slaughter</h3>\\n <p class=\"bold-image-promo__summary\">Capturing daily life in Raqqa under Islamic State </p>\\n </a>\\n </div>\\n \\n \\n <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#2\">\\n <a href=\"/news/magazine-34858199\" class=\"bold-image-promo\">\\n <div class=\"bold-image-promo__image\">\\n <div class=\"responsive-image responsive-image--16by9\">\\n \\n <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/12B7C/production/_86886667_angel_bbc.jpg\" data-width=\"511\" data-height=\"287\" data-alt=\"Dave Angel\"></div>\\n <!--[if lt IE 9]>\\n <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/12B7C/production/_86886667_angel_bbc.jpg\" class=\"js-image-replace\" alt=\"Dave Angel\" width=\"511\" height=\"287\" />\\n <![endif]-->\\n </div>\\n </div>\\n <h3 class=\"bold-image-promo__title\">Say what?</h3>\\n <p class=\"bold-image-promo__summary\">Is this the subject with the most baffling jargon?</p>\\n </a>\\n </div>\\n \\n \\n <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#3\">\\n <a href=\"/news/magazine-34920068\" class=\"bold-image-promo\">\\n <div class=\"bold-image-promo__image\">\\n <div class=\"responsive-image responsive-image--16by9\">\\n \\n <div class=\"js-delayed-image-load\" data-src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/FB8E/production/_86889346_promo1.jpg\" data-width=\"976\" data-height=\"549\" data-alt=\"Man standing near grave\"></div>\\n <!--[if lt IE 9]>\\n <img src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/FB8E/production/_86889346_promo1.jpg\" class=\"js-image-replace\" alt=\"Man standing near grave\" width=\"976\" height=\"549\" />\\n <![endif]-->\\n </div>\\n </div>\\n <h3 class=\"bold-image-promo__title\">The other crisis</h3>\\n <p class=\"bold-image-promo__summary\">Why Greeks are exhuming their parents\\' bodies</p>\\n </a>\\n </div>\\n \\n \\n <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#4\">\\n <a href=\"/news/world-europe-34931467\" class=\"bold-image-promo\">\\n <div class=\"bold-image-promo__image\">\\n <div class=\"responsive-image responsive-image--16by9\">\\n \\n <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/DC63/production/_86891465_26nov_isis-raqqa_ap.jpg\" data-width=\"976\" data-height=\"549\" data-alt=\"Islamic State militants hold up their weapons and wave flags as they ride in a convoy which includes multiple Toyota pickup trucks through Raqqa city in Syria\"></div>\\n <!--[if lt IE 9]>\\n <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/DC63/production/_86891465_26nov_isis-raqqa_ap.jpg\" class=\"js-image-replace\" alt=\"Islamic State militants hold up their weapons and wave flags as they ride in a convoy which includes multiple Toyota pickup trucks through Raqqa city in Syria\" width=\"976\" height=\"549\" />\\n <![endif]-->\\n </div>\\n </div>\\n <h3 class=\"bold-image-promo__title\">Spiral of violence </h3>\\n <p class=\"bold-image-promo__summary\">Death toll from jihadist groups continues to rise</p>\\n </a>\\n </div>\\n \\n \\n <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#5\">\\n <a href=\"/news/world-africa-34924351\" class=\"bold-image-promo\">\\n <div class=\"bold-image-promo__image\">\\n <div class=\"responsive-image responsive-image--16by9\">\\n \\n <div class=\"js-delayed-image-load\" data-src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/9053/production/_86874963_kobeindex.jpg\" data-width=\"976\" data-height=\"549\" data-alt=\"Kobina Graham\"></div>\\n <!--[if lt IE 9]>\\n <img src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/9053/production/_86874963_kobeindex.jpg\" class=\"js-image-replace\" alt=\"Kobina Graham\" width=\"976\" height=\"549\" />\\n <![endif]-->\\n </div>\\n </div>\\n <h3 class=\"bold-image-promo__title\">Back to Africa</h3>\\n <p class=\"bold-image-promo__summary\">Young professionals leave London and head to Ghana</p>\\n </a>\\n </div>\\n \\n \\n <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#6\">\\n <a href=\"/news/blogs-trending-34922821\" class=\"bold-image-promo\">\\n <div class=\"bold-image-promo__image\">\\n <div class=\"responsive-image responsive-image--16by9\">\\n \\n <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/39D8/production/_86880841_turkey.jpg\" data-width=\"2048\" data-height=\"1152\" data-alt=\"Turkey float at Thanksgiving parade in New York City\"></div>\\n <!--[if lt IE 9]>\\n <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/39D8/production/_86880841_turkey.jpg\" class=\"js-image-replace\" alt=\"Turkey float at Thanksgiving parade in New York City\" width=\"2048\" height=\"1152\" />\\n <![endif]-->\\n </div>\\n </div>\\n <h3 class=\"bold-image-promo__title\">Thanksgiving humour</h3>\\n <p class=\"bold-image-promo__summary\">How black white Mexican Jewish Asian and other families celebrate</p>\\n </a>\\n </div>\\n \\n \\n <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#7\">\\n <a href=\"/news/business-34897955\" class=\"bold-image-promo\">\\n <div class=\"bold-image-promo__image\">\\n <div class=\"responsive-image responsive-image--16by9\">\\n \\n <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/1104/production/_86865340_img_3525.jpg\" data-width=\"2048\" data-height=\"1152\" data-alt=\"An image from a Prison Art t-shirt\"></div>\\n <!--[if lt IE 9]>\\n <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/1104/production/_86865340_img_3525.jpg\" class=\"js-image-replace\" alt=\"An image from a Prison Art t-shirt\" width=\"2048\" height=\"1152\" />\\n <![endif]-->\\n </div>\\n </div>\\n <h3 class=\"bold-image-promo__title\">Firms behind bars</h3>\\n <p class=\"bold-image-promo__summary\">The businesses offering hope to Mexican prisoners</p>\\n </a>\\n </div>\\n \\n \\n <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#8\">\\n <a href=\"/news/world-asia-34837187\" class=\"bold-image-promo\">\\n <div class=\"bold-image-promo__image\">\\n <div class=\"responsive-image responsive-image--16by9\">\\n \\n <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/14013/production/_86793918_img_4098.jpg\" data-width=\"976\" data-height=\"549\" data-alt=\"There\\'s still a front line near Kunduz with some districts and villages controlled by the Taliban\"></div>\\n <!--[if lt IE 9]>\\n <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/14013/production/_86793918_img_4098.jpg\" class=\"js-image-replace\" alt=\"There\\'s still a front line near Kunduz with some districts and villages controlled by the Taliban\" width=\"976\" height=\"549\" />\\n <![endif]-->\\n </div>\\n </div>\\n <h3 class=\"bold-image-promo__title\">After the Taliban</h3>\\n <p class=\"bold-image-promo__summary\">Kunduz a city still scarred and in shock</p>\\n </a>\\n </div>\\n \\n \\n <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#9\">\\n <a href=\"/news/entertainment-arts-34811138\" class=\"bold-image-promo\">\\n <div class=\"bold-image-promo__image\">\\n <div class=\"responsive-image responsive-image--16by9\">\\n \\n <div class=\"js-delayed-image-load\" data-src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/18125/production/_86679589_bridge-of-spies-rylance-ap.jpg\" data-width=\"2048\" data-height=\"1152\" data-alt=\"Mark Rylance\"></div>\\n <!--[if lt IE 9]>\\n <img src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/18125/production/_86679589_bridge-of-spies-rylance-ap.jpg\" class=\"js-image-replace\" alt=\"Mark Rylance\" width=\"2048\" height=\"1152\" />\\n <![endif]-->\\n </div>\\n </div>\\n <h3 class=\"bold-image-promo__title\">From spy to BFG</h3>\\n <p class=\"bold-image-promo__summary\">Mark Rylance on the biggest film roles of his career</p>\\n </a>\\n </div>\\n \\n </div>\\n</div>\\n \\n<div id=\"bbccom_native_1_2_3_4\" class=\"bbccom_slot native-ad\" >\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'native\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n <div id=comp-most-popular\\n class=\"hidden\"\\n data-comp-meta=\"{&quot;id&quot;:&quot;comp-most-popular&quot; &quot;type&quot;:&quot;most-popular&quot; &quot;handler&quot;:&quot;mostPopular&quot; &quot;deviceGroups&quot;:null &quot;opts&quot;:{&quot;loading_strategy&quot;:&quot;post_load&quot; &quot;position_info&quot;:{&quot;instanceNo&quot;:1 &quot;positionInRegion&quot;:4 &quot;lastInRegion&quot;:true &quot;lastOnPage&quot;:true &quot;column&quot;:&quot;secondary_column&quot;}}}\">\\n </div> \\n<div id=\"bbccom_mpu_bottom_1_2_3_4\" class=\"bbccom_slot mpu-bottom-ad\" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'mpu_bottom\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n<div id=\"bbccom_outbrain_ar_9_1_2_3_4\" class=\"bbccom_slot outbrain-ad\" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'outbrain_ar_9\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n<div id=\"bbccom_adsense_1_2_3_4\" class=\"bbccom_slot adsense-ad\" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'adsense\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n<div id=\"bbccom_inread_1_2_3_4\" class=\"bbccom_slot inread\" aria-hidden=\"true\">\\n <div class=\"bbccom_advert\">\\n <script type=\"text/javascript\">\\n /*<![CDATA[*/\\n (function() {\\n if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\\n bbcdotcom.adverts.slotAsync(\\'inread\\' [1 2 3 4]);\\n }\\n })();\\n /*]]>*/\\n </script>\\n </div>\\n</div>\\n </div>\\n </div> </div> </div> </div> \\n \\n<div id=\"core-navigation\" class=\"navigation--footer\">\\n <h2 class=\"navigation--footer__heading\">News navigation</h2>\\n \\n <nav id=\"navigation--bottom\" class=\"navigation navigation--bottom \" role=\"navigation\" aria-label=\"News\">\\n <span class=\"navigation-core-title\">Sections</span>\\n <ul class=\"navigation--bottom__toplevel\">\\n <li class=\"\">\\n <a href=\"/news\" class=\"\">\\n <span>Home</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/video_and_audio/international\" class=\"\">\\n <span>Video</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/world\" data-panel-id=\"js-navigation-panel-World\" class=\"navigation-arrow\">\\n <span>World</span>\\n </a>\\n <div class=\"navigation-panel navigation-panel--closed js-navigation-panel-World\">\\n <div class=\"navigation-panel__content\">\\n <ul class=\"navigation-panel-secondary\">\\n <li><a href=\"/news/world\"><span>World Home</span></a></li>\\n <li>\\n <a href=\"/news/world/africa\"><span>Africa</span></a> </li>\\n <li>\\n <a href=\"/news/world/asia\"><span>Asia</span></a> </li>\\n <li>\\n <a href=\"/news/world/australia\"><span>Australia</span></a> </li>\\n <li>\\n <a href=\"/news/world/europe\"><span>Europe</span></a> </li>\\n <li>\\n <a href=\"/news/world/latin_america\"><span>Latin America</span></a> </li>\\n <li>\\n <a href=\"/news/world/middle_east\"><span>Middle East</span></a> </li>\\n <li>\\n <a href=\"/news/world/us_and_canada\"><span>US &amp; Canada</span></a> </li>\\n </ul>\\n </div>\\n </div>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/uk\" data-panel-id=\"js-navigation-panel-UK\" class=\"navigation-arrow\">\\n <span>UK</span>\\n </a>\\n <div class=\"navigation-panel navigation-panel--closed js-navigation-panel-UK\">\\n <div class=\"navigation-panel__content\">\\n <ul class=\"navigation-panel-secondary\">\\n <li><a href=\"/news/uk\"><span>UK Home</span></a></li>\\n <li>\\n <a href=\"/news/england\"><span>England</span></a> </li>\\n <li>\\n <a href=\"/news/northern_ireland\"><span>N. Ireland</span></a> </li>\\n <li>\\n <a href=\"/news/scotland\"><span>Scotland</span></a> </li>\\n <li>\\n <a href=\"/news/wales\"><span>Wales</span></a> </li>\\n <li>\\n <a href=\"/news/politics\"><span>Politics</span></a> </li>\\n </ul>\\n </div>\\n </div>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/business\" data-panel-id=\"js-navigation-panel-Business\" class=\"navigation-arrow\">\\n <span>Business</span>\\n </a>\\n <div class=\"navigation-panel navigation-panel--closed js-navigation-panel-Business\">\\n <div class=\"navigation-panel__content\">\\n <ul class=\"navigation-panel-secondary\">\\n <li><a href=\"/news/business\"><span>Business Home</span></a></li>\\n <li>\\n <a href=\"http://www.bbc.co.uk/news/business/market_data\"><span>Market Data</span></a> </li>\\n <li>\\n <a href=\"/news/business/markets\"><span>Markets</span></a> </li>\\n <li>\\n <a href=\"/news/business/economy\"><span>Economy</span></a> </li>\\n <li>\\n <a href=\"/news/business/companies\"><span>Companies</span></a> </li>\\n <li>\\n <a href=\"/news/business-22434141\"><span>Entrepreneurship</span></a> </li>\\n <li>\\n <a href=\"/news/business-11428889\"><span>Technology of Business</span></a> </li>\\n <li>\\n <a href=\"/news/business/business_of_sport\"><span>Business of Sport</span></a> </li>\\n <li>\\n <a href=\"/news/business-12686570\"><span>Knowledge economy</span></a> </li>\\n </ul>\\n </div>\\n </div>\\n </li>\\n <li class=\"selected \">\\n <a href=\"/news/technology\" class=\"navigation-arrow--open\">\\n <span>Tech</span>\\n </a>\\n <span class=\"off-screen\">selected</span> </li>\\n <li class=\"\">\\n <a href=\"/news/science_and_environment\" class=\"\">\\n <span>Science</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/magazine\" class=\"\">\\n <span>Magazine</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/entertainment_and_arts\" class=\"\">\\n <span>Entertainment &amp; Arts</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/health\" class=\"\">\\n <span>Health</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/in_pictures\" class=\"\">\\n <span>In Pictures</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/also_in_the_news\" class=\"\">\\n <span>Also in the News</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/special_reports\" class=\"\">\\n <span>Special Reports</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/explainers\" class=\"\">\\n <span>Explainers</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/the_reporters\" class=\"\">\\n <span>The Reporters</span>\\n </a>\\n </li>\\n <li class=\"\">\\n <a href=\"/news/have_your_say\" class=\"\">\\n <span>Have Your Say</span>\\n </a>\\n </li>\\n </ul>\\n </nav>\\n</div>\\n <div id=\"services-bar\" class=\"blue-tit\" role=\"navigation\" aria-label=\"BBC News Services\">\\n <div class=\"blue-tit__inner\">\\n <h2 class=\"blue-tit__title\">BBC News Services</h2>\\n <ul class=\"blue-tit__list\">\\n <li class=\"blue-tit__list-item\">\\n <a href=\"http://www.bbc.co.uk/news/10628994\" class=\"blue-tit__list-item-link mobile\">On your mobile</a>\\n </li>\\n <li class=\"blue-tit__list-item\">\\n <a href=\"http://www.bbc.co.uk/news/help-17655000\" class=\"blue-tit__list-item-link connected-tv\">On your connected TV</a>\\n </li>\\n <li class=\"blue-tit__list-item\">\\n <a href=\"http://www.bbc.co.uk/news/10628323\" class=\"blue-tit__list-item-link newsletter\">Get news alerts</a>\\n </li>\\n <li class=\"blue-tit__list-item\">\\n <a href=\"http://www.bbc.co.uk/news/20039682\" class=\"blue-tit__list-item-link contact-us\">Contact BBC News</a>\\n </li>\\n </ul>\\n </div>\\n</div>\\n </div><!-- closes #site-container --> </div> <div id=\"orb-footer\" class=\"orb-footer orb-footer-grey b-footer--grey--white\" > <div id=\"navp-orb-footer-promo\" class=\"orb-footer-grey\"></div> <aside role=\"complementary\"> <div id=\"orb-aside\" class=\"orb-nav-sec b-r b-g-p\"> <div class=\"orb-footer-inner\" role=\"navigation\"> <h2 class=\"orb-footer-lead\">Explore the BBC</h2> <div class=\"orb-footer-primary-links\"> <ul> <li class=\"orb-nav-news orb-d\" > <a href=\"http://www.bbc.co.uk/news/\">News</a> </li> <li class=\"orb-nav-newsdotcom orb-w\" > <a href=\"http://www.bbc.com/news/\">News</a> </li> <li class=\"orb-nav-sport\" > <a href=\"/sport/\">Sport</a> </li> <li class=\"orb-nav-weather\" > <a href=\"/weather/\">Weather</a> </li> <li class=\"orb-nav-shop orb-w\" > <a href=\"http://shop.bbc.com/\">Shop</a> </li> <li class=\"orb-nav-earthdotcom orb-w\" > <a href=\"http://www.bbc.com/earth/\">Earth</a> </li> <li class=\"orb-nav-travel-dotcom orb-w\" > <a href=\"http://www.bbc.com/travel/\">Travel</a> </li> <li class=\"orb-nav-capital orb-w\" > <a href=\"http://www.bbc.com/capital/\">Capital</a> </li> <li class=\"orb-nav-iplayer orb-d\" > <a href=\"/iplayer/\">iPlayer</a> </li> <li class=\"orb-nav-culture orb-w\" > <a href=\"http://www.bbc.com/culture/\">Culture</a> </li> <li class=\"orb-nav-autos orb-w\" > <a href=\"http://www.bbc.com/autos/\">Autos</a> </li> <li class=\"orb-nav-future orb-w\" > <a href=\"http://www.bbc.com/future/\">Future</a> </li> <li class=\"orb-nav-tv\" > <a href=\"/tv/\">TV</a> </li> <li class=\"orb-nav-radio\" > <a href=\"/radio/\">Radio</a> </li> <li class=\"orb-nav-cbbc\" > <a href=\"/cbbc\">CBBC</a> </li> <li class=\"orb-nav-cbeebies\" > <a href=\"/cbeebies\">CBeebies</a> </li> <li class=\"orb-nav-food\" > <a href=\"/food/\">Food</a> </li> <li class=\"orb-nav-arts orb-d\" > <a href=\"/arts/\">Arts</a> </li> <li class=\"orb-nav-makeitdigital\" > <a href=\"/makeitdigital\">Make It Digital</a> </li> <li > <a href=\"/iwonder\">iWonder</a> </li> <li > <a href=\"/education\">Bitesize</a> </li> <li class=\"orb-nav-music\" > <a href=\"/music/\">Music</a> </li> <li class=\"orb-nav-nature orb-w\" > <a href=\"/nature/\">Nature</a> </li> <li class=\"orb-nav-earth orb-d\" > <a href=\"http://www.bbc.com/earth/\">Earth</a> </li> <li class=\"orb-nav-local\" > <a href=\"/local/\">Local</a> </li> <li class=\"orb-nav-travel orb-d\" > <a href=\"/travel/\">Travel</a> </li> </ul> </div> </div> </div> </aside> <footer role=\"contentinfo\"> <div id=\"orb-contentinfo\" class=\"orb-nav-sec b-r b-g-p\"> <div class=\"orb-footer-inner\"> <ul> <li > <a href=\"/terms/\">Terms of Use</a> </li> <li > <a href=\"/aboutthebbc/\">About the BBC</a> </li> <li > <a href=\"/privacy/\">Privacy Policy</a> </li> <li > <a href=\"/privacy/cookies/about\">Cookies</a> </li> <li > <a href=\"/accessibility/\">Accessibility Help</a> </li> <li > <a href=\"/guidance/\">Parental Guidance</a> </li> <li > <a href=\"/contact/\">Contact the BBC</a> </li> <li class=\" orb-w\" > <a href=\"http://advertising.bbcworldwide.com/\">Advertise with us</a> </li> <li class=\" orb-w\" > <a href=\"/privacy/cookies/international/\">Ad choices</a> </li> </ul> <small> <span class=\"orb-hilight\">Copyright &copy; 2015 BBC.</span> The BBC is not responsible for the content of external sites. <a href=\"/help/web/links/\" class=\"orb-hilight\">Read about our approach to external linking.</a> </small> </div> </div> </footer> </div> <!-- BBCDOTCOM bodyLast --><div class=\"bbccom_display_none\"><script type=\"text/javascript\"> /*<![CDATA[*/ if (window.bbcdotcom && window.bbcdotcom.analytics) { bbcdotcom.analytics.page(); } if (window.bbcdotcom && bbcdotcom.currencyProviders) { bbcdotcom.currencyProviders.write(); } /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ if (window.bbcdotcom && bbcdotcom.currencyProviders) { bbcdotcom.currencyProviders.postWrite(); } /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ /** * ASNYC waits to make any gpt requests until the bottom of the page */ (function() { var gads = document.createElement(\\'script\\'); gads.async = true; gads.type = \\'text/javascript\\'; var useSSL = \\'https:\\' == document.location.protocol; gads.src = (useSSL ? \\'https:\\' : \\'http:\\') + \\'//www.googletagservices.com/tag/js/gpt.js\\'; var node = document.getElementsByTagName(\\'script\\')[0]; node.parentNode.insertBefore(gads node); })(); /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ if (window.bbcdotcom && bbcdotcom.data && bbcdotcom.data.stats && bbcdotcom.data.stats === 1 && bbcdotcom.utils && window.location.pathname === \\'/\\' && window.bbccookies && bbccookies.readPolicy(\\'performance\\') ) { var wwhpEdition = bbcdotcom.utils.getMetaPropertyContent(\\'wwhp-edition\\'); var _sf_async_config={}; /** CONFIGURATION START **/ _sf_async_config.uid = 50924; _sf_async_config.domain = \"bbc.co.uk\"; _sf_async_config.title = \"Homepage\"+(wwhpEdition !== \\'\\' ? \\' - \\'+wwhpEdition : \\'\\'); _sf_async_config.sections = \"Homepage\"+(wwhpEdition !== \\'\\' ? \\' Homepage - \\'+wwhpEdition : \\'\\'); _sf_async_config.region = wwhpEdition; _sf_async_config.path = \"/\"+(wwhpEdition !== \\'\\' ? \\'?\\'+wwhpEdition : \\'\\'); /** CONFIGURATION END **/ (function(){ function loadChartbeat() { window._sf_endpt=(new Date()).getTime(); var e = document.createElement(\"script\"); e.setAttribute(\"language\" \"javascript\"); e.setAttribute(\"type\" \"text/javascript\"); e.setAttribute(\\'src\\' \\'//static.chartbeat.com/js/chartbeat.js\\'); document.body.appendChild(e); } var oldonload = window.onload; window.onload = (typeof window.onload != \"function\") ? loadChartbeat : function() { oldonload(); loadChartbeat(); }; })(); } /*]]>*/ </script></div> <!-- BBCDOTCOM all code in page --> <script type=\"text/javascript\"> document.write(\\'<\\' + \\'script id=\"orb-js-script\" data-assetpath=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/\" src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/script/orb.min.js\"><\\' + \\'/script>\\'); </script> <script type=\"text/javascript\"> (function() {\\n \\'use strict\\';\\n var promoManager = {\\n url: \\'\\' \\n promoLoaded: false \\n makeUrl: function (theme site win) {\\n var loc = win? win.location : window.location \\n proto = loc.protocol \\n host = loc.host \\n url = proto + \\'//\\' + ((proto.match(/s:/i) && !host.match(/^www\\\\.(int|test)\\\\./i))? \\'ssl.\\' : \\'www.\\') \\n themes = [\\'light\\' \\'dark\\'];\\n if ( host.match(/^(?:www|ssl|m)\\\\.(int|test|stage|live)\\\\.bbc\\\\./i) ) {\\n url += RegExp.$1 + \\'.\\';\\n }\\n else if ( host.match(/^pal\\\\.sandbox\\\\./i) ) {\\n url += \\'test.\\';\\n }\\n theme = themes[ +(theme === themes[0]) ];\\n \\n return url + \\'bbc.co.uk/navpromo/card/\\' + site + \\'/\\' + theme;\\n } \\n init: function(node) {\\n var disabledByCookie = (document.cookie.indexOf(\\'ckns_orb_nopromo=1\\') > -1) \\n that = this;\\n \\n if (window.promomanagerOverride) {\\n for (var p in promomanagerOverride) {\\n that[p] = promomanagerOverride[p];\\n }\\n }\\n \\n if ( window.orb.fig(\\'uk\\') && !disabledByCookie ) {\\n require([\\'orb/async/_footerpromo\\' \\'istats-1\\'] function(promo istats) {\\n var virtualSite = istats.getSite() || \\'default\\';\\n that.url = (window.promomanagerOverride || that).makeUrl(\\'light\\' virtualSite);\\n if (that.url) { \\n promo.load(that.url node {\\n onSuccess: function(e) {\\n if(e.status === \\'success\\') {\\n node.parentNode.className = node.parentNode.className + \\' orb-footer-promo-loaded\\';\\n promoManager.promoLoaded = true;\\n promoManager.event(\\'promo-loaded\\').fire(e);\\n }\\n } \\n onError: function() {\\n istats.log(\\'error\\' \\'orb-footer-promo-failed\\');\\n bbccookies.set(\\'ckns_orb_nopromo=1; expires=\\' + new Date(new Date().getTime() + 1000 * 60 * 10).toGMTString() + \\';path=/;\\');\\n }\\n }); \\n }\\n });\\n }\\n }\\n };\\n \\n \\n define(\\'orb/promomanager\\' [\\'orb/lib/_event\\'] function (event) {\\n event.mixin(promoManager);\\n return promoManager;\\n });\\n \\n require([\\'orb/promomanager\\'] function (promoManager) {\\n promoManager.init(document.getElementById(\\'navp-orb-footer-promo\\'));\\n })\\n})();\\n </script> <script type=\"text/javascript\"> if (typeof require !== \\'undefined\\') { require([\\'istats-1\\'] function(istats){ istats.track(\\'external\\' { region: document.getElementsByTagName(\\'body\\')[0] }); istats.track(\\'download\\' { region: document.getElementsByTagName(\\'body\\')[0] }); }); } </script> <img alt=\"\" id=\"livestats\" src=\"http://stats.bbc.co.uk/o.gif?~RS~s~RS~News~RS~t~RS~HighWeb_Story~RS~i~RS~26415021~RS~p~RS~99113~RS~a~RS~International~RS~u~RS~/news/technology-26415021~RS~r~RS~0~RS~q~RS~0~RS~z~RS~6705~RS~\"> <script> window.old_onload = window.onload; window.onload = function() { if(window.old_onload) { window.old_onload(); } window.loaded = true; }; </script> <!-- Chartbeat Web Analytics code - start -->\\n<script type=\"text/javascript\">\\n var _sf_async_config={};\\n /** CONFIGURATION START **/\\n _sf_async_config.uid = \"50924\";\\n _sf_async_config.domain = \"www.bbc.co.uk\";\\n _sf_async_config.sections = \"News News - technology News - STY News - technology - STY\";\\n <!-- if page is an index add the edition to the path -->\\n _sf_async_config.path = \"bbc.co.uk/news/technology-26415021\";\\n (function() {\\n var noCookies = true;\\n var cookiePrefix = \\'_chartbeat\\';\\n if (\"object\" === typeof bbccookies && typeof bbccookies.readPolicy == \\'function\\') {\\n noCookies = !bbccookies.readPolicy().performance;\\n }\\n if (noCookies && document.cookie.indexOf(cookiePrefix) !== -1) {\\n //Find and remove cookies whose names begin with \\'_chartbeat\\'\\n var cookieSplit = document.cookie.split(\\';\\');\\n var cookieLength = cookieSplit.length;\\n while (cookieLength--) {\\n var cookie = cookieSplit[cookieLength].replace(/^\\\\s+|\\\\s+$/g \\'\\');\\n var cookieName = cookie.split(\\'=\\')[0];\\n if (cookieName.indexOf(cookiePrefix) === 0) {\\n document.cookie = cookieName + \\'=; expires=Thu 01 Jan 1970 00:00:00 GMT; path=/;\\';\\n }\\n }\\n }\\n _sf_async_config.noCookies = noCookies;\\n }());\\n /** CONFIGURATION END **/\\n (function(){\\n function loadChartbeat() {\\n window._sf_endpt=(new Date()).getTime();\\n var e = document.createElement(\"script\");\\n e.setAttribute(\"language\" \"javascript\");\\n e.setAttribute(\"type\" \"text/javascript\");\\n e.setAttribute(\\'src\\' \\'//static.chartbeat.com/js/chartbeat.js\\');\\n document.body.appendChild(e);\\n }\\n var oldonload = window.onload;\\n window.onload = (typeof window.onload != \"function\") ?\\n loadChartbeat : function() { oldonload(); loadChartbeat(); };\\n }());\\n</script>\\n<!-- Chartbeat Web Analytics code - end -->\\n <!-- mpulse start -->\\n<script>\\n(function(){\\n window.bbcnewsperformance = {};\\n var perf = window.performance;\\n function firstScrollTimer() {\\n document.removeEventListener(\\'scroll\\' firstScrollTimer);\\n perf.mark(\\'firstScroll\\');\\n perf.measure(\\'scrolltime\\' \\'firstScroll\\');\\n var timing = perf.getEntriesByName(\\'scrolltime\\');\\n bbcnewsperformance.firstScrollTime = timing[0].startTime;\\n }\\n function primaryImageTimer(src) {\\n var timing = perf.getEntriesByName(src);\\n bbcnewsperformance.primaryImageTime = timing[0].responseEnd;\\n }\\n if (perf) {\\n if (perf.mark && perf.measure) {\\n document.addEventListener(\\'scroll\\' firstScrollTimer);\\n }\\n if (perf.getEntriesByName) {\\n var primaryImage = document.querySelector(\\'.story-body__inner img\\');\\n if (primaryImage) {\\n var src = primaryImage.getAttribute(\\'src\\');\\n primaryImage.addEventListener(\\'load\\' primaryImageTimer.bind(this src));\\n }\\n }\\n }\\n var random = Math.random();\\n var rate = 1;\\n if (rate && (random < rate)) {\\n var accountId = \"X5H9R-GT47V-WJULQ-CWND4-S7WY8\";\\n // mpulse vendor code\\n if(window.BOOMR && window.BOOMR.version){return;}\\n var dom doc where iframe = document.createElement(\\'iframe\\');\\n iframe.src = \"javascript:false\";\\n iframe.title = \"\"; iframe.role=\"presentation\";\\n (iframe.frameElement || iframe).style.cssText = \"width:0;height:0;border:0;display:none;\";\\n where = document.getElementsByTagName(\\'script\\')[0];\\n where.parentNode.insertBefore(iframe where);\\n try {\\n doc = iframe.contentWindow.document;\\n } catch(e) {\\n dom = document.domain;\\n iframe.src=\"javascript:var d=document.open();d.domain=\\'\"+dom+\"\\';void(0);\";\\n doc = iframe.contentWindow.document;\\n }\\n doc.open()._l = function() {\\n var js = this.createElement(\"script\");\\n if(dom) this.domain = dom;\\n js.id = \"boomr-if-as\";\\n js.src = \\'//c.go-mpulse.net/boomerang/\\' +\\n accountId;\\n BOOMR_lstart=new Date().getTime();\\n this.body.appendChild(js);\\n };\\n doc.write(\\'<body onload=\"document._l();\">\\');\\n doc.close();\\n // mpulse vendor code - end\\n }\\n})();\\n</script>\\n<!-- mpulse end -->\\n </body> </html> \\n'"
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "html"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "This is becoming a mess, let us get line breaks back:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "<!DOCTYPE html>\n",
      "<html lang=\"en\" id=\"responsive-news\" prefix=\"og: http://ogp.me/ns#\">\n",
      "<head >\n",
      " <meta charset=\"utf-8\">\n",
      " <meta http-equiv=\"X-UA-Compatible\" content=\"IE=edge chrome=1\">\n",
      " <title>An hour to catch the coding bug - BBC News</title>\n",
      " <meta name=\"description\" content=\"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\">\n",
      " <link rel=\"dns-prefetch\" href=\"https://ssl.bbc.co.uk/\">\n",
      " <link rel=\"dns-prefetch\" href=\"http://sa.bbc.co.uk/\">\n",
      " <link rel=\"dns-prefetch\" href=\"http://ichef-1.bbci.co.uk/\">\n",
      " <link rel=\"dns-prefetch\" href=\"http://ichef.bbci.co.uk/\">\n",
      " <meta name=\"x-country\" content=\"il\">\n",
      " <meta name=\"x-audience\" content=\"International\">\n",
      " <meta name=\"CPS_AUDIENCE\" content=\"International\">\n",
      " <meta name=\"CPS_CHANGEQUEUEID\" content=\"\">\n",
      " <link rel=\"canonical\" href=\"http://www.bbc.com/news/technology-26415021\">\n",
      " <link rel=\"alternate\" hreflang=\"en-gb\" href=\"http://www.bbc.co.uk/news/technology-26415021\">\n",
      " <link rel=\"alternate\" hreflang=\"en\" href=\"http://www.bbc.com/news/technology-26415021\">\n",
      " <meta property=\"og:title\" content=\"An hour to catch the coding bug - BBC News\" />\n",
      " <meta property=\"og:type\" content=\"article\" />\n",
      " <meta property=\"og:description\" content=\"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\" />\n",
      " <meta property=\"og:site_name\" content=\"BBC News\" />\n",
      " <meta property=\"og:locale\" content=\"en_GB\" />\n",
      " <meta property=\"og:article:author\" content=\"BBC News\" />\n",
      " <meta property=\"og:article:section\" content=\"Technology\" />\n",
      " <meta property=\"og:url\" content=\"http://www.bbc.com/news/technology-26415021\" />\n",
      " <meta property=\"og:image\" content=\"http://ichef-1.bbci.co.uk/news/1024/media/images/73325000/jpg/_73325451_hourofcode.jpg\" />\n",
      " <meta name=\"twitter:card\" content=\"summary_large_image\">\n",
      " <meta name=\"twitter:site\" content=\"@BBCWorld\">\n",
      " <meta name=\"twitter:title\" content=\"An hour to catch the coding bug - BBC News\">\n",
      " <meta name=\"twitter:description\" content=\"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\">\n",
      " <meta name=\"twitter:creator\" content=\"@BBCWorld\">\n",
      " <meta name=\"twitter:image:src\" content=\"http://ichef-1.bbci.co.uk/news/560/media/images/73325000/jpg/_73325451_hourofcode.jpg\">\n",
      " <meta name=\"twitter:domain\" content=\"www.bbc.com\">\n",
      " <script type=\"application/ld+json\">\n",
      " {\n",
      " \"@context\": \"http://schema.org\"\n",
      " \"@type\": \"Article\"\n",
      " \n",
      " \"url\": \"http://www.bbc.com/news/technology-26415021\"\n",
      " \"publisher\": {\n",
      " \"@type\": \"Organization\" \n",
      " \"name\": \"BBC News\" \n",
      " \"logo\": \"http://www.bbc.co.uk/news/special/2015/newsspec_10857/bbc_news_logo.png?cb=1\"\n",
      " }\n",
      " \n",
      " \"headline\": \"An hour to catch the coding bug\"\n",
      " \"author\": \"Mark Ward\"\n",
      " \"mainEntityOfPage\": \"http://www.bbc.com/news/technology-26415021\"\n",
      " \"articleBody\": \"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\"\n",
      " \n",
      " \"image\": {\n",
      " \"@list\": [\n",
      " \"http://ichef-1.bbci.co.uk/news/560/media/images/73325000/jpg/_73325163_olly009.jpg\"\n",
      " \"http://ichef.bbci.co.uk/news/560/media/images/73325000/jpg/_73325167_hourofcode.jpg\"\n",
      " \"http://ichef.bbci.co.uk/news/560/media/images/73325000/jpg/_73325169_appinventor.jpg\"\n",
      " ]\n",
      " }\n",
      " \"datePublished\": \"2014-03-03T10:22:55+00:00\"\n",
      " }\n",
      " </script>\n",
      " \n",
      " \n",
      " <meta name=\"apple-mobile-web-app-title\" content=\"BBC News\">\n",
      " <link rel=\"apple-touch-icon-precomposed\" sizes=\"57x57\" href=\"http://static.bbci.co.uk/news/1.99.0479/apple-touch-icon-57x57-precomposed.png\">\n",
      " <link rel=\"apple-touch-icon-precomposed\" sizes=\"72x72\" href=\"http://static.bbci.co.uk/news/1.99.0479/apple-touch-icon-72x72-precomposed.png\">\n",
      " <link rel=\"apple-touch-icon-precomposed\" sizes=\"114x114\" href=\"http://static.bbci.co.uk/news/1.99.0479/apple-touch-icon-114x114-precomposed.png\">\n",
      " <link rel=\"apple-touch-icon-precomposed\" sizes=\"144x144\" href=\"http://static.bbci.co.uk/news/1.99.0479/apple-touch-icon.png\">\n",
      " <link rel=\"apple-touch-icon\" href=\"http://static.bbci.co.uk/news/1.99.0479/apple-touch-icon.png\">\n",
      " <meta name=\"application-name\" content=\"BBC News\">\n",
      " <meta name=\"msapplication-TileImage\" content=\"http://static.bbci.co.uk/news/1.99.0479/windows-eight-icon-144x144.png\">\n",
      " <meta name=\"msapplication-TileColor\" content=\"#bb1919\">\n",
      " <meta http-equiv=\"cleartype\" content=\"on\">\n",
      " <meta name=\"mobile-web-app-capable\" content=\"yes\">\n",
      " <meta name=\"robots\" content=\"NOODP NOYDIR\" />\n",
      " <meta name=\"theme-color\" content=\"#bb1919\">\n",
      " <script type=\"text/javascript\">var _sf_startpt=(new Date()).getTime()</script>\n",
      " <script>\n",
      " (function() {\n",
      " if (navigator.userAgent.match(/IEMobile\\/10\\.0/)) {\n",
      " var msViewportStyle = document.createElement(\"style\");\n",
      " msViewportStyle.appendChild(\n",
      " document.createTextNode(\"@-ms-viewport{width:auto!important}\")\n",
      " );\n",
      " document.getElementsByTagName(\"head\")[0].appendChild(msViewportStyle);\n",
      " }\n",
      " })();\n",
      " </script>\n",
      " \n",
      " <script>window.fig = window.fig || {}; window.fig.async = true;</script>\n",
      " <meta name=\"viewport\" content=\"width=device-width initial-scale=1.0\" /> <meta property=\"fb:admins\" content=\"100004154058350\" /> <script type=\"text/javascript\">window.bbcredirection={geo:true}</script> <!--orb.ws.require.lib--> <script type=\"text/javascript\">/*<![CDATA[*/ if (typeof window.define !== 'function' || typeof window.require !== 'function') { document.write('<script class=\"js-require-lib\" src=\"http://static.bbci.co.uk/frameworks/requirejs/lib.js\"><'+'/script>'); } /*]]>*/</script> <script type=\"text/javascript\"> bbcRequireMap = {\"jquery-1\":\"http://static.bbci.co.uk/frameworks/jquery/0.3.0/sharedmodules/jquery-1.7.2\" \"jquery-1.4\":\"http://static.bbci.co.uk/frameworks/jquery/0.3.0/sharedmodules/jquery-1.4\" \"jquery-1.9\":\"http://static.bbci.co.uk/frameworks/jquery/0.3.0/sharedmodules/jquery-1.9.1\" \"swfobject-2\":\"http://static.bbci.co.uk/frameworks/swfobject/0.1.10/sharedmodules/swfobject-2\" \"demi-1\":\"http://static.bbci.co.uk/frameworks/demi/0.10.0/sharedmodules/demi-1\" \"gelui-1\":\"http://static.bbci.co.uk/frameworks/gelui/0.9.13/sharedmodules/gelui-1\" \"cssp!gelui-1/overlay\":\"http://static.bbci.co.uk/frameworks/gelui/0.9.13/sharedmodules/gelui-1/overlay.css\" \"istats-1\":\"http://static.bbci.co.uk/frameworks/istats/0.28.4/modules/istats-1\" \"relay-1\":\"http://static.bbci.co.uk/frameworks/relay/0.2.6/sharedmodules/relay-1\" \"clock-1\":\"http://static.bbci.co.uk/frameworks/clock/0.1.9/sharedmodules/clock-1\" \"canvas-clock-1\":\"http://static.bbci.co.uk/frameworks/clock/0.1.9/sharedmodules/canvas-clock-1\" \"cssp!clock-1\":\"http://static.bbci.co.uk/frameworks/clock/0.1.9/sharedmodules/clock-1.css\" \"jssignals-1\":\"http://static.bbci.co.uk/frameworks/jssignals/0.3.6/modules/jssignals-1\" \"jcarousel-1\":\"http://static.bbci.co.uk/frameworks/jcarousel/0.1.10/modules/jcarousel-1\" \"bump-3\":\"//emp.bbci.co.uk/emp/bump-3/bump-3\"}; require({ baseUrl: 'http://static.bbci.co.uk/' paths: bbcRequireMap waitSeconds: 30 }); </script> <script type=\"text/javascript\">/*<![CDATA[*/ if (typeof bbccookies_flag === 'undefined') { bbccookies_flag = 'ON'; } showCTA_flag = true; cta_enabled = (showCTA_flag && (bbccookies_flag === 'ON')); (function(){var e=\"ckns_policy\" m=\"Thu 01 Jan 1970 00:00:00 GMT\" k={ads:true personalisation:true performance:true necessary:true};function f(p){if(f.cache[p]){return f.cache[p]}var o=p.split(\"/\") q=[\"\"];do{q.unshift((o.join(\"/\")||\"/\"));o.pop()}while(q[0]!==\"/\");f.cache[p]=q;return q}f.cache={};function a(p){if(a.cache[p]){return a.cache[p]}var q=p.split(\".\") o=[];while(q.length&&\"|co.uk|com|\".indexOf(\"|\"+q.join(\".\")+\"|\")===-1){if(q.length){o.push(q.join(\".\"))}q.shift()}f.cache[p]=o;return o}a.cache={};function i(o t p){var z=[\"\"].concat(a(window.location.hostname)) w=f(window.location.pathname) y=\"\" r x;for(var s=0 v=z.length;s<v;s++){r=z[s];for(var q=0 u=w.length;q<u;q++){x=w[q];y=o+\"=\"+t+\";\"+(r?\"domain=\"+r+\";\":\"\")+(x?\"path=\"+x+\";\":\"\")+(p?\"expires=\"+p+\";\":\"\");bbccookies.set(y true)}}}window.bbccookies={POLICY_REFRESH_DATE_MILLIS:new Date(2015 4 21 0 0 0 0).getTime() POLICY_EXPIRY_COOKIENAME:\"ckns_policy_exp\" _setEverywhere:i cookiesEnabled:function(){var o=\"ckns_testcookie\"+Math.floor(Math.random()*100000);this.set(o+\"=1\");if(this.get().indexOf(o)>-1){g(o);return true}return false} set:function(o){return document.cookie=o} get:function(){return document.cookie} getCrumb:function(o){if(!o){return null}return decodeURIComponent(document.cookie.replace(new RegExp(\"(?:(?:^|.*;)\\\\s*\"+encodeURIComponent(o).replace(/[\\-\\.\\+\\*]/g \"\\\\$&\")+\"\\\\s*\\\\=\\\\s*([^;]*).*$)|^.*$\") \"$1\"))||null} policyRequiresRefresh:function(){var p=new Date();p.setHours(0);p.setMinutes(0);p.setSeconds(0);p.setMilliseconds(0);if(bbccookies.POLICY_REFRESH_DATE_MILLIS<=p.getTime()){var o=bbccookies.getCrumb(bbccookies.POLICY_EXPIRY_COOKIENAME);if(o){o=new Date(parseInt(o));o.setYear(o.getFullYear()-1);return bbccookies.POLICY_REFRESH_DATE_MILLIS>=o.getTime()}else{return true}}else{return false}} _setPolicy:function(o){return h.apply(this arguments)} readPolicy:function(){return b.apply(this arguments)} _deletePolicy:function(){i(e \"\" m)} isAllowed:function(){return true} _isConfirmed:function(){return c()!==null} _acceptsAll:function(){var o=b();return o&&!(j(o).indexOf(\"0\")>-1)} _getCookieName:function(){return d.apply(this arguments)} _showPrompt:function(){var o=((!this._isConfirmed()||this.policyRequiresRefresh())&&window.cta_enabled&&this.cookiesEnabled()&&!window.bbccookies_disable);return(window.orb&&window.orb.fig)?o&&(window.orb.fig(\"no\")||window.orb.fig(\"ck\")):o}};bbccookies._getPolicy=bbccookies.readPolicy;function d(p){var o=(\"\"+p).match(/^([^=]+)(?==)/);return(o&&o.length?o[0]:\"\")}function j(o){return\"\"+(o.ads?1:0)+(o.personalisation?1:0)+(o.performance?1:0)}function h(s){if(typeof s===\"undefined\"){s=k}if(typeof arguments[0]===\"string\"){var p=arguments[0] r=arguments[1];if(p===\"necessary\"){r=true}s=b();s[p]=r}else{if(typeof arguments[0]===\"object\"){s.necessary=true}}var q=new Date();q.setYear(q.getFullYear()+1);bbccookies.set(e+\"=\"+j(s)+\";domain=bbc.co.uk;path=/;expires=\"+q.toUTCString()+\";\");bbccookies.set(e+\"=\"+j(s)+\";domain=bbc.com;path=/;expires=\"+q.toUTCString()+\";\");var o=new Date(q.getTime());o.setMonth(o.getMonth()+1);bbccookies.set(bbccookies.POLICY_EXPIRY_COOKIENAME+\"=\"+q.getTime()+\";domain=bbc.co.uk;path=/;expires=\"+o.toUTCString()+\";\");bbccookies.set(bbccookies.POLICY_EXPIRY_COOKIENAME+\"=\"+q.getTime()+\";domain=bbc.com;path=/;expires=\"+o.toUTCString()+\";\");return s}function l(o){if(o===null){return null}var p=o.split(\"\");return{ads:!!+p[0] personalisation:!!+p[1] performance:!!+p[2] necessary:true}}function c(){var o=new RegExp(\"(?:^|; ?)\"+e+\"=(\\\\d\\\\d\\\\d)($|;)\") p=document.cookie.match(o);if(!p){return null}return p[1]}function b(o){var p=l(c());if(!p){p=k}if(o){return p[o]}else{return p}}function g(o){return document.cookie=o+\"=;expires=\"+m+\";\"}function n(){var o='<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/frameworks/bbccookies/0.6.15/script/bbccookies.js\"><\\/script>';if(window.bbccookies_flag===\"ON\"&&!bbccookies._acceptsAll()&&!window.bbccookies_disable){document.write(o)}}n()})(); /*]]>*/</script> <script type=\"text/javascript\">/*<![CDATA[*/\n",
      "(function(){window.fig=window.fig||{};window.fig.manager={include:function(a){a=a||window;var e=a.document g=e.cookie b=g.match(/(?:^|; ?)ckns_orb_fig=([^;]+)/);if(!b&&g.indexOf(\"ckns_orb_nofig=1\")>-1){this.setFig(a {no:1})}else{if(b){b=this.deserialise(decodeURIComponent(RegExp.$1));this.setFig(a b)}e.write('<script src=\"https://fig.bbc.co.uk/frameworks/fig/1/fig.js\"><'+\"/script>\")}} confirm:function(a){a=a||window;if(a.orb&&a.orb.fig&&a.orb.fig(\"no\")){this.setNoFigCookie(a)}if(a.orb===undefined||a.orb.fig===undefined){this.setFig(a {no:1});this.setNoFigCookie(a)}} setNoFigCookie:function(a){a.document.cookie=\"ckns_orb_nofig=1; expires=\"+new Date(new Date().getTime()+1000*60*10).toGMTString()+\";\"} setFig:function(a b){(function(){var c=b;a.orb=a.orb||{};a.orb.fig=function(d){return(arguments.length)?c[d]:c}})()} deserialise:function(b){var a={};b.replace(/([a-z]{2}):([0-9]+)/g function(){a[RegExp.$1]=+RegExp.$2});return a}}})();fig.manager.include();/*]]>*/</script>\n",
      " \n",
      "<!--[if (gt IE 8) | (IEMobile)]><!-->\n",
      "<link rel=\"stylesheet\" href=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/style/orb.min.css\">\n",
      "<!--<![endif]-->\n",
      "<!--[if (lt IE 9) & (!IEMobile)]>\n",
      "<link rel=\"stylesheet\" href=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/style/orb-ie.min.css\">\n",
      "<![endif]-->\n",
      " <script type=\"text/javascript\">/*<![CDATA[*/ (function(undefined){if(!window.bbc){window.bbc={}}var ROLLING_PERIOD_DAYS=30;window.bbc.Mandolin=function(id segments opts){var now=new Date().getTime() storedItem DEFAULT_START=now DEFAULT_RATE=1 COOKIE_NAME=\"ckpf_mandolin\";opts=opts||{};this._id=id;this._segmentSet=segments;this._store=new window.window.bbc.Mandolin.Storage(COOKIE_NAME);this._opts=opts;this._rate=(opts.rate!==undefined)?+opts.rate:DEFAULT_RATE;this._startTs=(opts.start!==undefined)?new Date(opts.start).getTime():new Date(DEFAULT_START).getTime();this._endTs=(opts.end!==undefined)?new Date(opts.end).getTime():daysFromNow(ROLLING_PERIOD_DAYS);this._signupEndTs=(opts.signupEnd!==undefined)?new Date(opts.signupEnd).getTime():this._endTs;this._segment=null;if(typeof id!==\"string\"){throw new Error(\"Invalid Argument: id must be defined and be a string\")}if(Object.prototype.toString.call(segments)!==\"[object Array]\"){throw new Error(\"Invalid Argument: Segments are required.\")}if(opts.rate!==undefined&&(opts.rate<0||opts.rate>1)){throw new Error(\"Invalid Argument: Rate must be between 0 and 1.\")}if(this._startTs>this._endTs){throw new Error(\"Invalid Argument: end date must occur after start date.\")}if(!(this._startTs<this._signupEndTs&&this._signupEndTs<=this._endTs)){throw new Error(\"Invalid Argument: SignupEnd must be between start and end date\")}removeExpired.call(this now);var overrides=window.bbccookies.get().match(/ckns_mandolin_setSegments=([^;]+)/);if(overrides!==null){eval(\"overrides = \"+decodeURIComponent(RegExp.$1)+\";\");if(overrides[this._id]&&this._segmentSet.indexOf(overrides[this._id])==-1){throw new Error(\"Invalid Override: overridden segment should exist in segments array\")}}if(overrides!==null&&overrides[this._id]){this._segment=overrides[this._id]}else{if((storedItem=this._store.getItem(this._id))){this._segment=storedItem.segment}else{if(this._startTs<=now&&now<this._signupEndTs&&now<=this._endTs&&this._store.isEnabled()===true){this._segment=pick(segments this._rate);if(opts.end===undefined){this._store.setItem(this._id {segment:this._segment})}else{this._store.setItem(this._id {segment:this._segment end:this._endTs})}log.call(this \"mandolin_segment\")}}}log.call(this \"mandolin_view\")};window.bbc.Mandolin.prototype.getSegment=function(){return this._segment};function log(actionType params){var that=this;require([\"istats-1\"] function(istats){istats.log(actionType that._id+\":\"+that._segment params?params:{})})}function removeExpired(expires){var items=this._store.getItems() expiresInt=+expires;for(var key in items){if(items[key].end!==undefined&&+items[key].end<expiresInt){this._store.removeItem(key)}}}function getLastExpirationDate(data){var winner=0 rollingExpire=daysFromNow(ROLLING_PERIOD_DAYS);for(var key in data){if(data[key].end===undefined&&rollingExpire>winner){winner=rollingExpire}else{if(+data[key].end>winner){winner=+data[key].end}}}return(winner)?new Date(winner):new Date(rollingExpire)}window.bbc.Mandolin.prototype.log=function(params){log.call(this \"mandolin_log\" params)};window.bbc.Mandolin.prototype.convert=function(params){log.call(this \"mandolin_convert\" params);this.convert=function(){}};function daysFromNow(n){var endDate;endDate=new Date().getTime()+(n*60*60*24)*1000;return endDate}function pick(segments rate){var picked min=0 max=segments.length-1;if(typeof rate===\"number\"&&Math.random()>rate){return null}do{picked=Math.floor(Math.random()*(max-min+1))+min}while(picked>max);return segments[picked]}window.bbc.Mandolin.Storage=function(name){validateCookieName(name);this._cookieName=name;this._isEnabled=(bbccookies.isAllowed(this._cookieName)===true&&bbccookies.cookiesEnabled()===true)};window.bbc.Mandolin.Storage.prototype.setItem=function(key value){var storeData=this.getItems();storeData[key]=value;this.save(storeData);return value};window.bbc.Mandolin.Storage.prototype.isEnabled=function(){return this._isEnabled};window.bbc.Mandolin.Storage.prototype.getItem=function(key){var storeData=this.getItems();return storeData[key]};window.bbc.Mandolin.Storage.prototype.removeItem=function(key){var storeData=this.getItems();delete storeData[key];this.save(storeData)};window.bbc.Mandolin.Storage.prototype.getItems=function(){return deserialise(this.readCookie(this._cookieName)||\"\")};window.bbc.Mandolin.Storage.prototype.save=function(data){window.bbccookies.set(this._cookieName+\"=\"+encodeURIComponent(serialise(data))+\"; expires=\"+getLastExpirationDate(data).toUTCString()+\";\")};window.bbc.Mandolin.Storage.prototype.readCookie=function(name){var nameEq=name+\"=\" ca=window.bbccookies.get().split(\"; \") i c;validateCookieName(name);for(i=0;i<ca.length;i++){c=ca[i];if(c.indexOf(nameEq)===0){return decodeURIComponent(c.substring(nameEq.length c.length))}}return null};function serialise(o){var str=\"\";for(var p in o){if(o.hasOwnProperty(p)){str+='\"'+p+'\"'+\":\"+(typeof o[p]===\"object\"?(o[p]===null?\"null\":\"{\"+serialise(o[p])+\"}\"):'\"'+o[p].toString()+'\"')+\" \"}}return str.replace(/ \\}/g \"}\").replace(/ $/g \"\")}function deserialise(str){var o;str=\"{\"+str+\"}\";if(!validateSerialisation(str)){throw\"Invalid input provided for deserialisation.\"}eval(\"o = \"+str);return o}var validateSerialisation=(function(){var OBJECT_TOKEN=\"<Object>\" ESCAPED_CHAR='\"\\\\n\\\\r\\\\u2028\\\\u2029\\\\u000A\\\\u000D\\\\u005C' ALLOWED_CHAR=\"([^\"+ESCAPED_CHAR+\"]|\\\\\\\\[\"+ESCAPED_CHAR+\"])\" KEY='\"'+ALLOWED_CHAR+'+\"' VALUE='(null|\"'+ALLOWED_CHAR+'*\"|'+OBJECT_TOKEN+\")\" KEY_VALUE=KEY+\":\"+VALUE KEY_VALUE_SEQUENCE=\"(\"+KEY_VALUE+\" )*\"+KEY_VALUE OBJECT_LITERAL=\"({}|{\"+KEY_VALUE_SEQUENCE+\"})\" objectPattern=new RegExp(OBJECT_LITERAL \"g\");return function(str){if(str.indexOf(OBJECT_TOKEN)!==-1){return false}while(str.match(objectPattern)){str=str.replace(objectPattern OBJECT_TOKEN)}return str===OBJECT_TOKEN}})();function validateCookieName(name){if(name.match(/ ;/)){throw\"Illegal name provided must be valid in browser cookie.\"}}})(); /*]]>*/</script> <script type=\"text/javascript\"> document.documentElement.className += (document.documentElement.className? ' ' : '') + 'orb-js'; fig.manager.confirm(); </script> <script src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/script/orb/api.min.js\"></script> <script type=\"text/javascript\"> var blq = { environment: function() { return 'live'; } } </script> <script type=\"text/javascript\"> /*<![CDATA[*/ function oqsSurveyManager(w flag) { if (flag !== 'OFF') { w.document.write('<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/script/vendor/edr.js\"><'+'/script>'); } } oqsSurveyManager(window 'ON'); /*]]>*/ </script> <!-- BBCDOTCOM template: responsive webservice -->\n",
      " <!-- BBCDOTCOM head --><script type=\"text/javascript\"> /*<![CDATA[*/ var _sf_startpt = (new Date()).getTime(); /*]]>*/ </script><style type=\"text/css\">.bbccom_display_none{display:none;}</style><script type=\"text/javascript\"> /*<![CDATA[*/ var bbcdotcomConfig googletag = googletag || {}; googletag.cmd = googletag.cmd || []; var bbcdotcom = false; (function(){ if(typeof require !== 'undefined') { require({ paths:{ \"bbcdotcom\":\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script\" } }); } })(); /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ var bbcdotcom = { adverts: { keyValues: { set: function() {} } } advert: { write: function () {} show: function () {} isActive: function () { return false; } layout: function() { return { reset: function() {} } } } config: { init: function() {} isActive: function() {} setSections: function() {} isAdsEnabled: function() {} setAdsEnabled: function() {} isAnalyticsEnabled: function() {} setAnalyticsEnabled: function() {} setAssetPrefix: function() {} setVersion: function () {} setJsPrefix: function() {} setSwfPrefix: function() {} setCssPrefix: function() {} setConfig: function() {} getAssetPrefix: function() {} getJsPrefix: function () {} getSwfPrefix: function () {} getCssPrefix: function () {} } survey: { init: function(){ return false; } } data: {} init: function() {} objects: function(str) { return false; } locale: { set: function() {} get: function() {} } setAdKeyValue: function() {} utils: { addEvent: function() {} addHtmlTagClass: function() {} log: function () {} } addLoadEvent: function() {} }; /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ (function(){ if (typeof orb !== 'undefined' && typeof orb.fig === 'function') { if (orb.fig('ad') && orb.fig('uk') == 0) { bbcdotcom.data = { ads: (orb.fig('ad') ? 1 : 0) stats: (orb.fig('uk') == 0 ? 1 : 0) statsProvider: orb.fig('ap') }; } } else { document.write('<script type=\"text/javascript\" src=\"'+('https:' == document.location.protocol ? 'https://ssl.bbc.com' : 'http://tps.bbc.com')+'/wwscripts/data\">\\x3C/script>'); } })(); /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ (function(){ if (typeof orb === 'undefined' || typeof orb.fig !== 'function') { bbcdotcom.data = { ads: bbcdotcom.data.a stats: bbcdotcom.data.b statsProvider: bbcdotcom.data.c }; } if (bbcdotcom.data.ads == 1) { document.write('<script type=\"text/javascript\" src=\"'+('https:' == document.location.protocol ? 'https://ssl.bbc.co.uk' : 'http://www.bbc.co.uk')+'/wwscripts/flag\">\\x3C/script>'); } })(); /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ (function(){ if (window.bbcdotcom && (typeof bbcdotcom.flag == 'undefined' || (typeof bbcdotcom.data.ads !== 'undefined' && bbcdotcom.flag.a != 1))) { bbcdotcom.data.ads = 0; } if (/[?|&]ads/.test(window.location.href) || /(^|; )ads=on; /.test(document.cookie) || /; ads=on(; |$)/.test(document.cookie)) { bbcdotcom.data.ads = 1; bbcdotcom.data.stats = 1; } if (window.bbcdotcom && (bbcdotcom.data.ads == 1 || bbcdotcom.data.stats == 1)) { bbcdotcom.assetPrefix = \"http://static.bbci.co.uk/bbcdotcom/0.3.344/\"; if (/(sandbox|int)(.dev)*.bbc.co*/.test(window.location.href) || /[?|&]ads-debug/.test(window.location.href) || document.cookie.indexOf('ads-debug=') !== -1) { document.write('<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script/orb/individual.js\">\\x3C/script>'); } else { document.write('<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script/orb/bbcdotcom.js\">\\x3C/script>'); } if(/[\\\\?&]ads=([^&#]*)/.test(window.location.href)) { document.write('<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script/orb/adverts/adSuites.js\">\\x3C/script>'); } } })(); /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ (function(){ if (window.bbcdotcom && (bbcdotcom.data.ads == 1 || bbcdotcom.data.stats == 1)) { bbcdotcomConfig = {\"adFormat\":\"standard\" \"adKeyword\":\"\" \"adMode\":\"smart\" \"adsEnabled\":true \"appAnalyticsSections\":\"news>technology\" \"asyncEnabled\":true \"disableInitialLoad\":false \"advertInfoPageUrl\":\"http:\\/\\/www.bbc.co.uk\\/faqs\\/online\\/adverts_general\" \"advertisementText\":\"Advertisement\" \"analyticsEnabled\":true \"appName\":\"tabloid\" \"assetPrefix\":\"http:\\/\\/static.bbci.co.uk\\/bbcdotcom\\/0.3.344\\/\" \"continuousPlayEnabled\":false \"customAdParams\":[] \"customStatsParams\":[] \"headline\":\"An hour to catch the coding bug\" \"id\":\"26415021\" \"inAssociationWithText\":\"in association with\" \"keywords\":\"\" \"language\":\"\" \"orbTransitional\":false \"outbrainEnabled\":true \"palEnv\":\"live\" \"productName\":\"\" \"sections\":[] \"siteCatalystEnabled\":true \"comScoreEnabled\":true \"slots\":\"\" \"sponsoredByText\":\"is sponsored by\" \"adsByGoogleText\":\"Ads by Google\" \"summary\":\"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\" \"type\":\"STORY\" \"staticBase\":\"\\/bbcdotcom\" \"staticHost\":\"http:\\/\\/static.bbci.co.uk\" \"staticVersion\":\"0.3.344\" \"staticPrefix\":\"http:\\/\\/static.bbci.co.uk\\/bbcdotcom\\/0.3.344\" \"dataHttp\":\"tps.bbc.com\" \"dataHttps\":\"ssl.bbc.com\" \"flagHttp\":\"www.bbc.co.uk\" \"flagHttps\":\"ssl.bbc.co.uk\" \"analyticsHttp\":\"sa.bbc.com\" \"analyticsHttps\":\"ssa.bbc.com\"}; bbcdotcom.config.init(bbcdotcomConfig bbcdotcom.data window.location window.document); bbcdotcom.config.setAssetPrefix(\"http://static.bbci.co.uk/bbcdotcom/0.3.344/\"); bbcdotcom.config.setVersion(\"0.3.344\"); document.write('<!--[if IE 7]><script type=\"text/javascript\">bbcdotcom.config.setIE7(true);\\x3C/script><![endif]-->'); document.write('<!--[if IE 8]><script type=\"text/javascript\">bbcdotcom.config.setIE8(true);\\x3C/script><![endif]-->'); document.write('<!--[if IE 9]><script type=\"text/javascript\">bbcdotcom.config.setIE9(true);\\x3C/script><![endif]-->'); if (/[?|&]ex-dp/.test(window.location.href) || document.cookie.indexOf('ex-dp=') !== -1) { bbcdotcom.utils.addHtmlTagClass('bbcdotcom-ex-dp'); } } })(); /*]]>*/ </script> <script type=\"text/javascript\">/*<![CDATA[*/\n",
      " window.bbcFlagpoles_istats = 'ON';\n",
      " window.orb = window.orb || {};\n",
      " if (bbccookies.isAllowed('s1')) {\n",
      " var istatsTrackingUrl = '//sa.bbc.co.uk/bbc/bbc/s?name=news.technology.story.26415021.page&cps_asset_id=26415021&page_type=Story&section=%2Fnews%2Ftechnology&first_pub=2014-03-03T07%3A36%3A59%2B00%3A00&last_editorial_update=2014-03-03T10%3A22%3A55%2B00%3A00&title=An+hour+to+catch+the+coding+bug&for_nation=il&app_version=1.99.0&bbc_site=news&pal_route=asset&ml_name=barlesque&app_type=responsive&language=en-GB&ml_version=0.28.4&pal_webapp=tabloid&prod_name=news&app_name=news';\n",
      " require(['istats-1'] function (istats) {\n",
      " istats.addCollector({'name': 'default' 'url': '//sa.bbc.co.uk/bbc/bbc/s' 'separator': '&' });\n",
      " var counterName = (window.istats_countername) ? window.istats_countername : istatsTrackingUrl.match(/[\\?&]name=([^&]*)/i)[1];\n",
      " istats.setCountername(counterName);\n",
      " if (/\\bIDENTITY=/.test(document.cookie)) {\n",
      " istats.addLabels({'bbc_identity': '1'});\n",
      " }\n",
      " if (/\\bckns_policy=\\d\\d0/.test(document.cookie)) {\n",
      " istats.addLabels({'ns_nc': '1'});\n",
      " }\n",
      " var c = (document.cookie.match(/\\bckns_policy=(\\d\\d\\d)/) || []).pop() || '';\n",
      " var screenWidthAndHeight = 'unavailable';\n",
      " if (window.screen && screen.width && screen.height) {\n",
      " screenWidthAndHeight = screen.width + 'x' + screen.height;\n",
      " }\n",
      " istats.addLabels('cps_asset_id=26415021&page_type=Story&section=%2Fnews%2Ftechnology&first_pub=2014-03-03T07%3A36%3A59%2B00%3A00&last_editorial_update=2014-03-03T10%3A22%3A55%2B00%3A00&title=An+hour+to+catch+the+coding+bug&for_nation=il&app_version=1.99.0&bbc_site=news&pal_route=asset&ml_name=barlesque&app_type=responsive&language=en-GB&ml_version=0.28.4&pal_webapp=tabloid&prod_name=news&app_name=news');\n",
      " istats.addLabels({\n",
      " 'blq_s': '4d' \n",
      " 'blq_r': '2.7' \n",
      " 'blq_v': 'default' \n",
      " 'blq_e': 'pal' \n",
      " 'bbc_mc': (c ? 'ad' + c.charAt(0) + 'ps' + c.charAt(1) + 'pf' + c.charAt(2) : 'not_set') \n",
      " 'screen_resolution': screenWidthAndHeight \n",
      " 'ns_referrer': encodeURI(((window.orb.referrer) ? window.orb.referrer : document.referrer))\n",
      " }\n",
      " );\n",
      " });\n",
      " }\n",
      " /*]]>*/</script>\n",
      " <script type=\"text/javascript\"> /* <![CDATA[ */ define('id-statusbar-config' { 'translation_signedout': \"Sign in\" 'translation_signedin': \"Your account\" 'use_overlay' : false 'signin_url' : \"https://ssl.bbc.com/id/signin?ptrt=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021\" 'locale' : \"en-GB\" 'policyname' : \"\" 'ptrt' : \"http://www.bbc.com/news/technology-26415021\" }); var map = {}; map['idcta/statusbar'] = 'http://static.bbci.co.uk/id/0.32.25/modules/idcta/statusbar'; require({paths: map}); /* ]]> */ </script> <script type=\"text/javascript\"> require(['istats-1'] function(istats){ if (typeof(document) != 'undefined' && typeof(document.cookie) != 'undefined') { var cookieAphidMatch = document.cookie.match(/ckpf_APHID=([^;]*)/); if (cookieAphidMatch && typeof(cookieAphidMatch[1]) == 'string') { istats.addLabels({'bbc_hid': cookieAphidMatch[1]}); } } })(); </script> <script type=\"text/javascript\"> (function () { if (! window.require) { throw new Error('idcta: could not find require module'); } var map = {}; map['idapp-1'] = 'http://static.bbci.co.uk/idapp/0.71.76/modules/idapp/idapp-1'; map['idcta/idcta-1'] = 'http://static.bbci.co.uk/id/0.32.25/modules/idcta/idcta-1'; map['idcta/idCookie'] = 'http://static.bbci.co.uk/id/0.32.25/modules/idcta/idCookie'; map['idcta/overlayManager'] = 'http://static.bbci.co.uk/id/0.32.25/modules/idcta/overlayManager'; require({paths: map}); define('id-config' {\"idapp\":{\"version\":\"0.71.76\" \"hostname\":\"ssl.bbc.com\" \"insecurehostname\":\"www.bbc.com\" \"tld\":\"bbc.com\"} \"idtranslations\":{\"version\":\"0.33.27\"} \"identity\":{\"baseUrl\":\"https:\\/\\/talkback.live.bbc.co.uk\\/identity\" \"cookieAgeDays\":730 \"accessTokenCookieName\":\"ckns_IDA-ATKN\"} \"pathway\":{\"name\":null \"staticAssetUrl\":\"http:\\/\\/static.bbci.co.uk\\/idapp\\/0.71.76\\/modules\\/idapp\\/idapp-1\\/View.css\"} \"idpurl\":\"https:\\/\\/idp.api.bbc.co.uk\\/idp\\/oauth2\\/authorize?client_id=bbc-co-uk&response_type=code&scope=openid+play.bbcstore.r+plays.any.w+plays.any.r+follows.any.w+follows.any.r+favourites.any.w+favourites.any.r+idm.basic.r&module=bbc-co-uk&state=ptrt%3Dhttp%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021%26locale%3Den-GB&redirect_uri=https%3A%2F%2Fssl.bbc.com%2Fid%2Foauth2%2Fconsume%2Fidp.bbc.co.uk\"}); })(); </script> <script type=\"text/javascript\"> require(['idcta/idCookie'] function(idCookie){ if (typeof(document) != 'undefined' && typeof(document.cookie) != 'undefined') { var idCookieInstance = idCookie.getInstance(); /* Timestamp in milliseconds for the 6am on 27th of October 2015 */ var timestamp27thOct = 1445925600000; /* Only select users who signed in before the dooms day and were not downgraded yet */ if (idCookieInstance.hasCookie() && idCookieInstance.timestamp != '' && parseInt(idCookieInstance.timestamp) > 0 && parseInt(idCookieInstance.timestamp) < timestamp27thOct && !idCookieInstance.isDowngraded()) { /* iPlayer uplift is session cookie so downgrade based on this cookie missed 20% users. To cover all the users with our fix ut is nor uncoditional: all users that have not been downgraded before will now be downgraded */ idCookieInstance.downgrade(); } } }); </script> \n",
      " <link type=\"text/css\" rel=\"stylesheet\" href=\"http://static.bbci.co.uk/news/1.99.0479/stylesheets/services/news/core.css\">\n",
      " <!--[if lt IE 9]>\n",
      " <link type=\"text/css\" rel=\"stylesheet\" href=\"http://static.bbci.co.uk/news/1.99.0479/stylesheets/services/news/old-ie.css\">\n",
      " <script src=\"http://static.bbci.co.uk/news/1.99.0479/js/vendor/html5shiv/html5shiv.js\"></script>\n",
      " <![endif]-->\n",
      " <script id=\"news-loader\"> if (document.getElementById(\"responsive-news\")) { window.bbcNewsResponsive = true; } var isIE = (function() { var undef v = 3 div = document.createElement('div') all = div.getElementsByTagName('i'); while ( div.innerHTML = '<!--[if gt IE ' + (++v) + ']><i></i><![endif]-->' all[0] ); return v > 4 ? v : undef; }()); var modernDevice = 'querySelector' in document && 'localStorage' in window && 'addEventListener' in window forceCore = document.cookie.indexOf('ckps_force_core') !== -1; window.cutsTheMustard = modernDevice && !forceCore; if (window.cutsTheMustard) { document.documentElement.className += ' ctm'; var insertPoint = document.getElementById('news-loader') config = {\"asset\":{\"asset_id\":\"26415021\" \"asset_uri\":\"\\/news\\/technology-26415021\" \"first_created\":{\"date\":\"2014-03-03 07:36:59\" \"timezone_type\":3 \"timezone\":\"Europe\\/London\"} \"last_updated\":{\"date\":\"2014-03-03 10:22:55\" \"timezone_type\":3 \"timezone\":\"Europe\\/London\"} \"options\":{\"allowHeadline\":true \"allowDateStamp\":true \"allowRelatedStoriesBox\":true \"allowRightHandSide\":true \"includeComments\":false \"isIgorSeoTagsEnabled\":false \"allowPrintingSharingLinks\":true \"allowAdvertising\":true} \"section\":{\"name\":\"Technology\" \"id\":\"99113\" \"uri\":\"\\/news\\/technology\" \"urlIdentifier\":\"\\/news\\/technology\"} \"edition\":\"International\" \"audience\":null \"iStats_counter_name\":\"news.technology.story.26415021.page\" \"type\":\"STY\" \"length\":5362 \"byline\":{\"name\":\"By Mark Ward\" \"persons\":{\"0\":{\"name\":\"Mark Ward\" \"function\":\"Technology correspondent BBC News\"}} \"title\":\"Technology correspondent BBC News\"} \"headline\":\"An hour to catch the coding bug\" \"mediaType\":null} \"smpBrand\":null \"staticHost\":\"http:\\/\\/static.bbci.co.uk\" \"environment\":\"live\" \"locatorVersion\":\"0.46.3\" \"pathPrefix\":\"\\/news\" \"staticPrefix\":\"http:\\/\\/static.bbci.co.uk\\/news\\/1.99.0479\" \"jsPath\":\"http:\\/\\/static.bbci.co.uk\\/news\\/1.99.0479\\/js\" \"cssPath\":\"http:\\/\\/static.bbci.co.uk\\/news\\/1.99.0479\\/stylesheets\\/services\\/news\" \"cssPostfix\":\"\" \"dynamic\":null \"features\":{\"localnews\":true \"video\":true \"liveeventcomponent\":true \"mediaassetpage\":true \"travel\":true \"gallery\":true \"rollingnews\":true \"rumanalytics\":true \"sportstories\":true \"radiopromo\":true \"fromothernewssites\":true \"locallive\":true \"weather\":true} \"features2\":{\"svg_brand\":true \"chartbeat\":true \"connected_stream\":true \"connected_stream_promo\":true \"nav\":true \"pulse_survey\":false \"local_survey\":true \"correspondents\":true \"blogs\":true \"open_graph\":true \"follow_us\":true \"marketdata_markets\":true \"marketdata_shares\":true \"nations_pseudo_nav\":true \"politics_election2015_topic_pages\":true \"politics_election2016_az_pages\":true \"politics_election2016_council_police_pages\":true \"politics_election2016_ni_results_page\":true \"responsive_breaking_news\":true \"live_event\":true \"most_popular\":true \"most_popular_tabs\":true \"most_popular_by_day\":true \"routing\":true \"rum\":true \"radiopromonownext\":true \"config_based_layout\":true \"orb\":true \"enhanced_gallery\":true \"map_most_watched\":true \"top_stories_promo\":true \"features_and_analysis\":true \"section_labels\":true \"index_title\":true \"share_tools\":true \"local_live_promo\":true \"adverts\":true \"adverts_async\":true \"adexpert\":true \"igor_geo_redirect\":true \"igor_device_redirect\":true \"live\":true \"comscore_mmx\":true \"find_local_news\":true \"comments\":true \"comments_enhanced\":true \"browser_notify\":true \"stream_grid_promo\":true \"breaking_news\":false \"top_stories_max_volume\":true \"record_livestats\":true \"contact_form\":true \"channel_page\":true \"portlet_global_variants\":true \"suppress_lep_timezone\":true \"story_recommendations\":true \"cedexis\":true \"mpulse\":true \"story_single_column_layout\":true \"story_image_copyright_labels\":true \"ovp_resolve_primary_media_vpids\":false \"media_player\":true \"travel\":true} \"configuration\":{\"showtimestamp\":\"1\" \"showweather\":\"1\" \"showsport\":\"1\" \"showolympics\":\"1\" \"showfeaturemain\":\"1\" \"showsitecatalyst\":\"1\" \"candyplatform\":\"EnhancedMobile\" \"showwatchlisten\":\"1\" \"showspecialreports\":\"\" \"videotopiccandyid\":\"\" \"showvideofeedsections\":\"1\" \"showstorytopstories\":\"\" \"showstoryfeaturesandanalysis\":\"1\" \"showstorymostpopular\":\"\" \"showgallery\":\"1\" \"cms\":\"cps\" \"channelpagecandyid\":\"10318089\"} \"pollingHost\":\"http:\\/\\/polling.bbc.co.uk\" \"service\":\"news\" \"locale\":\"en-GB\" \"locatorHost\":null \"locatorFlagPole\":true \"local\":{\"allowLocationLookup\":true} \"isWorldService\":false \"rumAnalytics\":{\"server\":\"http:\\/\\/ingest.rum.bbc.co.uk\" \"key\":\"news\" \"sample_rate\":0.1 \"url_params\":null \"edition\":\"international\"} \"isChannelPage\":false \"suitenameMap\":\"\" \"languageVariant\":\"\" \"commentsHost\":\"http:\\/\\/feeds.bbci.co.uk\" \"search\":null \"comscoreAnalytics\":null}; config.configuration['get'] = function (key) { return this[key.toLowerCase()]; }; var bootstrapUI=function(){var e=function(){if(navigator.userAgent.match(/(Android (2.0|2.1))|(Nokia)|(OSRE\\/)|(Opera (Mini|Mobi))|(w(eb)?OSBrowser)|(UCWEB)|(Windows Phone)|(XBLWP)|(ZuneWP)/))return!1;if(navigator.userAgent.match(/MSIE 10.0/))return!0;var e t=document n=t.head||t.getElementsByTagName(\"head\")[0] r=t.createElement(\"style\") s=t.implementation||{hasFeature:function(){return!1}};r.type=\"text/css\" n.insertBefore(r n.firstChild) e=r.sheet||r.styleSheet;var i=s.hasFeature(\"CSS2\" \"\")?function(t){if(!e||!t)return!1;var n=!1;try{e.insertRule(t 0) n=!/unknown/i.test(e.cssRules[0].cssText) e.deleteRule(e.cssRules.length-1)}catch(r){}return n}:function(t){return e&&t?(e.cssText=t 0!==e.cssText.length&&!/unknown/i.test(e.cssText)&&0===e.cssText.replace(/\\r+|\\n+/g \"\").indexOf(t.split(\" \")[0])):!1};return i('@font-face{ font-family:\"font\";src:\"font.ttf\"; }')}();e&&(document.getElementsByTagName(\"html\")[0].className+=\" ff\") function(){var e=document.documentElement.style;(\"flexBasis\"in e||\"WebkitFlexBasis\"in e||\"msFlexBasis\"in e)&&(document.documentElement.className+=\" flex\")}();var t n r s i a o={} u=function(){var e=document.documentElement.clientWidth r=document.documentElement.clientHeight s=window.innerWidth i=window.innerHeight a=s>1.5*e;t=a?e:s n=a?r:i} c=function(e){var t=document.createElement(\"link\");t.setAttribute(\"rel\" \"stylesheet\") t.setAttribute(\"type\" \"text/css\") t.setAttribute(\"href\" r+e+s+\".css\") t.setAttribute(\"media\" a[e]) i.parentNode.insertBefore(t i) delete a[e]} l=function(e r s){r&&!s&&(t>=r||n>=r)&&c(e) s&&!r&&(s>=t||s>=n)&&c(e) r&&s&&(t>=r||n>=r)&&(s>=t||s>=n)&&c(e)} f=function(e){if(o[e])return o[e];var t=e.match(/\\(min\\-width:[\\s]*([\\s]*[0-9\\.]+)(px|em)[\\s]*\\)/) n=e.match(/\\(max\\-width:[\\s]*([\\s]*[0-9\\.]+)(px|em)[\\s]*\\)/) r=t&&parseFloat(t[1])||null s=n&&parseFloat(n[1])||null;return o[e]=[r s] o[e]} m=function(){var e=0;for(var t in a)e++;return e} d=function(){m()||window.removeEventListener(\"resize\" h !1);for(var e in a){var t=a[e] n=f(t);l(e n[0] n[1])}} h=function(){u() d()} v=function(e t){a=e r=t.path+(\"/\"!==t.path.substr(-1)?\"/\":\"\") s=t.postfix i=t.insertBefore u() d() window.addEventListener(\"resize\" h !1)};return{stylesheetLoaderInit:v}}(); var stylesheets = {\"compact\":\"(max-width: 599px)\" \"tablet\":\"(min-width: 600px)\" \"wide\":\"(min-width: 1008px)\"}; bootstrapUI.stylesheetLoaderInit(stylesheets { path: 'http://static.bbci.co.uk/news/1.99.0479/stylesheets/services/news' postfix: '' insertBefore: insertPoint }); var loadRequire = function(){ var js_paths = {\"jquery-1.9\":\"vendor\\/jquery-1\\/jquery\" \"jquery-1\":\"http:\\/\\/static.bbci.co.uk\\/frameworks\\/jquery\\/0.3.0\\/sharedmodules\\/jquery-1.7.2\" \"demi-1\":\"http:\\/\\/static.bbci.co.uk\\/frameworks\\/demi\\/0.10.0\\/sharedmodules\\/demi-1\" \"swfobject-2\":\"http:\\/\\/static.bbci.co.uk\\/frameworks\\/swfobject\\/0.1.10\\/sharedmodules\\/swfobject-2\" \"jquery\":\"vendor\\/jquery-2\\/jquery.min\" \"domReady\":\"vendor\\/require\\/domReady\" \"translation\":\"module\\/translations\\/en-GB\" \"bump-3\":\"\\/\\/emp.bbci.co.uk\\/emp\\/bump-3\\/bump-3\"}; js_paths.navigation = 'module/nav/navManager'; requirejs.config({ baseUrl: 'http://static.bbci.co.uk/news/1.99.0479/js' map: { 'vendor/locator': { 'module/bootstrap': 'vendor/locator/bootstrap' 'locator/stats': 'vendor/locator/stats' 'locator/locatorView': 'vendor/locator/locatorView' } } paths: js_paths waitSeconds: 30 }); define('config' function () { return config; }); require([\"compiled\\/all\"] function() {\n",
      " require(['domReady'] function (domReady) { domReady(function () { require([\"module\\/dotcom\\/handlerAdapter\" \"module\\/rumAdaptor\" \"module\\/stats\\/statsSubscriberAdapter\" \"module\\/alternativeJsStrategy\\/controller\" \"module\\/iconLoaderAdapter\" \"module\\/polyfill\\/location.origin\" \"module\\/components\\/breakingNewsAdapter\" \"module\\/indexTitleAdaptor\" \"module\\/navigation\\/handlerAdaptor\" \"module\\/noTouchDetectionForCss\" \"module\\/components\\/responsiveImage\" \"module\\/components\\/timestampAdaptor\" \"module\\/tableScrollAdapter\" \"module\\/components\\/mediaPlayer\\/mainAdapter\" \"module\\/stats\\/statsBindingAdapter\" \"module\\/hotspot\\/handlerAdapter\"] function() { require([\"module\\/strategiserAdaptor\"]); }); }); }); });\n",
      " }; loadRequire(); } else { var l = document.createElement('link'); l.href = 'http://static.bbci.co.uk/news/1.99.0479/icons/generated/icons.fallback.css'; l.rel = 'stylesheet'; document.getElementsByTagName('head')[0].appendChild(l); } </script> <script type=\"text/javascript\"> /*<![CDATA[*/ bbcdotcom.init({adsToDisplay:['leaderboard' 'sponsor_section' 'mpu' 'outbrain_ar_5' 'outbrain_ar_7' 'outbrain_ar_8' 'outbrain_ar_9' 'native' 'mpu_bottom' 'adsense' 'inread']}); /*]]>*/ </script> <noscript><link href=\"http://static.bbci.co.uk/news/1.99.0479/icons/generated/icons.fallback.css\" rel=\"stylesheet\"></noscript>\n",
      " \n",
      " <meta name=\"viewport\" content=\"width=device-width initial-scale=1 user-scalable=1\">\n",
      "</head>\n",
      "<!--[if IE]><body id=\"asset-type-sty\" class=\"ie device--feature\"><![endif]-->\n",
      "<!--[if !IE]>--><body id=\"asset-type-sty\" class=\"device--feature\"><!--<![endif]-->\n",
      " <div class=\"direction\" >\n",
      " \n",
      " <!-- BBCDOTCOM bodyFirst --><div id=\"bbccom_interstitial_ad\" class=\"bbccom_display_none\"></div><div id=\"bbccom_interstitial\" class=\"bbccom_display_none\"><script type=\"text/javascript\"> /*<![CDATA[*/ (function() { if (window.bbcdotcom && bbcdotcom.config.isActive('ads')) { googletag.cmd.push(function() { googletag.display('bbccom_interstitial'); }); } }()); /*]]>*/ </script></div><div id=\"bbccom_wallpaper_ad\" class=\"bbccom_display_none\"></div><div id=\"bbccom_wallpaper\" class=\"bbccom_display_none\"><script type=\"text/javascript\"> /*<![CDATA[*/ (function() { var wallpaper; if (window.bbcdotcom && bbcdotcom.config.isActive('ads')) { if (bbcdotcom.config.isAsync()) { googletag.cmd.push(function() { googletag.display('bbccom_wallpaper'); }); } else { googletag.display(\"wallpaper\"); } wallpaper = bbcdotcom.adverts.adRegister.getAd('wallpaper'); if (wallpaper !== null && wallpaper !== undefined) { wallpaper.setDomElement('bbccom_wallpaper'); } } }()); /*]]>*/ </script></div><script type=\"text/javascript\"> /*<![CDATA[*/ (function() { if (window.bbcdotcom && bbcdotcom.config.isActive('ads')) { document.write(unescape('%3Cscript id=\"gnlAdsEnabled\" class=\"bbccom_display_none\"%3E%3C/script%3E')); } if (window.bbcdotcom && bbcdotcom.config.isActive('analytics')) { document.write(unescape('%3Cscript id=\"gnlAnalyticsEnabled\" class=\"bbccom_display_none\"%3E%3C/script%3E')); } if (window.bbcdotcom && bbcdotcom.config.isActive('continuousPlay')) { document.write(unescape('%3Cscript id=\"gnlContinuousPlayEnabled\" class=\"bbccom_display_none\"%3E%3C/script%3E')); } }()); /*]]>*/ </script> <div id=\"blq-global\"> <div id=\"blq-pre-mast\"> </div> </div> <script type=\"text/html\" id=\"blq-bbccookies-tmpl\"><![CDATA[ <section> <div id=\"bbccookies\" class=\"bbccookies-banner orb-banner-wrapper bbccookies-d\"> <div id=\"bbccookies-prompt\" class=\"orb-banner b-g-p b-r b-f\"> <h2 class=\"orb-banner-title\"> Cookies on the BBC website </h2> <p class=\"orb-banner-content\" dir=\"ltr\"> The BBC has updated its cookie policy. We use cookies to ensure that we give you the best experience on our website. This includes cookies from third party social media websites if you visit a page which contains embedded content from social media. Such third party cookies may track your use of the BBC website.<span class=\"bbccookies-international-message\"> We and our partners also use cookies to ensure we show you advertising that is relevant to you.</span> If you continue without changing your settings we'll assume that you are happy to receive all cookies on the BBC website. However you can change your cookie settings at any time. </p> <ul class=\"orb-banner-options\"> <li id=\"bbccookies-continue\"> <button type=\"button\" id=\"bbccookies-continue-button\">Continue</button> </li> <li id=\"bbccookies-settings\"> <a href=\"/privacy/cookies/managing/cookie-settings.html\">Change settings</a> </li> <li id=\"bbccookies-more\"><a href=\"/privacy/cookies/bbc\">Find out more</a></li></ul> </div> </div> </section> ]]></script> <script type=\"text/javascript\">/*<![CDATA[*/ (function(){if(bbccookies._showPrompt()){var g=document b=g.getElementById(\"blq-pre-mast\") e=g.getElementById(\"blq-bbccookies-tmpl\") a f;if(b&&g.createElement){a=g.createElement(\"div\");f=e.innerHTML;f=f.replace(\"<\"+\"![CDATA[\" \"\").replace(\"]]\"+\">\" \"\");a.innerHTML=f;b.appendChild(a);blqCookieContinueButton=g.getElementById(\"bbccookies-continue-button\");blqCookieContinueButton.onclick=function(){a.parentNode.removeChild(a);return false};bbccookies._setPolicy(bbccookies.readPolicy())}var c=g.getElementById(\"bbccookies\");if(c&&!window.orb.fig(\"uk\")){c.className=c.className.replace(/\\bbbccookies-d\\b/ \"\");c.className=c.className+(\" bbccookies-w\")}}})(); /*]]>*/</script> <script type=\"text/javascript\">/*<![CDATA[*/ if (bbccookies.isAllowed('s1')) { require(['istats-1'] function (istats) { istats.invoke(); }); } /*]]>*/</script> <!-- Begin iStats 20100118 (UX-CMC 1.1009.3) --> <script type=\"text/javascript\">/*<![CDATA[*/ if (bbccookies.isAllowed('s1')) { (function () { require(['istats-1'] function (istats) { istatsTrackingUrl = istats.getDefaultURL(); if (istats.isEnabled() && bbcFlagpoles_istats === 'ON') { sitestat(istatsTrackingUrl); } else { window.ns_pixelUrl = istatsTrackingUrl; /* used by Flash library to track */ } function sitestat(n) { var j = document f = j.location b = \"\"; if (j.cookie.indexOf(\"st_ux=\") != -1) { var k = j.cookie.split(\";\"); var e = \"st_ux\" h = document.domain a = \"/\"; if (typeof ns_ != \"undefined\" && typeof ns_.ux != \"undefined\") { e = ns_.ux.cName || e; h = ns_.ux.cDomain || h; a = ns_.ux.cPath || a } for (var g = 0 f = k.length; g < f; g++) { var m = k[g].indexOf(\"st_ux=\"); if (m != -1) { b = \"&\" + decodeURI(k[g].substring(m + 6)) } } bbccookies.set(e + \"=; expires=\" + new Date(new Date().getTime() - 60).toGMTString() + \"; path=\" + a + \"; domain=\" + h); } window.ns_pixelUrl = n; } }); })(); } else { window.istats = {enabled: false}; } /*]]>*/</script> <noscript><p style=\"position: absolute; top: -999em;\"><img src=\"//sa.bbc.co.uk/bbc/bbc/s?name=news.technology.story.26415021.page&amp;cps_asset_id=26415021&amp;page_type=Story&amp;section=%2Fnews%2Ftechnology&amp;first_pub=2014-03-03T07%3A36%3A59%2B00%3A00&amp;last_editorial_update=2014-03-03T10%3A22%3A55%2B00%3A00&amp;title=An+hour+to+catch+the+coding+bug&amp;for_nation=il&amp;app_version=1.99.0&amp;bbc_site=news&amp;pal_route=asset&amp;ml_name=barlesque&amp;app_type=responsive&amp;language=en-GB&amp;ml_version=0.28.4&amp;pal_webapp=tabloid&amp;prod_name=news&amp;app_name=news&amp;blq_js_enabled=0&amp;blq_s=4d&amp;blq_r=2.7&amp;blq_v=default&amp;blq_e=pal \" height=\"1\" width=\"1\" alt=\"\"/></p></noscript> <!-- End iStats (UX-CMC) --> \n",
      " <!--[if (gt IE 8) | (IEMobile)]><!--> <header id=\"orb-banner\" role=\"banner\"> <!--<![endif]--> <!--[if (lt IE 9) & (!IEMobile)]> <![if (IE 8)]> <header id=\"orb-banner\" role=\"banner\" class=\"orb-old-ie orb-ie8\"> <![endif]> <![if (IE 7)]> <header id=\"orb-banner\" role=\"banner\" class=\"orb-old-ie orb-ie7\"> <![endif]> <![if (IE 6)]> <header id=\"orb-banner\" role=\"banner\" class=\"orb-old-ie orb-ie6\"> <![endif]> <![endif]--> <div id=\"orb-header\" class=\"orb-nav-pri orb-nav-pri-white b-header--white--black orb-nav-empty\" > <div class=\"orb-nav-pri-container b-r b-g-p\"> <div class=\"orb-nav-section orb-nav-blocks\"> <a href=\"/\"> <img src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/img/bbc-blocks-dark.png\" width=\"84\" height=\"24\" alt=\"BBC\" /> </a> </div> <section> <div class=\"orb-skip-links\"> <h2>Accessibility links</h2> <ul> <li><a href=\"#page\">Skip to content</a></li> <li><a id=\"orb-accessibility-help\" href=\"/accessibility/\">Accessibility Help</a></li> </ul> </div> </section> <div class=\"orb-nav-section orb-nav-id orb-nav-focus orb-nav-id-default\"> <div id=\"idcta-statusbar\" class=\"orb-nav-section orb-nav-focus\"> <a id=\"idcta-link\" href=\"https://ssl.bbc.com/id/status?ptrt=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021\"> <img id=\"idcta-image\" src=\"http://static.bbci.co.uk/id/0.32.25/img/bbcid_orb_signin_dark.png\" alt=\"\" width=\"18\" height=\"18\" > <span id=\"idcta-username\">BBC iD</span> </a> </div> <script type=\"text/javascript\"> require(['idcta/statusbar'] function(statusbar) { new statusbar.Statusbar({\"id\":\"idcta-statusbar\" \"publiclyCacheable\":true}); }); </script> </div> <nav role=\"navigation\" class=\"orb-nav\"> <div class=\"orb-nav-section orb-nav-links orb-nav-focus\" id=\"orb-nav-links\"> <h2>BBC navigation</h2> <ul> <li class=\"orb-nav-news orb-d\" > <a href=\"http://www.bbc.co.uk/news/\">News</a> </li> <li class=\"orb-nav-newsdotcom orb-w\" > <a href=\"http://www.bbc.com/news/\">News</a> </li> <li class=\"orb-nav-sport\" > <a href=\"/sport/\">Sport</a> </li> <li class=\"orb-nav-weather\" > <a href=\"/weather/\">Weather</a> </li> <li class=\"orb-nav-shop orb-w\" > <a href=\"http://shop.bbc.com/\">Shop</a> </li> <li class=\"orb-nav-earthdotcom orb-w\" > <a href=\"http://www.bbc.com/earth/\">Earth</a> </li> <li class=\"orb-nav-travel-dotcom orb-w\" > <a href=\"http://www.bbc.com/travel/\">Travel</a> </li> <li class=\"orb-nav-capital orb-w\" > <a href=\"http://www.bbc.com/capital/\">Capital</a> </li> <li class=\"orb-nav-iplayer orb-d\" > <a href=\"/iplayer/\">iPlayer</a> </li> <li class=\"orb-nav-culture orb-w\" > <a href=\"http://www.bbc.com/culture/\">Culture</a> </li> <li class=\"orb-nav-autos orb-w\" > <a href=\"http://www.bbc.com/autos/\">Autos</a> </li> <li class=\"orb-nav-future orb-w\" > <a href=\"http://www.bbc.com/future/\">Future</a> </li> <li class=\"orb-nav-tv\" > <a href=\"/tv/\">TV</a> </li> <li class=\"orb-nav-radio\" > <a href=\"/radio/\">Radio</a> </li> <li class=\"orb-nav-cbbc\" > <a href=\"/cbbc\">CBBC</a> </li> <li class=\"orb-nav-cbeebies\" > <a href=\"/cbeebies\">CBeebies</a> </li> <li class=\"orb-nav-food\" > <a href=\"/food/\">Food</a> </li> <li class=\"orb-nav-arts orb-d\" > <a href=\"/arts/\">Arts</a> </li> <li class=\"orb-nav-makeitdigital\" > <a href=\"/makeitdigital\">Make It Digital</a> </li> <li > <a href=\"/iwonder\">iWonder</a> </li> <li > <a href=\"/education\">Bitesize</a> </li> <li class=\"orb-nav-music\" > <a href=\"/music/\">Music</a> </li> <li class=\"orb-nav-nature orb-w\" > <a href=\"/nature/\">Nature</a> </li> <li class=\"orb-nav-earth orb-d\" > <a href=\"http://www.bbc.com/earth/\">Earth</a> </li> <li class=\"orb-nav-local\" > <a href=\"/local/\">Local</a> </li> <li class=\"orb-nav-travel orb-d\" > <a href=\"/travel/\">Travel</a> </li> <li id=\"orb-nav-more\"><a href=\"#orb-footer\" data-alt=\"More\">Menu<span class=\"orb-icon orb-icon-arrow\"></span></a></li> </ul> </div> </nav> <div class=\"orb-nav-section orb-nav-search\"> <a href=\"http://search.bbc.co.uk/search\"> <img src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/img/orb-search-dark.png\" width=\"18\" height=\"18\" alt=\"Search the BBC\" /> </a> <form class=\"b-f\" id=\"orb-search-form\" role=\"search\" method=\"get\" action=\"http://search.bbc.co.uk/search\" accept-charset=\"utf-8\"> <div> <input type=\"hidden\" name=\"uri\" value=\"/news/technology-26415021\" /> <label for=\"orb-search-q\">Search the BBC</label> <input id=\"orb-search-q\" type=\"text\" name=\"q\" placeholder=\"Search\" /> <input type=\"image\" id=\"orb-search-button\" src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/img/orb-search-dark.png\" width=\"17\" height=\"17\" alt=\"Search the BBC\" /> <input type=\"hidden\" name=\"suggid\" id=\"orb-search-suggid\" /> </div> </form> </div> </div> <div id=\"orb-panels\" > <script type=\"text/template\" id=\"orb-panel-template\"><![CDATA[ <div id=\"orb-panel-<%= panelname %>\" class=\"orb-panel\" aria-labelledby=\"orb-nav-<%= panelname %>\"> <div class=\"orb-panel-content b-g-p b-r\"> <%= panelcontent %> </div> </div> ]]></script> </div> </div> </header> <!-- Styling hook for shared modules only --> <div id=\"orb-modules\"> \n",
      " <div id=\"site-container\">\n",
      " <!--[if lt IE 9]>\n",
      "<div class=\"browser-notify\">\n",
      " <div class=\"browser-notify__banner\">\n",
      " <div class=\"browser-notify__icon\"></div>\n",
      " <span>This site is optimised for modern web browsers and does not fully support your version of Internet Explorer</span>\n",
      " </div>\n",
      "</div>\n",
      "<![endif]-->\n",
      " <div class=\"site-brand site-brand--height\" role=\"banner\" aria-label=\"News\">\n",
      " <div class=\"site-brand-inner site-brand-inner--height\">\n",
      " <div class=\"navigation navigation--primary\">\n",
      " <a href=\"/news\" id=\"brand\">\n",
      " <svg class=\"brand__svg\" aria-label=\"BBC News\">\n",
      " <title>BBC News</title>\n",
      " <image xlink:href=\"http://static.bbci.co.uk/news/1.99.0479/img/brand/generated/news-light.svg\" src=\"http://static.bbci.co.uk/news/1.99.0479/img/brand/generated/news-light.png\" width=\"100%\" height=\"100%\"/>\n",
      " </svg>\n",
      " </a>\n",
      " <h2 class=\"navigation__heading off-screen\">News navigation</h2>\n",
      " <a href=\"#core-navigation\" class=\"navigation__section navigation__section--core\" data-event=\"header\">\n",
      " Sections </a>\n",
      " </div>\n",
      " </div>\n",
      " \n",
      "<div class=\"navigation navigation--wide\">\n",
      " <ul class=\"navigation-wide-list\" role=\"navigation\" aria-label=\"News\" data-panel-id=\"js-navigation-panel-primary\">\n",
      " <li>\n",
      " <a href=\"/news\" class=\"navigation-wide-list__link\">\n",
      " <span>Home</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/video_and_audio/international\" class=\"navigation-wide-list__link\">\n",
      " <span>Video</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/world\" data-panel-id=\"js-navigation-panel-World\" class=\"navigation-wide-list__link\">\n",
      " <span>World</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/uk\" data-panel-id=\"js-navigation-panel-UK\" class=\"navigation-wide-list__link\">\n",
      " <span>UK</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/business\" data-panel-id=\"js-navigation-panel-Business\" class=\"navigation-wide-list__link\">\n",
      " <span>Business</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"selected\">\n",
      " <a href=\"/news/technology\" class=\"navigation-wide-list__link navigation-arrow--open\">\n",
      " <span>Tech</span>\n",
      " </a>\n",
      " <span class=\"off-screen\">selected</span> </li>\n",
      " <li>\n",
      " <a href=\"/news/science_and_environment\" class=\"navigation-wide-list__link\">\n",
      " <span>Science</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/magazine\" class=\"navigation-wide-list__link\">\n",
      " <span>Magazine</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/entertainment_and_arts\" class=\"navigation-wide-list__link\">\n",
      " <span>Entertainment &amp; Arts</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/health\" class=\"navigation-wide-list__link\">\n",
      " <span>Health</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/in_pictures\" class=\"navigation-wide-list__link\">\n",
      " <span>In Pictures</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/also_in_the_news\" class=\"navigation-wide-list__link\">\n",
      " <span>Also in the News</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/special_reports\" class=\"navigation-wide-list__link\">\n",
      " <span>Special Reports</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/explainers\" class=\"navigation-wide-list__link\">\n",
      " <span>Explainers</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/the_reporters\" class=\"navigation-wide-list__link\">\n",
      " <span>The Reporters</span>\n",
      " </a>\n",
      " </li>\n",
      " <li>\n",
      " <a href=\"/news/have_your_say\" class=\"navigation-wide-list__link navigation-wide-list__link--last\">\n",
      " <span>Have Your Say</span>\n",
      " </a>\n",
      " </li>\n",
      " </ul>\n",
      "</div>\n",
      " </div>\n",
      " \n",
      " \n",
      " \n",
      "<div id=\"bbccom_leaderboard_1_2_3_4\" class=\"bbccom_slot \" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('leaderboard' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      " <div id=\"breaking-news-container\" data-polling-url=\"http://polling.bbc.co.uk/news/latest_breaking_news?audience=International\" aria-live=\"polite\"></div>\n",
      " <div class=\"container-width-only\">\n",
      " <span class=\"index-title index-title--redundant \" id=\"comp-index-title\" data-index-title-meta=\"{&quot;id&quot;:&quot;comp-index-title&quot; &quot;type&quot;:&quot;index-title&quot; &quot;handler&quot;:&quot;indexTitle&quot; &quot;deviceGroups&quot;:null &quot;opts&quot;:{&quot;alwaysVisible&quot;:false &quot;onFrontPage&quot;:false} &quot;template&quot;:&quot;index-title&quot;}\">\n",
      " <span class=\"index-title__container\">\n",
      " <a href=\"/news/technology\">Technology</a>\n",
      " </span>\n",
      " </span>\n",
      " \n",
      "<div id=\"bbccom_sponsor_section_1_2_3_4\" class=\"bbccom_slot \" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('sponsor_section' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      " </div>\n",
      " \n",
      " <div id=\"page\" class=\"configurable story \" data-story-id=\"technology-26415021\"> <div role=\"main\"> <div class=\"container-width-only\"> <span class=\"index-title index-title--redundant \" id=\"comp-index-title\" data-index-title-meta=\"{&quot;id&quot;:&quot;comp-index-title&quot; &quot;type&quot;:&quot;index-title&quot; &quot;handler&quot;:&quot;indexTitle&quot; &quot;deviceGroups&quot;:null &quot;opts&quot;:{&quot;alwaysVisible&quot;:false &quot;onFrontPage&quot;:false} &quot;template&quot;:&quot;index-title&quot;}\">\n",
      " <span class=\"index-title__container\">\n",
      " <a href=\"/news/technology\">Technology</a>\n",
      " </span>\n",
      " </span>\n",
      " \n",
      "<div id=\"bbccom_sponsor_section_1_2_3_4\" class=\"bbccom_slot \" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('sponsor_section' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      " </div> <div class=\"container\"> <div class=\"container--primary-and-secondary-columns column-clearfix\"> <div class=\"column--primary\">\n",
      " <div class=\"story-body\">\n",
      " <h1 class=\"story-body__h1\">An hour to catch the coding bug</h1>\n",
      " <div class=\"byline\">\n",
      " <span class=\"byline__name\">By Mark Ward</span>\n",
      " <span class=\"byline__title\">Technology correspondent BBC News</span>\n",
      " </div>\n",
      " \n",
      " <div class=\"story-body__mini-info-list-and-share\">\n",
      " <ul class=\"mini-info-list\">\n",
      " <li class=\"mini-info-list__item\"> <div class=\"date date--v2\" data-seconds=\"1393842175\" data-datetime=\"3 March 2014\">3 March 2014</div>\n",
      "</li>\n",
      " <li class=\"mini-info-list__item\"><span class=\"mini-info-list__section-desc off-screen\">From the section </span><a href=\"/news/technology\" class=\"mini-info-list__section\" data-entityid=\"section-label\">Technology</a></li>\n",
      "</ul>\n",
      " </div>\n",
      " <div class=\"story-body__inner\" property=\"articleBody\">\n",
      " <figure class=\"media-landscape has-caption full-width lead\">\n",
      " <span class=\"image-and-copyright-container\">\n",
      " \n",
      " <img class=\"js-image-replace\" alt=\"Child with computer\" src=\"http://ichef.bbci.co.uk/news/320/media/images/73325000/jpg/_73325163_olly009.jpg\" width=\"512\" height=\"320\">\n",
      " \n",
      " \n",
      " \n",
      " </span>\n",
      " \n",
      " <figcaption class=\"media-caption\">\n",
      " <span class=\"off-screen\">Image caption</span>\n",
      " <span class=\"media-caption__text\">\n",
      " We did our Hour of Code on a lazy Sunday morning\n",
      " </span>\n",
      " </figcaption>\n",
      " \n",
      " </figure><p class=\"story-body__introduction\">Okay 60 minutes and counting. Here we go.</p><p>I've got an hour to convince my kids that programming is for them.</p><p>Well sort of.</p><p>I'm putting my twin 10-year-old boys Toby and Callum through the Hour of Code - a campaign that seeks to ignite an interest in programming - the part we're doing using specially created web-based exercises. </p><p>The campaign begun in the US has landed in the UK where it also coincides with government calls for as many children as possible to get coding.</p><div id=\"bbccom_mpu_1_2_3\" class=\"bbccom_slot mpu-ad\" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /**/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('mpu' [1 2 3]);\n",
      " }\n",
      " })();\n",
      " /**/\n",
      " </script>\n",
      " </div>\n",
      "</div><p>Programming is being pushed because in an ever more technological world it can only be a good thing to give people a peep into what goes on behind the touch screen cash point and website. </p><p>The Hour of Code is supposed to be the start of that journey and I like many other parents feel it's one my children should be embarking on. I do feel like a clock somewhere is ticking and unless they get started with this essential skill they'll be left behind. </p><p>\"In the future kids are going to be doing programming \" said Callum when I asked him why it was worth learning how to code. \"We need to learn so we can do stuff with the computer otherwise it will be a blank page and never work.\"</p><h2 class=\"story-body__crosshead\">Zombie dance</h2><figure class=\"media-landscape has-caption full-width\">\n",
      " <span class=\"image-and-copyright-container\">\n",
      " \n",
      " \n",
      " <div class=\"js-delayed-image-load\" data-alt=\"Screenshot from the hour of code\" data-src=\"http://ichef-1.bbci.co.uk/news/320/media/images/73325000/jpg/_73325167_hourofcode.jpg\" data-width=\"512\" data-height=\"288\"></div>\n",
      " \n",
      " \n",
      " </span>\n",
      " \n",
      " <figcaption class=\"media-caption\">\n",
      " <span class=\"off-screen\">Image caption</span>\n",
      " <span class=\"media-caption__text\">\n",
      " The coding exercises involve familiar characters such as the Angry Birds\n",
      " </span>\n",
      " </figcaption>\n",
      " \n",
      " </figure> <div id=comp-story-recommendations\n",
      " class=\"hidden\"\n",
      " data-comp-meta=\"{&quot;id&quot;:&quot;comp-story-recommendations&quot; &quot;type&quot;:&quot;recommendations&quot; &quot;handler&quot;:&quot;default&quot; &quot;deviceGroups&quot;:null &quot;opts&quot;:{&quot;conditions&quot;:{&quot;feature_toggle&quot;:&quot;story_recommendations&quot; &quot;uri_contains&quot;:{&quot;show_if&quot;:&quot;\\/technology-&quot;}} &quot;id&quot;:&quot;story-recommendations&quot; &quot;loading_strategy&quot;:&quot;post_load&quot; &quot;link_location&quot;:&quot;news_recommendation&quot; &quot;hotspot&quot;:true &quot;asset_id&quot;:&quot;technology-26415021&quot; &quot;position_info&quot;:{&quot;instanceNo&quot;:1 &quot;positionInRegion&quot;:3 &quot;lastInRegion&quot;:false &quot;lastOnPage&quot;:false &quot;column&quot;:&quot;primary_column&quot;}}}\">\n",
      " </div> <p>It's the getting started for both parents and their offspring that the Hour is intended to help with. I'm probably like most parents in that I have no significant qualification in computer science. All I can offer my boys is a lifetime of tinkering backed up over the past 18 months with online courses in Python HTML CSS Javascript and the like. </p><p>There's good precedents for the value of something like the Hour of Code. I've quizzed every chief technology officer (CTO) developer or IT worker I've met in the past couple of weeks about what got them started and every one knew exactly the moment they got it. Their eyes lit up as they talked about typing in code listings from magazines working through every Dos command or designing their own blocky 8-bit game characters.</p><p>And finally at the back of my mind are all those statistics about the shortages of skilled IT staff and my hope that if this works then their future career options will be much wider than they would be without this skill.</p><p>So no pressure then.</p><p>Yesterday morning we gave it a go. I was keen for it to be fun rather than feel like school as there's nothing more likely to turn them off than for it to be sold as good for them. I think we struck the right note of informality - Cal did it in his onesie. </p><p>It went OK no better than that. Pretty good. We worked through all the exercises getting angry birds to mash pigs and zombies to chomp sunflowers. The coding is done by dragging blocks representing different commands into a work area and building the blocks into a tower of coherent instructions.</p><p>The block-building system is based on the Scratch programming language build by MIT's Mitch Resnick. </p><p>The exercises start easy - just getting an angry bird to hop on to a pig. By the end we were using \"If… else\" statements and loops to help a zombie navigate a tricky maze to reach the sunflower.</p><p>This went down well with Callum. \"Cool! It's scanning for a path \" he said as the zombie worked its way towards the hapless flower.</p><p>Mistakes were made but we learned from them we debated over which way to make the birds and zombies turn and the time went really fast. </p><p>Toby was surprised to find that this counted as programming.</p><p>\"I thought coding was just a lot of people tapping in letter and numbers until they got it right \" he said. </p><h2 class=\"story-body__crosshead\">Next steps</h2><p>And yet I felt it was a bit too easy. I wanted to make the coding connection to real life more tangible. So as we had about 15 minutes of our Hour of Code left we went further.</p><p>This time we used the MIT App Inventor to build a basic program that would run on the tablets they own. </p><p>The app inventor uses the same \"drag the block\" method to build a program and following the instructions we had soon created an app that turned anything typed in text into speech. </p><figure class=\"media-landscape has-caption body-narrow-width\">\n",
      " <span class=\"image-and-copyright-container\">\n",
      " \n",
      " \n",
      " <div class=\"js-delayed-image-load\" data-alt=\"Screenshot from MIT App Inventor\" data-src=\"http://ichef-1.bbci.co.uk/news/320/media/images/73325000/jpg/_73325169_appinventor.jpg\" data-width=\"448\" data-height=\"287\"></div>\n",
      " \n",
      " \n",
      " </span>\n",
      " \n",
      " <figcaption class=\"media-caption\">\n",
      " <span class=\"off-screen\">Image caption</span>\n",
      " <span class=\"media-caption__text\">\n",
      " The App Inventor uses the same block dragging system as the Hour of Code exercises\n",
      " </span>\n",
      " </figcaption>\n",
      " \n",
      " </figure><p>We got it working on Cal's tablet and soon they were getting that gadget to call out lots of phrases. Almost inevitably as they are 10 years old a lot of these phrases involved the words \"willy\" and \"bum\". </p><p>But they had a lot of fun with it and it brought home to them how straight-forward coding can be. In just over an hour they went from being pretty much novices to creating an Android app - a basic one that trades on the expertise of the people that built the coding tools but it was an accomplishment nonetheless.</p><p>Did they catch the coding bug as a result? </p><p>Maybe later in the day they were programming each other after one of their regular wrestling matches left Toby lying exhausted on the floor. Suddenly Cal called out commands such as \"roll left\" and Toby started obeying even to the point of crashing into the sofa when too many roll commands were given. </p><p>Then Toby had his turn and did the same they even worked out that they had to compensate for the changes in left and right as they rolled. </p><p>So I think that hour started something. Both with them and with me. Building that Android app made me realise that it is straight-forward. That my lack of formal qualifications do not matter as much as I thought. And maybe that's the point of the hour. Making people realise that it is not scary and difficult. You just have to find an hour and give it a try. You can even do it in your onesie.</p>\n",
      " </div>\n",
      "</div>\n",
      " <div class=\"share share--lightweight show ghost-column\">\n",
      " <a name=\"share-tools\"></a>\n",
      " <h2 class=\"share__title share__title--lightweight\">\n",
      " Share this story <a href=\"http://www.bbc.co.uk/help/web/sharing.shtml\">About&nbsp;sharing</a>\n",
      " </h2>\n",
      " <ul class=\"share__tools share__tools--lightweight\">\n",
      " <li class=\"share__tool share__tool--email\">\n",
      " <a href=\"mailto:?subject=Shared%20from%20BBC%20News&body=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021\" >\n",
      " <span>Email</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"share__tool share__tool--facebook\">\n",
      " <a href=\"http://www.facebook.com/dialog/feed?app_id=58567469885&redirect_uri=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021&link=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021%3FSThisFB\" >\n",
      " <span>Facebook</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"share__tool share__tool--twitter\">\n",
      " <a href=\"https://twitter.com/intent/tweet?text=BBC%20News%20-%20An%20hour%20to%20catch%20the%20coding%20bug&url=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021\" class=shortenUrl data-social-url=https://twitter.com/intent/tweet?text=BBC+News+-+An+hour+to+catch+the+coding+bug&amp;url= data-target-url=http://www.bbc.com/news/technology-26415021>\n",
      " <span>Twitter</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"share__tool share__tool--whatsapp\">\n",
      " <a href=\"whatsapp://send?text=BBC%20News%20%7C%20An%20hour%20to%20catch%20the%20coding%20bug%20-%20http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021%3Focid%3Dwsnews.chat-apps.in-app-msg.whatsapp.trial.link1_.auin\" >\n",
      " <span>WhatsApp</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"share__tool share__tool--linkedin\">\n",
      " <a href=\"https://www.linkedin.com/shareArticle?mini=true&url=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021&title=An%20hour%20to%20catch%20the%20coding%20bug&summary=Is%20it%20possible%20to%20get%20children%20interested%20in%20computer%20programming%20in%20just%2060%20minutes%3F%20The%20Hour%20of%20Code%20has%20been%20designed%20to%20do%20just%20that.&source=BBC\" >\n",
      " <span>Linkedin</span>\n",
      " </a>\n",
      " </li>\n",
      " </ul>\n",
      "</div>\n",
      " <div class=\"story-more\">\n",
      " <div class=\"group story-alsos more-on-this-story\"> <div class=\"group__header\"> <h2 class=\"group__title\">More on this story</h2> </div> <div class=\"group__body\"> <ul class=\"units-list \"> <li class=\"unit unit--regular\" data-entityid=\"more-on-this-story#1\" > <a href=\"/news/education-25648769\" class=\"unit__link-wrapper\"> <div class=\"unit__body\"> <div class=\"unit__header\"> <div class=\"unit__title\"> \n",
      " <span class=\"icon-new icon-new--video-square-red\"><span class=\"off-screen\"> Video</span></span>\n",
      " \n",
      " \n",
      " <span class=\"cta\"> Computer coding taught in Estonian primary schools </span> </div> <div class=\"unit__meta\"> <div class=\"date date--v1\" data-seconds=\"1389169705\" data-datetime=\"8 January 2014\">8 January 2014</div> </div> </div> </div> </a> </li> <li class=\"unit unit--regular\" data-entityid=\"more-on-this-story#2\" > <a href=\"/news/technology-26150717\" class=\"unit__link-wrapper\"> <div class=\"unit__body\"> <div class=\"unit__header\"> <div class=\"unit__title\"> <span class=\"cta\"> Year of Code - PR fiasco or vital mission? </span> </div> <div class=\"unit__meta\"> <div class=\"date date--v1\" data-seconds=\"1392196197\" data-datetime=\"12 February 2014\">12 February 2014</div> </div> </div> </div> </a> </li> <li class=\"unit unit--regular\" data-entityid=\"more-on-this-story#3\" > <a href=\"/news/technology-25857276\" class=\"unit__link-wrapper\"> <div class=\"unit__body\"> <div class=\"unit__header\"> <div class=\"unit__title\"> <span class=\"cta\"> Are teachers ready for the coding revolution? </span> </div> <div class=\"unit__meta\"> <div class=\"date date--v1\" data-seconds=\"1390468159\" data-datetime=\"23 January 2014\">23 January 2014</div> </div> </div> </div> </a> </li> </ul> </div> </div> </div>\n",
      " \n",
      "<div class=\"story-more\">\n",
      " <div class=\"group related-links--external more-on-this-story\"> <div class=\"group__header\"> <h2 class=\"group__title\">Related Internet links</h2> </div> <div class=\"group__body\"> <ul class=\"units-list \"> <li class=\"unit unit--headline\" data-entityid=\"more-on-this-story#1\" > <div class=\"unit__body\"> <div class=\"unit__header\"> <a class=\"unit__link-wrapper\" href=\"http://uk.code.org/\"> <div class=\"unit__title\"> <span class=\"cta\">UK Hour of Code</span> </div> </a> </div> </div> </li> <li class=\"unit unit--headline\" data-entityid=\"more-on-this-story#2\" > <div class=\"unit__body\"> <div class=\"unit__header\"> <a class=\"unit__link-wrapper\" href=\"http://appinventor.mit.edu/explore/\"> <div class=\"unit__title\"> <span class=\"cta\">MIT App Inventor</span> </div> </a> </div> </div> </li> <li class=\"unit unit--headline\" data-entityid=\"more-on-this-story#3\" > <div class=\"unit__body\"> <div class=\"unit__header\"> <a class=\"unit__link-wrapper\" href=\"http://scratch.mit.edu/\"> <div class=\"unit__title\"> <span class=\"cta\">MIT Scratch</span> </div> </a> </div> </div> </li> </ul> </div> </div> \n",
      " <p class=\"unit__meta\">The BBC is not responsible for the content of external Internet sites</p>\n",
      "</div>\n",
      " <div id=comp-pattern-library\n",
      " class=\"hidden\"\n",
      " data-post-load-url=\"/news/pattern-library-components?options%5Bcontainer_class%5D=container-more-from-this-index&amp;options%5Bdata%5D%5Bsource%5D=candy_parent_index&amp;options%5Bdata%5D%5Bsource_params%5D%5Bsection_title%5D=1&amp;options%5Bcomponents%5D%5B0%5D%5Bname%5D=sparrow&amp;options%5Bcomponents%5D%5B0%5D%5Blimit%5D=3&amp;options%5Bloading_strategy%5D=post_load&amp;options%5Bstats%5D%5Blink_location%5D=more-section&amp;options%5Basset_id%5D=technology-26415021&amp;presenter=pattern-library-presenter\">\n",
      " </div> <div id=comp-from-other-news-sites\n",
      " class=\"hidden\"\n",
      " data-comp-meta=\"{&quot;id&quot;:&quot;comp-from-other-news-sites&quot; &quot;type&quot;:&quot;from-other-news-sites&quot; &quot;handler&quot;:&quot;default&quot; &quot;deviceGroups&quot;:null &quot;opts&quot;:{&quot;conditions&quot;:[&quot;is_local_page&quot;] &quot;loading_strategy&quot;:&quot;post_load&quot; &quot;asset_id&quot;:&quot;technology-26415021&quot; &quot;position_info&quot;:{&quot;instanceNo&quot;:1 &quot;positionInRegion&quot;:10 &quot;lastInRegion&quot;:true &quot;lastOnPage&quot;:false &quot;column&quot;:&quot;primary_column&quot;}} &quot;template&quot;:&quot;\\/component\\/from-other-news-sites&quot;}\">\n",
      " </div> \n",
      "<div id=\"bbccom_outbrain_ar_5_1_2_3_4\" class=\"bbccom_slot outbrain-ad\" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('outbrain_ar_5' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      "<div id=\"bbccom_outbrain_ar_7_1_2_3_4\" class=\"bbccom_slot outbrain-ad\" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('outbrain_ar_7' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      "<div id=\"bbccom_outbrain_ar_8_1_2_3_4\" class=\"bbccom_slot outbrain-ad\" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('outbrain_ar_8' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      " </div>\n",
      " <div class=\"column--secondary\" role=\"complementary\">\n",
      " <div id=\"comp-top-stories-promo\" class=\"top-stories-promo\">\n",
      " <h2 class=\"top-stories-promo__title\">Top Stories</h2>\n",
      " <a href=\"/news/world-europe-34933608\" class=\"top-stories-promo-story\" data-asset-id=\"/news/world-europe-34933608\"data-entityid=\"top-stories#1\">\n",
      " <strong class=\"top-stories-promo-story__title\">Russia 'plans sanctions against Turkey'</strong>\n",
      " <p class=\"top-stories-promo-story__summary top-stories-promo-story__summary--none\">Russia is preparing wide-ranging economic sanctions against Turkey after the downing of one of its jets Prime Minister Dmitry Medvedev says.</p>\n",
      " <div class=\"date date--v2\" data-seconds=\"1448556072\" data-datetime=\"26 November 2015\">26 November 2015</div>\n",
      " </a>\n",
      " <a href=\"/news/world-europe-34933500\" class=\"top-stories-promo-story\" data-asset-id=\"/news/world-europe-34933500\"data-entityid=\"top-stories#3\">\n",
      " <strong class=\"top-stories-promo-story__title\">Brussels threat level reduced</strong>\n",
      " <div class=\"date date--v2\" data-seconds=\"1448556876\" data-datetime=\"26 November 2015\">26 November 2015</div>\n",
      " </a>\n",
      " <a href=\"/news/world-us-canada-34930042\" class=\"top-stories-promo-story\" data-asset-id=\"/news/world-us-canada-34930042\"data-entityid=\"top-stories#5\">\n",
      " <strong class=\"top-stories-promo-story__title\">Trump mocks disabled reporter</strong>\n",
      " <div class=\"date date--v2\" data-seconds=\"1448528751\" data-datetime=\"26 November 2015\">26 November 2015</div>\n",
      " </a>\n",
      " </div> \n",
      "<div id=\"bbccom_mpu_4\" class=\"bbccom_slot mpu-ad\" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('mpu' [4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      " <div class=\"hotspot hotspot--empty hotspot--hidden\"></div>\n",
      " \n",
      "<div class=\"features-and-analysis\" id=\"comp-features-and-analysis\" >\n",
      " <h2 class=\"features-and-analysis__title\">\n",
      " \n",
      " Features &amp; Analysis\n",
      " </h2>\n",
      " <div class=\"features-and-analysis__stories promo-unit-spacer\">\n",
      " \n",
      " <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#1\">\n",
      " <a href=\"/news/magazine-34928547\" class=\"bold-image-promo\">\n",
      " <div class=\"bold-image-promo__image\">\n",
      " <div class=\"responsive-image responsive-image--16by9\">\n",
      " <div class=\"responsive-image__inner-for-label\">\n",
      " <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/4D9C/production/_86886891__73250751_020647244-1.jpg\" data-width=\"976\" data-height=\"549\" data-alt=\"Fighters from the so called Islamic State (ISIS) in Raqqa\"></div>\n",
      " <!--[if lt IE 9]>\n",
      " <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/4D9C/production/_86886891__73250751_020647244-1.jpg\" class=\"js-image-replace\" alt=\"Fighters from the so called Islamic State (ISIS) in Raqqa\" width=\"976\" height=\"549\" />\n",
      " <![endif]-->\n",
      " \n",
      " <div class=\"responsive-image__label\" aria-hidden=\"true\">\n",
      " <span class=\"icon video\"><span class=\"off-screen\"> Video</span></span>\n",
      " \n",
      " \n",
      " \n",
      " <span class=\"responsive-image__label-text\">3:23</span>\n",
      " </div>\n",
      " </div>\n",
      " </div>\n",
      " </div>\n",
      " <h3 class=\"bold-image-promo__title\">Silent slaughter</h3>\n",
      " <p class=\"bold-image-promo__summary\">Capturing daily life in Raqqa under Islamic State </p>\n",
      " </a>\n",
      " </div>\n",
      " \n",
      " \n",
      " <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#2\">\n",
      " <a href=\"/news/magazine-34858199\" class=\"bold-image-promo\">\n",
      " <div class=\"bold-image-promo__image\">\n",
      " <div class=\"responsive-image responsive-image--16by9\">\n",
      " \n",
      " <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/12B7C/production/_86886667_angel_bbc.jpg\" data-width=\"511\" data-height=\"287\" data-alt=\"Dave Angel\"></div>\n",
      " <!--[if lt IE 9]>\n",
      " <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/12B7C/production/_86886667_angel_bbc.jpg\" class=\"js-image-replace\" alt=\"Dave Angel\" width=\"511\" height=\"287\" />\n",
      " <![endif]-->\n",
      " </div>\n",
      " </div>\n",
      " <h3 class=\"bold-image-promo__title\">Say what?</h3>\n",
      " <p class=\"bold-image-promo__summary\">Is this the subject with the most baffling jargon?</p>\n",
      " </a>\n",
      " </div>\n",
      " \n",
      " \n",
      " <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#3\">\n",
      " <a href=\"/news/magazine-34920068\" class=\"bold-image-promo\">\n",
      " <div class=\"bold-image-promo__image\">\n",
      " <div class=\"responsive-image responsive-image--16by9\">\n",
      " \n",
      " <div class=\"js-delayed-image-load\" data-src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/FB8E/production/_86889346_promo1.jpg\" data-width=\"976\" data-height=\"549\" data-alt=\"Man standing near grave\"></div>\n",
      " <!--[if lt IE 9]>\n",
      " <img src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/FB8E/production/_86889346_promo1.jpg\" class=\"js-image-replace\" alt=\"Man standing near grave\" width=\"976\" height=\"549\" />\n",
      " <![endif]-->\n",
      " </div>\n",
      " </div>\n",
      " <h3 class=\"bold-image-promo__title\">The other crisis</h3>\n",
      " <p class=\"bold-image-promo__summary\">Why Greeks are exhuming their parents' bodies</p>\n",
      " </a>\n",
      " </div>\n",
      " \n",
      " \n",
      " <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#4\">\n",
      " <a href=\"/news/world-europe-34931467\" class=\"bold-image-promo\">\n",
      " <div class=\"bold-image-promo__image\">\n",
      " <div class=\"responsive-image responsive-image--16by9\">\n",
      " \n",
      " <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/DC63/production/_86891465_26nov_isis-raqqa_ap.jpg\" data-width=\"976\" data-height=\"549\" data-alt=\"Islamic State militants hold up their weapons and wave flags as they ride in a convoy which includes multiple Toyota pickup trucks through Raqqa city in Syria\"></div>\n",
      " <!--[if lt IE 9]>\n",
      " <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/DC63/production/_86891465_26nov_isis-raqqa_ap.jpg\" class=\"js-image-replace\" alt=\"Islamic State militants hold up their weapons and wave flags as they ride in a convoy which includes multiple Toyota pickup trucks through Raqqa city in Syria\" width=\"976\" height=\"549\" />\n",
      " <![endif]-->\n",
      " </div>\n",
      " </div>\n",
      " <h3 class=\"bold-image-promo__title\">Spiral of violence </h3>\n",
      " <p class=\"bold-image-promo__summary\">Death toll from jihadist groups continues to rise</p>\n",
      " </a>\n",
      " </div>\n",
      " \n",
      " \n",
      " <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#5\">\n",
      " <a href=\"/news/world-africa-34924351\" class=\"bold-image-promo\">\n",
      " <div class=\"bold-image-promo__image\">\n",
      " <div class=\"responsive-image responsive-image--16by9\">\n",
      " \n",
      " <div class=\"js-delayed-image-load\" data-src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/9053/production/_86874963_kobeindex.jpg\" data-width=\"976\" data-height=\"549\" data-alt=\"Kobina Graham\"></div>\n",
      " <!--[if lt IE 9]>\n",
      " <img src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/9053/production/_86874963_kobeindex.jpg\" class=\"js-image-replace\" alt=\"Kobina Graham\" width=\"976\" height=\"549\" />\n",
      " <![endif]-->\n",
      " </div>\n",
      " </div>\n",
      " <h3 class=\"bold-image-promo__title\">Back to Africa</h3>\n",
      " <p class=\"bold-image-promo__summary\">Young professionals leave London and head to Ghana</p>\n",
      " </a>\n",
      " </div>\n",
      " \n",
      " \n",
      " <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#6\">\n",
      " <a href=\"/news/blogs-trending-34922821\" class=\"bold-image-promo\">\n",
      " <div class=\"bold-image-promo__image\">\n",
      " <div class=\"responsive-image responsive-image--16by9\">\n",
      " \n",
      " <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/39D8/production/_86880841_turkey.jpg\" data-width=\"2048\" data-height=\"1152\" data-alt=\"Turkey float at Thanksgiving parade in New York City\"></div>\n",
      " <!--[if lt IE 9]>\n",
      " <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/39D8/production/_86880841_turkey.jpg\" class=\"js-image-replace\" alt=\"Turkey float at Thanksgiving parade in New York City\" width=\"2048\" height=\"1152\" />\n",
      " <![endif]-->\n",
      " </div>\n",
      " </div>\n",
      " <h3 class=\"bold-image-promo__title\">Thanksgiving humour</h3>\n",
      " <p class=\"bold-image-promo__summary\">How black white Mexican Jewish Asian and other families celebrate</p>\n",
      " </a>\n",
      " </div>\n",
      " \n",
      " \n",
      " <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#7\">\n",
      " <a href=\"/news/business-34897955\" class=\"bold-image-promo\">\n",
      " <div class=\"bold-image-promo__image\">\n",
      " <div class=\"responsive-image responsive-image--16by9\">\n",
      " \n",
      " <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/1104/production/_86865340_img_3525.jpg\" data-width=\"2048\" data-height=\"1152\" data-alt=\"An image from a Prison Art t-shirt\"></div>\n",
      " <!--[if lt IE 9]>\n",
      " <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/1104/production/_86865340_img_3525.jpg\" class=\"js-image-replace\" alt=\"An image from a Prison Art t-shirt\" width=\"2048\" height=\"1152\" />\n",
      " <![endif]-->\n",
      " </div>\n",
      " </div>\n",
      " <h3 class=\"bold-image-promo__title\">Firms behind bars</h3>\n",
      " <p class=\"bold-image-promo__summary\">The businesses offering hope to Mexican prisoners</p>\n",
      " </a>\n",
      " </div>\n",
      " \n",
      " \n",
      " <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#8\">\n",
      " <a href=\"/news/world-asia-34837187\" class=\"bold-image-promo\">\n",
      " <div class=\"bold-image-promo__image\">\n",
      " <div class=\"responsive-image responsive-image--16by9\">\n",
      " \n",
      " <div class=\"js-delayed-image-load\" data-src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/14013/production/_86793918_img_4098.jpg\" data-width=\"976\" data-height=\"549\" data-alt=\"There's still a front line near Kunduz with some districts and villages controlled by the Taliban\"></div>\n",
      " <!--[if lt IE 9]>\n",
      " <img src=\"http://ichef.bbci.co.uk/news/304/cpsprodpb/14013/production/_86793918_img_4098.jpg\" class=\"js-image-replace\" alt=\"There's still a front line near Kunduz with some districts and villages controlled by the Taliban\" width=\"976\" height=\"549\" />\n",
      " <![endif]-->\n",
      " </div>\n",
      " </div>\n",
      " <h3 class=\"bold-image-promo__title\">After the Taliban</h3>\n",
      " <p class=\"bold-image-promo__summary\">Kunduz a city still scarred and in shock</p>\n",
      " </a>\n",
      " </div>\n",
      " \n",
      " \n",
      " <div class=\"features-and-analysis__story\" data-entityid=\"features-and-analysis#9\">\n",
      " <a href=\"/news/entertainment-arts-34811138\" class=\"bold-image-promo\">\n",
      " <div class=\"bold-image-promo__image\">\n",
      " <div class=\"responsive-image responsive-image--16by9\">\n",
      " \n",
      " <div class=\"js-delayed-image-load\" data-src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/18125/production/_86679589_bridge-of-spies-rylance-ap.jpg\" data-width=\"2048\" data-height=\"1152\" data-alt=\"Mark Rylance\"></div>\n",
      " <!--[if lt IE 9]>\n",
      " <img src=\"http://ichef-1.bbci.co.uk/news/304/cpsprodpb/18125/production/_86679589_bridge-of-spies-rylance-ap.jpg\" class=\"js-image-replace\" alt=\"Mark Rylance\" width=\"2048\" height=\"1152\" />\n",
      " <![endif]-->\n",
      " </div>\n",
      " </div>\n",
      " <h3 class=\"bold-image-promo__title\">From spy to BFG</h3>\n",
      " <p class=\"bold-image-promo__summary\">Mark Rylance on the biggest film roles of his career</p>\n",
      " </a>\n",
      " </div>\n",
      " \n",
      " </div>\n",
      "</div>\n",
      " \n",
      "<div id=\"bbccom_native_1_2_3_4\" class=\"bbccom_slot native-ad\" >\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('native' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      " <div id=comp-most-popular\n",
      " class=\"hidden\"\n",
      " data-comp-meta=\"{&quot;id&quot;:&quot;comp-most-popular&quot; &quot;type&quot;:&quot;most-popular&quot; &quot;handler&quot;:&quot;mostPopular&quot; &quot;deviceGroups&quot;:null &quot;opts&quot;:{&quot;loading_strategy&quot;:&quot;post_load&quot; &quot;position_info&quot;:{&quot;instanceNo&quot;:1 &quot;positionInRegion&quot;:4 &quot;lastInRegion&quot;:true &quot;lastOnPage&quot;:true &quot;column&quot;:&quot;secondary_column&quot;}}}\">\n",
      " </div> \n",
      "<div id=\"bbccom_mpu_bottom_1_2_3_4\" class=\"bbccom_slot mpu-bottom-ad\" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('mpu_bottom' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      "<div id=\"bbccom_outbrain_ar_9_1_2_3_4\" class=\"bbccom_slot outbrain-ad\" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('outbrain_ar_9' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      "<div id=\"bbccom_adsense_1_2_3_4\" class=\"bbccom_slot adsense-ad\" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('adsense' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      "<div id=\"bbccom_inread_1_2_3_4\" class=\"bbccom_slot inread\" aria-hidden=\"true\">\n",
      " <div class=\"bbccom_advert\">\n",
      " <script type=\"text/javascript\">\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('inread' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " </script>\n",
      " </div>\n",
      "</div>\n",
      " </div>\n",
      " </div> </div> </div> </div> \n",
      " \n",
      "<div id=\"core-navigation\" class=\"navigation--footer\">\n",
      " <h2 class=\"navigation--footer__heading\">News navigation</h2>\n",
      " \n",
      " <nav id=\"navigation--bottom\" class=\"navigation navigation--bottom \" role=\"navigation\" aria-label=\"News\">\n",
      " <span class=\"navigation-core-title\">Sections</span>\n",
      " <ul class=\"navigation--bottom__toplevel\">\n",
      " <li class=\"\">\n",
      " <a href=\"/news\" class=\"\">\n",
      " <span>Home</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/video_and_audio/international\" class=\"\">\n",
      " <span>Video</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/world\" data-panel-id=\"js-navigation-panel-World\" class=\"navigation-arrow\">\n",
      " <span>World</span>\n",
      " </a>\n",
      " <div class=\"navigation-panel navigation-panel--closed js-navigation-panel-World\">\n",
      " <div class=\"navigation-panel__content\">\n",
      " <ul class=\"navigation-panel-secondary\">\n",
      " <li><a href=\"/news/world\"><span>World Home</span></a></li>\n",
      " <li>\n",
      " <a href=\"/news/world/africa\"><span>Africa</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/world/asia\"><span>Asia</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/world/australia\"><span>Australia</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/world/europe\"><span>Europe</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/world/latin_america\"><span>Latin America</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/world/middle_east\"><span>Middle East</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/world/us_and_canada\"><span>US &amp; Canada</span></a> </li>\n",
      " </ul>\n",
      " </div>\n",
      " </div>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/uk\" data-panel-id=\"js-navigation-panel-UK\" class=\"navigation-arrow\">\n",
      " <span>UK</span>\n",
      " </a>\n",
      " <div class=\"navigation-panel navigation-panel--closed js-navigation-panel-UK\">\n",
      " <div class=\"navigation-panel__content\">\n",
      " <ul class=\"navigation-panel-secondary\">\n",
      " <li><a href=\"/news/uk\"><span>UK Home</span></a></li>\n",
      " <li>\n",
      " <a href=\"/news/england\"><span>England</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/northern_ireland\"><span>N. Ireland</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/scotland\"><span>Scotland</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/wales\"><span>Wales</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/politics\"><span>Politics</span></a> </li>\n",
      " </ul>\n",
      " </div>\n",
      " </div>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/business\" data-panel-id=\"js-navigation-panel-Business\" class=\"navigation-arrow\">\n",
      " <span>Business</span>\n",
      " </a>\n",
      " <div class=\"navigation-panel navigation-panel--closed js-navigation-panel-Business\">\n",
      " <div class=\"navigation-panel__content\">\n",
      " <ul class=\"navigation-panel-secondary\">\n",
      " <li><a href=\"/news/business\"><span>Business Home</span></a></li>\n",
      " <li>\n",
      " <a href=\"http://www.bbc.co.uk/news/business/market_data\"><span>Market Data</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/business/markets\"><span>Markets</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/business/economy\"><span>Economy</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/business/companies\"><span>Companies</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/business-22434141\"><span>Entrepreneurship</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/business-11428889\"><span>Technology of Business</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/business/business_of_sport\"><span>Business of Sport</span></a> </li>\n",
      " <li>\n",
      " <a href=\"/news/business-12686570\"><span>Knowledge economy</span></a> </li>\n",
      " </ul>\n",
      " </div>\n",
      " </div>\n",
      " </li>\n",
      " <li class=\"selected \">\n",
      " <a href=\"/news/technology\" class=\"navigation-arrow--open\">\n",
      " <span>Tech</span>\n",
      " </a>\n",
      " <span class=\"off-screen\">selected</span> </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/science_and_environment\" class=\"\">\n",
      " <span>Science</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/magazine\" class=\"\">\n",
      " <span>Magazine</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/entertainment_and_arts\" class=\"\">\n",
      " <span>Entertainment &amp; Arts</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/health\" class=\"\">\n",
      " <span>Health</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/in_pictures\" class=\"\">\n",
      " <span>In Pictures</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/also_in_the_news\" class=\"\">\n",
      " <span>Also in the News</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/special_reports\" class=\"\">\n",
      " <span>Special Reports</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/explainers\" class=\"\">\n",
      " <span>Explainers</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/the_reporters\" class=\"\">\n",
      " <span>The Reporters</span>\n",
      " </a>\n",
      " </li>\n",
      " <li class=\"\">\n",
      " <a href=\"/news/have_your_say\" class=\"\">\n",
      " <span>Have Your Say</span>\n",
      " </a>\n",
      " </li>\n",
      " </ul>\n",
      " </nav>\n",
      "</div>\n",
      " <div id=\"services-bar\" class=\"blue-tit\" role=\"navigation\" aria-label=\"BBC News Services\">\n",
      " <div class=\"blue-tit__inner\">\n",
      " <h2 class=\"blue-tit__title\">BBC News Services</h2>\n",
      " <ul class=\"blue-tit__list\">\n",
      " <li class=\"blue-tit__list-item\">\n",
      " <a href=\"http://www.bbc.co.uk/news/10628994\" class=\"blue-tit__list-item-link mobile\">On your mobile</a>\n",
      " </li>\n",
      " <li class=\"blue-tit__list-item\">\n",
      " <a href=\"http://www.bbc.co.uk/news/help-17655000\" class=\"blue-tit__list-item-link connected-tv\">On your connected TV</a>\n",
      " </li>\n",
      " <li class=\"blue-tit__list-item\">\n",
      " <a href=\"http://www.bbc.co.uk/news/10628323\" class=\"blue-tit__list-item-link newsletter\">Get news alerts</a>\n",
      " </li>\n",
      " <li class=\"blue-tit__list-item\">\n",
      " <a href=\"http://www.bbc.co.uk/news/20039682\" class=\"blue-tit__list-item-link contact-us\">Contact BBC News</a>\n",
      " </li>\n",
      " </ul>\n",
      " </div>\n",
      "</div>\n",
      " </div><!-- closes #site-container --> </div> <div id=\"orb-footer\" class=\"orb-footer orb-footer-grey b-footer--grey--white\" > <div id=\"navp-orb-footer-promo\" class=\"orb-footer-grey\"></div> <aside role=\"complementary\"> <div id=\"orb-aside\" class=\"orb-nav-sec b-r b-g-p\"> <div class=\"orb-footer-inner\" role=\"navigation\"> <h2 class=\"orb-footer-lead\">Explore the BBC</h2> <div class=\"orb-footer-primary-links\"> <ul> <li class=\"orb-nav-news orb-d\" > <a href=\"http://www.bbc.co.uk/news/\">News</a> </li> <li class=\"orb-nav-newsdotcom orb-w\" > <a href=\"http://www.bbc.com/news/\">News</a> </li> <li class=\"orb-nav-sport\" > <a href=\"/sport/\">Sport</a> </li> <li class=\"orb-nav-weather\" > <a href=\"/weather/\">Weather</a> </li> <li class=\"orb-nav-shop orb-w\" > <a href=\"http://shop.bbc.com/\">Shop</a> </li> <li class=\"orb-nav-earthdotcom orb-w\" > <a href=\"http://www.bbc.com/earth/\">Earth</a> </li> <li class=\"orb-nav-travel-dotcom orb-w\" > <a href=\"http://www.bbc.com/travel/\">Travel</a> </li> <li class=\"orb-nav-capital orb-w\" > <a href=\"http://www.bbc.com/capital/\">Capital</a> </li> <li class=\"orb-nav-iplayer orb-d\" > <a href=\"/iplayer/\">iPlayer</a> </li> <li class=\"orb-nav-culture orb-w\" > <a href=\"http://www.bbc.com/culture/\">Culture</a> </li> <li class=\"orb-nav-autos orb-w\" > <a href=\"http://www.bbc.com/autos/\">Autos</a> </li> <li class=\"orb-nav-future orb-w\" > <a href=\"http://www.bbc.com/future/\">Future</a> </li> <li class=\"orb-nav-tv\" > <a href=\"/tv/\">TV</a> </li> <li class=\"orb-nav-radio\" > <a href=\"/radio/\">Radio</a> </li> <li class=\"orb-nav-cbbc\" > <a href=\"/cbbc\">CBBC</a> </li> <li class=\"orb-nav-cbeebies\" > <a href=\"/cbeebies\">CBeebies</a> </li> <li class=\"orb-nav-food\" > <a href=\"/food/\">Food</a> </li> <li class=\"orb-nav-arts orb-d\" > <a href=\"/arts/\">Arts</a> </li> <li class=\"orb-nav-makeitdigital\" > <a href=\"/makeitdigital\">Make It Digital</a> </li> <li > <a href=\"/iwonder\">iWonder</a> </li> <li > <a href=\"/education\">Bitesize</a> </li> <li class=\"orb-nav-music\" > <a href=\"/music/\">Music</a> </li> <li class=\"orb-nav-nature orb-w\" > <a href=\"/nature/\">Nature</a> </li> <li class=\"orb-nav-earth orb-d\" > <a href=\"http://www.bbc.com/earth/\">Earth</a> </li> <li class=\"orb-nav-local\" > <a href=\"/local/\">Local</a> </li> <li class=\"orb-nav-travel orb-d\" > <a href=\"/travel/\">Travel</a> </li> </ul> </div> </div> </div> </aside> <footer role=\"contentinfo\"> <div id=\"orb-contentinfo\" class=\"orb-nav-sec b-r b-g-p\"> <div class=\"orb-footer-inner\"> <ul> <li > <a href=\"/terms/\">Terms of Use</a> </li> <li > <a href=\"/aboutthebbc/\">About the BBC</a> </li> <li > <a href=\"/privacy/\">Privacy Policy</a> </li> <li > <a href=\"/privacy/cookies/about\">Cookies</a> </li> <li > <a href=\"/accessibility/\">Accessibility Help</a> </li> <li > <a href=\"/guidance/\">Parental Guidance</a> </li> <li > <a href=\"/contact/\">Contact the BBC</a> </li> <li class=\" orb-w\" > <a href=\"http://advertising.bbcworldwide.com/\">Advertise with us</a> </li> <li class=\" orb-w\" > <a href=\"/privacy/cookies/international/\">Ad choices</a> </li> </ul> <small> <span class=\"orb-hilight\">Copyright &copy; 2015 BBC.</span> The BBC is not responsible for the content of external sites. <a href=\"/help/web/links/\" class=\"orb-hilight\">Read about our approach to external linking.</a> </small> </div> </div> </footer> </div> <!-- BBCDOTCOM bodyLast --><div class=\"bbccom_display_none\"><script type=\"text/javascript\"> /*<![CDATA[*/ if (window.bbcdotcom && window.bbcdotcom.analytics) { bbcdotcom.analytics.page(); } if (window.bbcdotcom && bbcdotcom.currencyProviders) { bbcdotcom.currencyProviders.write(); } /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ if (window.bbcdotcom && bbcdotcom.currencyProviders) { bbcdotcom.currencyProviders.postWrite(); } /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ /** * ASNYC waits to make any gpt requests until the bottom of the page */ (function() { var gads = document.createElement('script'); gads.async = true; gads.type = 'text/javascript'; var useSSL = 'https:' == document.location.protocol; gads.src = (useSSL ? 'https:' : 'http:') + '//www.googletagservices.com/tag/js/gpt.js'; var node = document.getElementsByTagName('script')[0]; node.parentNode.insertBefore(gads node); })(); /*]]>*/ </script><script type=\"text/javascript\"> /*<![CDATA[*/ if (window.bbcdotcom && bbcdotcom.data && bbcdotcom.data.stats && bbcdotcom.data.stats === 1 && bbcdotcom.utils && window.location.pathname === '/' && window.bbccookies && bbccookies.readPolicy('performance') ) { var wwhpEdition = bbcdotcom.utils.getMetaPropertyContent('wwhp-edition'); var _sf_async_config={}; /** CONFIGURATION START **/ _sf_async_config.uid = 50924; _sf_async_config.domain = \"bbc.co.uk\"; _sf_async_config.title = \"Homepage\"+(wwhpEdition !== '' ? ' - '+wwhpEdition : ''); _sf_async_config.sections = \"Homepage\"+(wwhpEdition !== '' ? ' Homepage - '+wwhpEdition : ''); _sf_async_config.region = wwhpEdition; _sf_async_config.path = \"/\"+(wwhpEdition !== '' ? '?'+wwhpEdition : ''); /** CONFIGURATION END **/ (function(){ function loadChartbeat() { window._sf_endpt=(new Date()).getTime(); var e = document.createElement(\"script\"); e.setAttribute(\"language\" \"javascript\"); e.setAttribute(\"type\" \"text/javascript\"); e.setAttribute('src' '//static.chartbeat.com/js/chartbeat.js'); document.body.appendChild(e); } var oldonload = window.onload; window.onload = (typeof window.onload != \"function\") ? loadChartbeat : function() { oldonload(); loadChartbeat(); }; })(); } /*]]>*/ </script></div> <!-- BBCDOTCOM all code in page --> <script type=\"text/javascript\"> document.write('<' + 'script id=\"orb-js-script\" data-assetpath=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/\" src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/script/orb.min.js\"><' + '/script>'); </script> <script type=\"text/javascript\"> (function() {\n",
      " 'use strict';\n",
      " var promoManager = {\n",
      " url: '' \n",
      " promoLoaded: false \n",
      " makeUrl: function (theme site win) {\n",
      " var loc = win? win.location : window.location \n",
      " proto = loc.protocol \n",
      " host = loc.host \n",
      " url = proto + '//' + ((proto.match(/s:/i) && !host.match(/^www\\.(int|test)\\./i))? 'ssl.' : 'www.') \n",
      " themes = ['light' 'dark'];\n",
      " if ( host.match(/^(?:www|ssl|m)\\.(int|test|stage|live)\\.bbc\\./i) ) {\n",
      " url += RegExp.$1 + '.';\n",
      " }\n",
      " else if ( host.match(/^pal\\.sandbox\\./i) ) {\n",
      " url += 'test.';\n",
      " }\n",
      " theme = themes[ +(theme === themes[0]) ];\n",
      " \n",
      " return url + 'bbc.co.uk/navpromo/card/' + site + '/' + theme;\n",
      " } \n",
      " init: function(node) {\n",
      " var disabledByCookie = (document.cookie.indexOf('ckns_orb_nopromo=1') > -1) \n",
      " that = this;\n",
      " \n",
      " if (window.promomanagerOverride) {\n",
      " for (var p in promomanagerOverride) {\n",
      " that[p] = promomanagerOverride[p];\n",
      " }\n",
      " }\n",
      " \n",
      " if ( window.orb.fig('uk') && !disabledByCookie ) {\n",
      " require(['orb/async/_footerpromo' 'istats-1'] function(promo istats) {\n",
      " var virtualSite = istats.getSite() || 'default';\n",
      " that.url = (window.promomanagerOverride || that).makeUrl('light' virtualSite);\n",
      " if (that.url) { \n",
      " promo.load(that.url node {\n",
      " onSuccess: function(e) {\n",
      " if(e.status === 'success') {\n",
      " node.parentNode.className = node.parentNode.className + ' orb-footer-promo-loaded';\n",
      " promoManager.promoLoaded = true;\n",
      " promoManager.event('promo-loaded').fire(e);\n",
      " }\n",
      " } \n",
      " onError: function() {\n",
      " istats.log('error' 'orb-footer-promo-failed');\n",
      " bbccookies.set('ckns_orb_nopromo=1; expires=' + new Date(new Date().getTime() + 1000 * 60 * 10).toGMTString() + ';path=/;');\n",
      " }\n",
      " }); \n",
      " }\n",
      " });\n",
      " }\n",
      " }\n",
      " };\n",
      " \n",
      " \n",
      " define('orb/promomanager' ['orb/lib/_event'] function (event) {\n",
      " event.mixin(promoManager);\n",
      " return promoManager;\n",
      " });\n",
      " \n",
      " require(['orb/promomanager'] function (promoManager) {\n",
      " promoManager.init(document.getElementById('navp-orb-footer-promo'));\n",
      " })\n",
      "})();\n",
      " </script> <script type=\"text/javascript\"> if (typeof require !== 'undefined') { require(['istats-1'] function(istats){ istats.track('external' { region: document.getElementsByTagName('body')[0] }); istats.track('download' { region: document.getElementsByTagName('body')[0] }); }); } </script> <img alt=\"\" id=\"livestats\" src=\"http://stats.bbc.co.uk/o.gif?~RS~s~RS~News~RS~t~RS~HighWeb_Story~RS~i~RS~26415021~RS~p~RS~99113~RS~a~RS~International~RS~u~RS~/news/technology-26415021~RS~r~RS~0~RS~q~RS~0~RS~z~RS~6705~RS~\"> <script> window.old_onload = window.onload; window.onload = function() { if(window.old_onload) { window.old_onload(); } window.loaded = true; }; </script> <!-- Chartbeat Web Analytics code - start -->\n",
      "<script type=\"text/javascript\">\n",
      " var _sf_async_config={};\n",
      " /** CONFIGURATION START **/\n",
      " _sf_async_config.uid = \"50924\";\n",
      " _sf_async_config.domain = \"www.bbc.co.uk\";\n",
      " _sf_async_config.sections = \"News News - technology News - STY News - technology - STY\";\n",
      " <!-- if page is an index add the edition to the path -->\n",
      " _sf_async_config.path = \"bbc.co.uk/news/technology-26415021\";\n",
      " (function() {\n",
      " var noCookies = true;\n",
      " var cookiePrefix = '_chartbeat';\n",
      " if (\"object\" === typeof bbccookies && typeof bbccookies.readPolicy == 'function') {\n",
      " noCookies = !bbccookies.readPolicy().performance;\n",
      " }\n",
      " if (noCookies && document.cookie.indexOf(cookiePrefix) !== -1) {\n",
      " //Find and remove cookies whose names begin with '_chartbeat'\n",
      " var cookieSplit = document.cookie.split(';');\n",
      " var cookieLength = cookieSplit.length;\n",
      " while (cookieLength--) {\n",
      " var cookie = cookieSplit[cookieLength].replace(/^\\s+|\\s+$/g '');\n",
      " var cookieName = cookie.split('=')[0];\n",
      " if (cookieName.indexOf(cookiePrefix) === 0) {\n",
      " document.cookie = cookieName + '=; expires=Thu 01 Jan 1970 00:00:00 GMT; path=/;';\n",
      " }\n",
      " }\n",
      " }\n",
      " _sf_async_config.noCookies = noCookies;\n",
      " }());\n",
      " /** CONFIGURATION END **/\n",
      " (function(){\n",
      " function loadChartbeat() {\n",
      " window._sf_endpt=(new Date()).getTime();\n",
      " var e = document.createElement(\"script\");\n",
      " e.setAttribute(\"language\" \"javascript\");\n",
      " e.setAttribute(\"type\" \"text/javascript\");\n",
      " e.setAttribute('src' '//static.chartbeat.com/js/chartbeat.js');\n",
      " document.body.appendChild(e);\n",
      " }\n",
      " var oldonload = window.onload;\n",
      " window.onload = (typeof window.onload != \"function\") ?\n",
      " loadChartbeat : function() { oldonload(); loadChartbeat(); };\n",
      " }());\n",
      "</script>\n",
      "<!-- Chartbeat Web Analytics code - end -->\n",
      " <!-- mpulse start -->\n",
      "<script>\n",
      "(function(){\n",
      " window.bbcnewsperformance = {};\n",
      " var perf = window.performance;\n",
      " function firstScrollTimer() {\n",
      " document.removeEventListener('scroll' firstScrollTimer);\n",
      " perf.mark('firstScroll');\n",
      " perf.measure('scrolltime' 'firstScroll');\n",
      " var timing = perf.getEntriesByName('scrolltime');\n",
      " bbcnewsperformance.firstScrollTime = timing[0].startTime;\n",
      " }\n",
      " function primaryImageTimer(src) {\n",
      " var timing = perf.getEntriesByName(src);\n",
      " bbcnewsperformance.primaryImageTime = timing[0].responseEnd;\n",
      " }\n",
      " if (perf) {\n",
      " if (perf.mark && perf.measure) {\n",
      " document.addEventListener('scroll' firstScrollTimer);\n",
      " }\n",
      " if (perf.getEntriesByName) {\n",
      " var primaryImage = document.querySelector('.story-body__inner img');\n",
      " if (primaryImage) {\n",
      " var src = primaryImage.getAttribute('src');\n",
      " primaryImage.addEventListener('load' primaryImageTimer.bind(this src));\n",
      " }\n",
      " }\n",
      " }\n",
      " var random = Math.random();\n",
      " var rate = 1;\n",
      " if (rate && (random < rate)) {\n",
      " var accountId = \"X5H9R-GT47V-WJULQ-CWND4-S7WY8\";\n",
      " // mpulse vendor code\n",
      " if(window.BOOMR && window.BOOMR.version){return;}\n",
      " var dom doc where iframe = document.createElement('iframe');\n",
      " iframe.src = \"javascript:false\";\n",
      " iframe.title = \"\"; iframe.role=\"presentation\";\n",
      " (iframe.frameElement || iframe).style.cssText = \"width:0;height:0;border:0;display:none;\";\n",
      " where = document.getElementsByTagName('script')[0];\n",
      " where.parentNode.insertBefore(iframe where);\n",
      " try {\n",
      " doc = iframe.contentWindow.document;\n",
      " } catch(e) {\n",
      " dom = document.domain;\n",
      " iframe.src=\"javascript:var d=document.open();d.domain='\"+dom+\"';void(0);\";\n",
      " doc = iframe.contentWindow.document;\n",
      " }\n",
      " doc.open()._l = function() {\n",
      " var js = this.createElement(\"script\");\n",
      " if(dom) this.domain = dom;\n",
      " js.id = \"boomr-if-as\";\n",
      " js.src = '//c.go-mpulse.net/boomerang/' +\n",
      " accountId;\n",
      " BOOMR_lstart=new Date().getTime();\n",
      " this.body.appendChild(js);\n",
      " };\n",
      " doc.write('<body onload=\"document._l();\">');\n",
      " doc.close();\n",
      " // mpulse vendor code - end\n",
      " }\n",
      "})();\n",
      "</script>\n",
      "<!-- mpulse end -->\n",
      " </body> </html> \n",
      "\n"
     ]
    }
   ],
   "source": [
    "html = html.split(\"\\n\") # html is now a list of lines\n",
    "html = \"\\n\".join(html)    # we turn it back into a single string\n",
    "print(html)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "We give up -- to much noise in this page! How can we get just the text out of this?\n",
    "\n",
    "Let us use existing libraries.\n",
    "\n",
    "The first we try is called BeautifulSoup.  It is a library to parse \"noisy\" HTML in general.  \n",
    "Once parsed, the HTML string can be navigated in a convenient manner.\n",
    "Make sure you install beautifulsoup4 by running:\n",
    "\n",
    "% pip install beautifulsoup4\n",
    "\n",
    "We can then run this:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "from bs4 import BeautifulSoup\n",
    "\n",
    "def clean_html1(html):\n",
    "    soup = BeautifulSoup(html)\n",
    "    return soup.get_text()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let us try this version of clean_html:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "\n",
      "\n",
      "\n",
      "\n",
      "An hour to catch the coding bug - BBC News\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " {\n",
      " \"@context\": \"http://schema.org\"\n",
      " \"@type\": \"Article\"\n",
      " \n",
      " \"url\": \"http://www.bbc.com/news/technology-26415021\"\n",
      " \"publisher\": {\n",
      " \"@type\": \"Organization\" \n",
      " \"name\": \"BBC News\" \n",
      " \"logo\": \"http://www.bbc.co.uk/news/special/2015/newsspec_10857/bbc_news_logo.png?cb=1\"\n",
      " }\n",
      " \n",
      " \"headline\": \"An hour to catch the coding bug\"\n",
      " \"author\": \"Mark Ward\"\n",
      " \"mainEntityOfPage\": \"http://www.bbc.com/news/technology-26415021\"\n",
      " \"articleBody\": \"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\"\n",
      " \n",
      " \"image\": {\n",
      " \"@list\": [\n",
      " \"http://ichef-1.bbci.co.uk/news/560/media/images/73325000/jpg/_73325163_olly009.jpg\"\n",
      " \"http://ichef.bbci.co.uk/news/560/media/images/73325000/jpg/_73325167_hourofcode.jpg\"\n",
      " \"http://ichef.bbci.co.uk/news/560/media/images/73325000/jpg/_73325169_appinventor.jpg\"\n",
      " ]\n",
      " }\n",
      " \"datePublished\": \"2014-03-03T10:22:55+00:00\"\n",
      " }\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "var _sf_startpt=(new Date()).getTime()\n",
      "\n",
      " (function() {\n",
      " if (navigator.userAgent.match(/IEMobile\\/10\\.0/)) {\n",
      " var msViewportStyle = document.createElement(\"style\");\n",
      " msViewportStyle.appendChild(\n",
      " document.createTextNode(\"@-ms-viewport{width:auto!important}\")\n",
      " );\n",
      " document.getElementsByTagName(\"head\")[0].appendChild(msViewportStyle);\n",
      " }\n",
      " })();\n",
      " \n",
      "window.fig = window.fig || {}; window.fig.async = true;\n",
      "  window.bbcredirection={geo:true}  /*<![CDATA[*/ if (typeof window.define !== 'function' || typeof window.require !== 'function') { document.write('<script class=\"js-require-lib\" src=\"http://static.bbci.co.uk/frameworks/requirejs/lib.js\"><'+'/script>'); } /*]]>*/  bbcRequireMap = {\"jquery-1\":\"http://static.bbci.co.uk/frameworks/jquery/0.3.0/sharedmodules/jquery-1.7.2\" \"jquery-1.4\":\"http://static.bbci.co.uk/frameworks/jquery/0.3.0/sharedmodules/jquery-1.4\" \"jquery-1.9\":\"http://static.bbci.co.uk/frameworks/jquery/0.3.0/sharedmodules/jquery-1.9.1\" \"swfobject-2\":\"http://static.bbci.co.uk/frameworks/swfobject/0.1.10/sharedmodules/swfobject-2\" \"demi-1\":\"http://static.bbci.co.uk/frameworks/demi/0.10.0/sharedmodules/demi-1\" \"gelui-1\":\"http://static.bbci.co.uk/frameworks/gelui/0.9.13/sharedmodules/gelui-1\" \"cssp!gelui-1/overlay\":\"http://static.bbci.co.uk/frameworks/gelui/0.9.13/sharedmodules/gelui-1/overlay.css\" \"istats-1\":\"http://static.bbci.co.uk/frameworks/istats/0.28.4/modules/istats-1\" \"relay-1\":\"http://static.bbci.co.uk/frameworks/relay/0.2.6/sharedmodules/relay-1\" \"clock-1\":\"http://static.bbci.co.uk/frameworks/clock/0.1.9/sharedmodules/clock-1\" \"canvas-clock-1\":\"http://static.bbci.co.uk/frameworks/clock/0.1.9/sharedmodules/canvas-clock-1\" \"cssp!clock-1\":\"http://static.bbci.co.uk/frameworks/clock/0.1.9/sharedmodules/clock-1.css\" \"jssignals-1\":\"http://static.bbci.co.uk/frameworks/jssignals/0.3.6/modules/jssignals-1\" \"jcarousel-1\":\"http://static.bbci.co.uk/frameworks/jcarousel/0.1.10/modules/jcarousel-1\" \"bump-3\":\"//emp.bbci.co.uk/emp/bump-3/bump-3\"}; require({ baseUrl: 'http://static.bbci.co.uk/' paths: bbcRequireMap waitSeconds: 30 });  /*<![CDATA[*/ if (typeof bbccookies_flag === 'undefined') { bbccookies_flag = 'ON'; } showCTA_flag = true; cta_enabled = (showCTA_flag && (bbccookies_flag === 'ON')); (function(){var e=\"ckns_policy\" m=\"Thu 01 Jan 1970 00:00:00 GMT\" k={ads:true personalisation:true performance:true necessary:true};function f(p){if(f.cache[p]){return f.cache[p]}var o=p.split(\"/\") q=[\"\"];do{q.unshift((o.join(\"/\")||\"/\"));o.pop()}while(q[0]!==\"/\");f.cache[p]=q;return q}f.cache={};function a(p){if(a.cache[p]){return a.cache[p]}var q=p.split(\".\") o=[];while(q.length&&\"|co.uk|com|\".indexOf(\"|\"+q.join(\".\")+\"|\")===-1){if(q.length){o.push(q.join(\".\"))}q.shift()}f.cache[p]=o;return o}a.cache={};function i(o t p){var z=[\"\"].concat(a(window.location.hostname)) w=f(window.location.pathname) y=\"\" r x;for(var s=0 v=z.length;s<v;s++){r=z[s];for(var q=0 u=w.length;q<u;q++){x=w[q];y=o+\"=\"+t+\";\"+(r?\"domain=\"+r+\";\":\"\")+(x?\"path=\"+x+\";\":\"\")+(p?\"expires=\"+p+\";\":\"\");bbccookies.set(y true)}}}window.bbccookies={POLICY_REFRESH_DATE_MILLIS:new Date(2015 4 21 0 0 0 0).getTime() POLICY_EXPIRY_COOKIENAME:\"ckns_policy_exp\" _setEverywhere:i cookiesEnabled:function(){var o=\"ckns_testcookie\"+Math.floor(Math.random()*100000);this.set(o+\"=1\");if(this.get().indexOf(o)>-1){g(o);return true}return false} set:function(o){return document.cookie=o} get:function(){return document.cookie} getCrumb:function(o){if(!o){return null}return decodeURIComponent(document.cookie.replace(new RegExp(\"(?:(?:^|.*;)\\\\s*\"+encodeURIComponent(o).replace(/[\\-\\.\\+\\*]/g \"\\\\$&\")+\"\\\\s*\\\\=\\\\s*([^;]*).*$)|^.*$\") \"$1\"))||null} policyRequiresRefresh:function(){var p=new Date();p.setHours(0);p.setMinutes(0);p.setSeconds(0);p.setMilliseconds(0);if(bbccookies.POLICY_REFRESH_DATE_MILLIS<=p.getTime()){var o=bbccookies.getCrumb(bbccookies.POLICY_EXPIRY_COOKIENAME);if(o){o=new Date(parseInt(o));o.setYear(o.getFullYear()-1);return bbccookies.POLICY_REFRESH_DATE_MILLIS>=o.getTime()}else{return true}}else{return false}} _setPolicy:function(o){return h.apply(this arguments)} readPolicy:function(){return b.apply(this arguments)} _deletePolicy:function(){i(e \"\" m)} isAllowed:function(){return true} _isConfirmed:function(){return c()!==null} _acceptsAll:function(){var o=b();return o&&!(j(o).indexOf(\"0\")>-1)} _getCookieName:function(){return d.apply(this arguments)} _showPrompt:function(){var o=((!this._isConfirmed()||this.policyRequiresRefresh())&&window.cta_enabled&&this.cookiesEnabled()&&!window.bbccookies_disable);return(window.orb&&window.orb.fig)?o&&(window.orb.fig(\"no\")||window.orb.fig(\"ck\")):o}};bbccookies._getPolicy=bbccookies.readPolicy;function d(p){var o=(\"\"+p).match(/^([^=]+)(?==)/);return(o&&o.length?o[0]:\"\")}function j(o){return\"\"+(o.ads?1:0)+(o.personalisation?1:0)+(o.performance?1:0)}function h(s){if(typeof s===\"undefined\"){s=k}if(typeof arguments[0]===\"string\"){var p=arguments[0] r=arguments[1];if(p===\"necessary\"){r=true}s=b();s[p]=r}else{if(typeof arguments[0]===\"object\"){s.necessary=true}}var q=new Date();q.setYear(q.getFullYear()+1);bbccookies.set(e+\"=\"+j(s)+\";domain=bbc.co.uk;path=/;expires=\"+q.toUTCString()+\";\");bbccookies.set(e+\"=\"+j(s)+\";domain=bbc.com;path=/;expires=\"+q.toUTCString()+\";\");var o=new Date(q.getTime());o.setMonth(o.getMonth()+1);bbccookies.set(bbccookies.POLICY_EXPIRY_COOKIENAME+\"=\"+q.getTime()+\";domain=bbc.co.uk;path=/;expires=\"+o.toUTCString()+\";\");bbccookies.set(bbccookies.POLICY_EXPIRY_COOKIENAME+\"=\"+q.getTime()+\";domain=bbc.com;path=/;expires=\"+o.toUTCString()+\";\");return s}function l(o){if(o===null){return null}var p=o.split(\"\");return{ads:!!+p[0] personalisation:!!+p[1] performance:!!+p[2] necessary:true}}function c(){var o=new RegExp(\"(?:^|; ?)\"+e+\"=(\\\\d\\\\d\\\\d)($|;)\") p=document.cookie.match(o);if(!p){return null}return p[1]}function b(o){var p=l(c());if(!p){p=k}if(o){return p[o]}else{return p}}function g(o){return document.cookie=o+\"=;expires=\"+m+\";\"}function n(){var o='<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/frameworks/bbccookies/0.6.15/script/bbccookies.js\"><\\/script>';if(window.bbccookies_flag===\"ON\"&&!bbccookies._acceptsAll()&&!window.bbccookies_disable){document.write(o)}}n()})(); /*]]>*/ /*<![CDATA[*/\n",
      "(function(){window.fig=window.fig||{};window.fig.manager={include:function(a){a=a||window;var e=a.document g=e.cookie b=g.match(/(?:^|; ?)ckns_orb_fig=([^;]+)/);if(!b&&g.indexOf(\"ckns_orb_nofig=1\")>-1){this.setFig(a {no:1})}else{if(b){b=this.deserialise(decodeURIComponent(RegExp.$1));this.setFig(a b)}e.write('<script src=\"https://fig.bbc.co.uk/frameworks/fig/1/fig.js\"><'+\"/script>\")}} confirm:function(a){a=a||window;if(a.orb&&a.orb.fig&&a.orb.fig(\"no\")){this.setNoFigCookie(a)}if(a.orb===undefined||a.orb.fig===undefined){this.setFig(a {no:1});this.setNoFigCookie(a)}} setNoFigCookie:function(a){a.document.cookie=\"ckns_orb_nofig=1; expires=\"+new Date(new Date().getTime()+1000*60*10).toGMTString()+\";\"} setFig:function(a b){(function(){var c=b;a.orb=a.orb||{};a.orb.fig=function(d){return(arguments.length)?c[d]:c}})()} deserialise:function(b){var a={};b.replace(/([a-z]{2}):([0-9]+)/g function(){a[RegExp.$1]=+RegExp.$2});return a}}})();fig.manager.include();/*]]>*/\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "/*<![CDATA[*/ (function(undefined){if(!window.bbc){window.bbc={}}var ROLLING_PERIOD_DAYS=30;window.bbc.Mandolin=function(id segments opts){var now=new Date().getTime() storedItem DEFAULT_START=now DEFAULT_RATE=1 COOKIE_NAME=\"ckpf_mandolin\";opts=opts||{};this._id=id;this._segmentSet=segments;this._store=new window.window.bbc.Mandolin.Storage(COOKIE_NAME);this._opts=opts;this._rate=(opts.rate!==undefined)?+opts.rate:DEFAULT_RATE;this._startTs=(opts.start!==undefined)?new Date(opts.start).getTime():new Date(DEFAULT_START).getTime();this._endTs=(opts.end!==undefined)?new Date(opts.end).getTime():daysFromNow(ROLLING_PERIOD_DAYS);this._signupEndTs=(opts.signupEnd!==undefined)?new Date(opts.signupEnd).getTime():this._endTs;this._segment=null;if(typeof id!==\"string\"){throw new Error(\"Invalid Argument: id must be defined and be a string\")}if(Object.prototype.toString.call(segments)!==\"[object Array]\"){throw new Error(\"Invalid Argument: Segments are required.\")}if(opts.rate!==undefined&&(opts.rate<0||opts.rate>1)){throw new Error(\"Invalid Argument: Rate must be between 0 and 1.\")}if(this._startTs>this._endTs){throw new Error(\"Invalid Argument: end date must occur after start date.\")}if(!(this._startTs<this._signupEndTs&&this._signupEndTs<=this._endTs)){throw new Error(\"Invalid Argument: SignupEnd must be between start and end date\")}removeExpired.call(this now);var overrides=window.bbccookies.get().match(/ckns_mandolin_setSegments=([^;]+)/);if(overrides!==null){eval(\"overrides = \"+decodeURIComponent(RegExp.$1)+\";\");if(overrides[this._id]&&this._segmentSet.indexOf(overrides[this._id])==-1){throw new Error(\"Invalid Override: overridden segment should exist in segments array\")}}if(overrides!==null&&overrides[this._id]){this._segment=overrides[this._id]}else{if((storedItem=this._store.getItem(this._id))){this._segment=storedItem.segment}else{if(this._startTs<=now&&now<this._signupEndTs&&now<=this._endTs&&this._store.isEnabled()===true){this._segment=pick(segments this._rate);if(opts.end===undefined){this._store.setItem(this._id {segment:this._segment})}else{this._store.setItem(this._id {segment:this._segment end:this._endTs})}log.call(this \"mandolin_segment\")}}}log.call(this \"mandolin_view\")};window.bbc.Mandolin.prototype.getSegment=function(){return this._segment};function log(actionType params){var that=this;require([\"istats-1\"] function(istats){istats.log(actionType that._id+\":\"+that._segment params?params:{})})}function removeExpired(expires){var items=this._store.getItems() expiresInt=+expires;for(var key in items){if(items[key].end!==undefined&&+items[key].end<expiresInt){this._store.removeItem(key)}}}function getLastExpirationDate(data){var winner=0 rollingExpire=daysFromNow(ROLLING_PERIOD_DAYS);for(var key in data){if(data[key].end===undefined&&rollingExpire>winner){winner=rollingExpire}else{if(+data[key].end>winner){winner=+data[key].end}}}return(winner)?new Date(winner):new Date(rollingExpire)}window.bbc.Mandolin.prototype.log=function(params){log.call(this \"mandolin_log\" params)};window.bbc.Mandolin.prototype.convert=function(params){log.call(this \"mandolin_convert\" params);this.convert=function(){}};function daysFromNow(n){var endDate;endDate=new Date().getTime()+(n*60*60*24)*1000;return endDate}function pick(segments rate){var picked min=0 max=segments.length-1;if(typeof rate===\"number\"&&Math.random()>rate){return null}do{picked=Math.floor(Math.random()*(max-min+1))+min}while(picked>max);return segments[picked]}window.bbc.Mandolin.Storage=function(name){validateCookieName(name);this._cookieName=name;this._isEnabled=(bbccookies.isAllowed(this._cookieName)===true&&bbccookies.cookiesEnabled()===true)};window.bbc.Mandolin.Storage.prototype.setItem=function(key value){var storeData=this.getItems();storeData[key]=value;this.save(storeData);return value};window.bbc.Mandolin.Storage.prototype.isEnabled=function(){return this._isEnabled};window.bbc.Mandolin.Storage.prototype.getItem=function(key){var storeData=this.getItems();return storeData[key]};window.bbc.Mandolin.Storage.prototype.removeItem=function(key){var storeData=this.getItems();delete storeData[key];this.save(storeData)};window.bbc.Mandolin.Storage.prototype.getItems=function(){return deserialise(this.readCookie(this._cookieName)||\"\")};window.bbc.Mandolin.Storage.prototype.save=function(data){window.bbccookies.set(this._cookieName+\"=\"+encodeURIComponent(serialise(data))+\"; expires=\"+getLastExpirationDate(data).toUTCString()+\";\")};window.bbc.Mandolin.Storage.prototype.readCookie=function(name){var nameEq=name+\"=\" ca=window.bbccookies.get().split(\"; \") i c;validateCookieName(name);for(i=0;i<ca.length;i++){c=ca[i];if(c.indexOf(nameEq)===0){return decodeURIComponent(c.substring(nameEq.length c.length))}}return null};function serialise(o){var str=\"\";for(var p in o){if(o.hasOwnProperty(p)){str+='\"'+p+'\"'+\":\"+(typeof o[p]===\"object\"?(o[p]===null?\"null\":\"{\"+serialise(o[p])+\"}\"):'\"'+o[p].toString()+'\"')+\" \"}}return str.replace(/ \\}/g \"}\").replace(/ $/g \"\")}function deserialise(str){var o;str=\"{\"+str+\"}\";if(!validateSerialisation(str)){throw\"Invalid input provided for deserialisation.\"}eval(\"o = \"+str);return o}var validateSerialisation=(function(){var OBJECT_TOKEN=\"<Object>\" ESCAPED_CHAR='\"\\\\n\\\\r\\\\u2028\\\\u2029\\\\u000A\\\\u000D\\\\u005C' ALLOWED_CHAR=\"([^\"+ESCAPED_CHAR+\"]|\\\\\\\\[\"+ESCAPED_CHAR+\"])\" KEY='\"'+ALLOWED_CHAR+'+\"' VALUE='(null|\"'+ALLOWED_CHAR+'*\"|'+OBJECT_TOKEN+\")\" KEY_VALUE=KEY+\":\"+VALUE KEY_VALUE_SEQUENCE=\"(\"+KEY_VALUE+\" )*\"+KEY_VALUE OBJECT_LITERAL=\"({}|{\"+KEY_VALUE_SEQUENCE+\"})\" objectPattern=new RegExp(OBJECT_LITERAL \"g\");return function(str){if(str.indexOf(OBJECT_TOKEN)!==-1){return false}while(str.match(objectPattern)){str=str.replace(objectPattern OBJECT_TOKEN)}return str===OBJECT_TOKEN}})();function validateCookieName(name){if(name.match(/ ;/)){throw\"Illegal name provided must be valid in browser cookie.\"}}})(); /*]]>*/  document.documentElement.className += (document.documentElement.className? ' ' : '') + 'orb-js'; fig.manager.confirm();    var blq = { environment: function() { return 'live'; } }   /*<![CDATA[*/ function oqsSurveyManager(w flag) { if (flag !== 'OFF') { w.document.write('<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/script/vendor/edr.js\"><'+'/script>'); } } oqsSurveyManager(window 'ON'); /*]]>*/  \n",
      " /*<![CDATA[*/ var _sf_startpt = (new Date()).getTime(); /*]]>*/ .bbccom_display_none{display:none;} /*<![CDATA[*/ var bbcdotcomConfig googletag = googletag || {}; googletag.cmd = googletag.cmd || []; var bbcdotcom = false; (function(){ if(typeof require !== 'undefined') { require({ paths:{ \"bbcdotcom\":\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script\" } }); } })(); /*]]>*/  /*<![CDATA[*/ var bbcdotcom = { adverts: { keyValues: { set: function() {} } } advert: { write: function () {} show: function () {} isActive: function () { return false; } layout: function() { return { reset: function() {} } } } config: { init: function() {} isActive: function() {} setSections: function() {} isAdsEnabled: function() {} setAdsEnabled: function() {} isAnalyticsEnabled: function() {} setAnalyticsEnabled: function() {} setAssetPrefix: function() {} setVersion: function () {} setJsPrefix: function() {} setSwfPrefix: function() {} setCssPrefix: function() {} setConfig: function() {} getAssetPrefix: function() {} getJsPrefix: function () {} getSwfPrefix: function () {} getCssPrefix: function () {} } survey: { init: function(){ return false; } } data: {} init: function() {} objects: function(str) { return false; } locale: { set: function() {} get: function() {} } setAdKeyValue: function() {} utils: { addEvent: function() {} addHtmlTagClass: function() {} log: function () {} } addLoadEvent: function() {} }; /*]]>*/  /*<![CDATA[*/ (function(){ if (typeof orb !== 'undefined' && typeof orb.fig === 'function') { if (orb.fig('ad') && orb.fig('uk') == 0) { bbcdotcom.data = { ads: (orb.fig('ad') ? 1 : 0) stats: (orb.fig('uk') == 0 ? 1 : 0) statsProvider: orb.fig('ap') }; } } else { document.write('<script type=\"text/javascript\" src=\"'+('https:' == document.location.protocol ? 'https://ssl.bbc.com' : 'http://tps.bbc.com')+'/wwscripts/data\">\\x3C/script>'); } })(); /*]]>*/  /*<![CDATA[*/ (function(){ if (typeof orb === 'undefined' || typeof orb.fig !== 'function') { bbcdotcom.data = { ads: bbcdotcom.data.a stats: bbcdotcom.data.b statsProvider: bbcdotcom.data.c }; } if (bbcdotcom.data.ads == 1) { document.write('<script type=\"text/javascript\" src=\"'+('https:' == document.location.protocol ? 'https://ssl.bbc.co.uk' : 'http://www.bbc.co.uk')+'/wwscripts/flag\">\\x3C/script>'); } })(); /*]]>*/  /*<![CDATA[*/ (function(){ if (window.bbcdotcom && (typeof bbcdotcom.flag == 'undefined' || (typeof bbcdotcom.data.ads !== 'undefined' && bbcdotcom.flag.a != 1))) { bbcdotcom.data.ads = 0; } if (/[?|&]ads/.test(window.location.href) || /(^|; )ads=on; /.test(document.cookie) || /; ads=on(; |$)/.test(document.cookie)) { bbcdotcom.data.ads = 1; bbcdotcom.data.stats = 1; } if (window.bbcdotcom && (bbcdotcom.data.ads == 1 || bbcdotcom.data.stats == 1)) { bbcdotcom.assetPrefix = \"http://static.bbci.co.uk/bbcdotcom/0.3.344/\"; if (/(sandbox|int)(.dev)*.bbc.co*/.test(window.location.href) || /[?|&]ads-debug/.test(window.location.href) || document.cookie.indexOf('ads-debug=') !== -1) { document.write('<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script/orb/individual.js\">\\x3C/script>'); } else { document.write('<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script/orb/bbcdotcom.js\">\\x3C/script>'); } if(/[\\\\?&]ads=([^&#]*)/.test(window.location.href)) { document.write('<script type=\"text/javascript\" src=\"http://static.bbci.co.uk/bbcdotcom/0.3.344/script/orb/adverts/adSuites.js\">\\x3C/script>'); } } })(); /*]]>*/  /*<![CDATA[*/ (function(){ if (window.bbcdotcom && (bbcdotcom.data.ads == 1 || bbcdotcom.data.stats == 1)) { bbcdotcomConfig = {\"adFormat\":\"standard\" \"adKeyword\":\"\" \"adMode\":\"smart\" \"adsEnabled\":true \"appAnalyticsSections\":\"news>technology\" \"asyncEnabled\":true \"disableInitialLoad\":false \"advertInfoPageUrl\":\"http:\\/\\/www.bbc.co.uk\\/faqs\\/online\\/adverts_general\" \"advertisementText\":\"Advertisement\" \"analyticsEnabled\":true \"appName\":\"tabloid\" \"assetPrefix\":\"http:\\/\\/static.bbci.co.uk\\/bbcdotcom\\/0.3.344\\/\" \"continuousPlayEnabled\":false \"customAdParams\":[] \"customStatsParams\":[] \"headline\":\"An hour to catch the coding bug\" \"id\":\"26415021\" \"inAssociationWithText\":\"in association with\" \"keywords\":\"\" \"language\":\"\" \"orbTransitional\":false \"outbrainEnabled\":true \"palEnv\":\"live\" \"productName\":\"\" \"sections\":[] \"siteCatalystEnabled\":true \"comScoreEnabled\":true \"slots\":\"\" \"sponsoredByText\":\"is sponsored by\" \"adsByGoogleText\":\"Ads by Google\" \"summary\":\"Is it possible to get children interested in computer programming in just 60 minutes? The Hour of Code has been designed to do just that.\" \"type\":\"STORY\" \"staticBase\":\"\\/bbcdotcom\" \"staticHost\":\"http:\\/\\/static.bbci.co.uk\" \"staticVersion\":\"0.3.344\" \"staticPrefix\":\"http:\\/\\/static.bbci.co.uk\\/bbcdotcom\\/0.3.344\" \"dataHttp\":\"tps.bbc.com\" \"dataHttps\":\"ssl.bbc.com\" \"flagHttp\":\"www.bbc.co.uk\" \"flagHttps\":\"ssl.bbc.co.uk\" \"analyticsHttp\":\"sa.bbc.com\" \"analyticsHttps\":\"ssa.bbc.com\"}; bbcdotcom.config.init(bbcdotcomConfig bbcdotcom.data window.location window.document); bbcdotcom.config.setAssetPrefix(\"http://static.bbci.co.uk/bbcdotcom/0.3.344/\"); bbcdotcom.config.setVersion(\"0.3.344\"); document.write('<!--[if IE 7]><script type=\"text/javascript\">bbcdotcom.config.setIE7(true);\\x3C/script><![endif]-->'); document.write('<!--[if IE 8]><script type=\"text/javascript\">bbcdotcom.config.setIE8(true);\\x3C/script><![endif]-->'); document.write('<!--[if IE 9]><script type=\"text/javascript\">bbcdotcom.config.setIE9(true);\\x3C/script><![endif]-->'); if (/[?|&]ex-dp/.test(window.location.href) || document.cookie.indexOf('ex-dp=') !== -1) { bbcdotcom.utils.addHtmlTagClass('bbcdotcom-ex-dp'); } } })(); /*]]>*/  /*<![CDATA[*/\n",
      " window.bbcFlagpoles_istats = 'ON';\n",
      " window.orb = window.orb || {};\n",
      " if (bbccookies.isAllowed('s1')) {\n",
      " var istatsTrackingUrl = '//sa.bbc.co.uk/bbc/bbc/s?name=news.technology.story.26415021.page&cps_asset_id=26415021&page_type=Story&section=%2Fnews%2Ftechnology&first_pub=2014-03-03T07%3A36%3A59%2B00%3A00&last_editorial_update=2014-03-03T10%3A22%3A55%2B00%3A00&title=An+hour+to+catch+the+coding+bug&for_nation=il&app_version=1.99.0&bbc_site=news&pal_route=asset&ml_name=barlesque&app_type=responsive&language=en-GB&ml_version=0.28.4&pal_webapp=tabloid&prod_name=news&app_name=news';\n",
      " require(['istats-1'] function (istats) {\n",
      " istats.addCollector({'name': 'default' 'url': '//sa.bbc.co.uk/bbc/bbc/s' 'separator': '&' });\n",
      " var counterName = (window.istats_countername) ? window.istats_countername : istatsTrackingUrl.match(/[\\?&]name=([^&]*)/i)[1];\n",
      " istats.setCountername(counterName);\n",
      " if (/\\bIDENTITY=/.test(document.cookie)) {\n",
      " istats.addLabels({'bbc_identity': '1'});\n",
      " }\n",
      " if (/\\bckns_policy=\\d\\d0/.test(document.cookie)) {\n",
      " istats.addLabels({'ns_nc': '1'});\n",
      " }\n",
      " var c = (document.cookie.match(/\\bckns_policy=(\\d\\d\\d)/) || []).pop() || '';\n",
      " var screenWidthAndHeight = 'unavailable';\n",
      " if (window.screen && screen.width && screen.height) {\n",
      " screenWidthAndHeight = screen.width + 'x' + screen.height;\n",
      " }\n",
      " istats.addLabels('cps_asset_id=26415021&page_type=Story&section=%2Fnews%2Ftechnology&first_pub=2014-03-03T07%3A36%3A59%2B00%3A00&last_editorial_update=2014-03-03T10%3A22%3A55%2B00%3A00&title=An+hour+to+catch+the+coding+bug&for_nation=il&app_version=1.99.0&bbc_site=news&pal_route=asset&ml_name=barlesque&app_type=responsive&language=en-GB&ml_version=0.28.4&pal_webapp=tabloid&prod_name=news&app_name=news');\n",
      " istats.addLabels({\n",
      " 'blq_s': '4d' \n",
      " 'blq_r': '2.7' \n",
      " 'blq_v': 'default' \n",
      " 'blq_e': 'pal' \n",
      " 'bbc_mc': (c ? 'ad' + c.charAt(0) + 'ps' + c.charAt(1) + 'pf' + c.charAt(2) : 'not_set') \n",
      " 'screen_resolution': screenWidthAndHeight \n",
      " 'ns_referrer': encodeURI(((window.orb.referrer) ? window.orb.referrer : document.referrer))\n",
      " }\n",
      " );\n",
      " });\n",
      " }\n",
      " /*]]>*/\n",
      " /* <![CDATA[ */ define('id-statusbar-config' { 'translation_signedout': \"Sign in\" 'translation_signedin': \"Your account\" 'use_overlay' : false 'signin_url' : \"https://ssl.bbc.com/id/signin?ptrt=http%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021\" 'locale' : \"en-GB\" 'policyname' : \"\" 'ptrt' : \"http://www.bbc.com/news/technology-26415021\" }); var map = {}; map['idcta/statusbar'] = 'http://static.bbci.co.uk/id/0.32.25/modules/idcta/statusbar'; require({paths: map}); /* ]]> */   require(['istats-1'] function(istats){ if (typeof(document) != 'undefined' && typeof(document.cookie) != 'undefined') { var cookieAphidMatch = document.cookie.match(/ckpf_APHID=([^;]*)/); if (cookieAphidMatch && typeof(cookieAphidMatch[1]) == 'string') { istats.addLabels({'bbc_hid': cookieAphidMatch[1]}); } } })();   (function () { if (! window.require) { throw new Error('idcta: could not find require module'); } var map = {}; map['idapp-1'] = 'http://static.bbci.co.uk/idapp/0.71.76/modules/idapp/idapp-1'; map['idcta/idcta-1'] = 'http://static.bbci.co.uk/id/0.32.25/modules/idcta/idcta-1'; map['idcta/idCookie'] = 'http://static.bbci.co.uk/id/0.32.25/modules/idcta/idCookie'; map['idcta/overlayManager'] = 'http://static.bbci.co.uk/id/0.32.25/modules/idcta/overlayManager'; require({paths: map}); define('id-config' {\"idapp\":{\"version\":\"0.71.76\" \"hostname\":\"ssl.bbc.com\" \"insecurehostname\":\"www.bbc.com\" \"tld\":\"bbc.com\"} \"idtranslations\":{\"version\":\"0.33.27\"} \"identity\":{\"baseUrl\":\"https:\\/\\/talkback.live.bbc.co.uk\\/identity\" \"cookieAgeDays\":730 \"accessTokenCookieName\":\"ckns_IDA-ATKN\"} \"pathway\":{\"name\":null \"staticAssetUrl\":\"http:\\/\\/static.bbci.co.uk\\/idapp\\/0.71.76\\/modules\\/idapp\\/idapp-1\\/View.css\"} \"idpurl\":\"https:\\/\\/idp.api.bbc.co.uk\\/idp\\/oauth2\\/authorize?client_id=bbc-co-uk&response_type=code&scope=openid+play.bbcstore.r+plays.any.w+plays.any.r+follows.any.w+follows.any.r+favourites.any.w+favourites.any.r+idm.basic.r&module=bbc-co-uk&state=ptrt%3Dhttp%3A%2F%2Fwww.bbc.com%2Fnews%2Ftechnology-26415021%26locale%3Den-GB&redirect_uri=https%3A%2F%2Fssl.bbc.com%2Fid%2Foauth2%2Fconsume%2Fidp.bbc.co.uk\"}); })();   require(['idcta/idCookie'] function(idCookie){ if (typeof(document) != 'undefined' && typeof(document.cookie) != 'undefined') { var idCookieInstance = idCookie.getInstance(); /* Timestamp in milliseconds for the 6am on 27th of October 2015 */ var timestamp27thOct = 1445925600000; /* Only select users who signed in before the dooms day and were not downgraded yet */ if (idCookieInstance.hasCookie() && idCookieInstance.timestamp != '' && parseInt(idCookieInstance.timestamp) > 0 && parseInt(idCookieInstance.timestamp) < timestamp27thOct && !idCookieInstance.isDowngraded()) { /* iPlayer uplift is session cookie so downgrade based on this cookie missed 20% users. To cover all the users with our fix ut is nor uncoditional: all users that have not been downgraded before will now be downgraded */ idCookieInstance.downgrade(); } } }); \n",
      "\n",
      "\n",
      " if (document.getElementById(\"responsive-news\")) { window.bbcNewsResponsive = true; } var isIE = (function() { var undef v = 3 div = document.createElement('div') all = div.getElementsByTagName('i'); while ( div.innerHTML = '<!--[if gt IE ' + (++v) + ']><i></i><![endif]-->' all[0] ); return v > 4 ? v : undef; }()); var modernDevice = 'querySelector' in document && 'localStorage' in window && 'addEventListener' in window forceCore = document.cookie.indexOf('ckps_force_core') !== -1; window.cutsTheMustard = modernDevice && !forceCore; if (window.cutsTheMustard) { document.documentElement.className += ' ctm'; var insertPoint = document.getElementById('news-loader') config = {\"asset\":{\"asset_id\":\"26415021\" \"asset_uri\":\"\\/news\\/technology-26415021\" \"first_created\":{\"date\":\"2014-03-03 07:36:59\" \"timezone_type\":3 \"timezone\":\"Europe\\/London\"} \"last_updated\":{\"date\":\"2014-03-03 10:22:55\" \"timezone_type\":3 \"timezone\":\"Europe\\/London\"} \"options\":{\"allowHeadline\":true \"allowDateStamp\":true \"allowRelatedStoriesBox\":true \"allowRightHandSide\":true \"includeComments\":false \"isIgorSeoTagsEnabled\":false \"allowPrintingSharingLinks\":true \"allowAdvertising\":true} \"section\":{\"name\":\"Technology\" \"id\":\"99113\" \"uri\":\"\\/news\\/technology\" \"urlIdentifier\":\"\\/news\\/technology\"} \"edition\":\"International\" \"audience\":null \"iStats_counter_name\":\"news.technology.story.26415021.page\" \"type\":\"STY\" \"length\":5362 \"byline\":{\"name\":\"By Mark Ward\" \"persons\":{\"0\":{\"name\":\"Mark Ward\" \"function\":\"Technology correspondent BBC News\"}} \"title\":\"Technology correspondent BBC News\"} \"headline\":\"An hour to catch the coding bug\" \"mediaType\":null} \"smpBrand\":null \"staticHost\":\"http:\\/\\/static.bbci.co.uk\" \"environment\":\"live\" \"locatorVersion\":\"0.46.3\" \"pathPrefix\":\"\\/news\" \"staticPrefix\":\"http:\\/\\/static.bbci.co.uk\\/news\\/1.99.0479\" \"jsPath\":\"http:\\/\\/static.bbci.co.uk\\/news\\/1.99.0479\\/js\" \"cssPath\":\"http:\\/\\/static.bbci.co.uk\\/news\\/1.99.0479\\/stylesheets\\/services\\/news\" \"cssPostfix\":\"\" \"dynamic\":null \"features\":{\"localnews\":true \"video\":true \"liveeventcomponent\":true \"mediaassetpage\":true \"travel\":true \"gallery\":true \"rollingnews\":true \"rumanalytics\":true \"sportstories\":true \"radiopromo\":true \"fromothernewssites\":true \"locallive\":true \"weather\":true} \"features2\":{\"svg_brand\":true \"chartbeat\":true \"connected_stream\":true \"connected_stream_promo\":true \"nav\":true \"pulse_survey\":false \"local_survey\":true \"correspondents\":true \"blogs\":true \"open_graph\":true \"follow_us\":true \"marketdata_markets\":true \"marketdata_shares\":true \"nations_pseudo_nav\":true \"politics_election2015_topic_pages\":true \"politics_election2016_az_pages\":true \"politics_election2016_council_police_pages\":true \"politics_election2016_ni_results_page\":true \"responsive_breaking_news\":true \"live_event\":true \"most_popular\":true \"most_popular_tabs\":true \"most_popular_by_day\":true \"routing\":true \"rum\":true \"radiopromonownext\":true \"config_based_layout\":true \"orb\":true \"enhanced_gallery\":true \"map_most_watched\":true \"top_stories_promo\":true \"features_and_analysis\":true \"section_labels\":true \"index_title\":true \"share_tools\":true \"local_live_promo\":true \"adverts\":true \"adverts_async\":true \"adexpert\":true \"igor_geo_redirect\":true \"igor_device_redirect\":true \"live\":true \"comscore_mmx\":true \"find_local_news\":true \"comments\":true \"comments_enhanced\":true \"browser_notify\":true \"stream_grid_promo\":true \"breaking_news\":false \"top_stories_max_volume\":true \"record_livestats\":true \"contact_form\":true \"channel_page\":true \"portlet_global_variants\":true \"suppress_lep_timezone\":true \"story_recommendations\":true \"cedexis\":true \"mpulse\":true \"story_single_column_layout\":true \"story_image_copyright_labels\":true \"ovp_resolve_primary_media_vpids\":false \"media_player\":true \"travel\":true} \"configuration\":{\"showtimestamp\":\"1\" \"showweather\":\"1\" \"showsport\":\"1\" \"showolympics\":\"1\" \"showfeaturemain\":\"1\" \"showsitecatalyst\":\"1\" \"candyplatform\":\"EnhancedMobile\" \"showwatchlisten\":\"1\" \"showspecialreports\":\"\" \"videotopiccandyid\":\"\" \"showvideofeedsections\":\"1\" \"showstorytopstories\":\"\" \"showstoryfeaturesandanalysis\":\"1\" \"showstorymostpopular\":\"\" \"showgallery\":\"1\" \"cms\":\"cps\" \"channelpagecandyid\":\"10318089\"} \"pollingHost\":\"http:\\/\\/polling.bbc.co.uk\" \"service\":\"news\" \"locale\":\"en-GB\" \"locatorHost\":null \"locatorFlagPole\":true \"local\":{\"allowLocationLookup\":true} \"isWorldService\":false \"rumAnalytics\":{\"server\":\"http:\\/\\/ingest.rum.bbc.co.uk\" \"key\":\"news\" \"sample_rate\":0.1 \"url_params\":null \"edition\":\"international\"} \"isChannelPage\":false \"suitenameMap\":\"\" \"languageVariant\":\"\" \"commentsHost\":\"http:\\/\\/feeds.bbci.co.uk\" \"search\":null \"comscoreAnalytics\":null}; config.configuration['get'] = function (key) { return this[key.toLowerCase()]; }; var bootstrapUI=function(){var e=function(){if(navigator.userAgent.match(/(Android (2.0|2.1))|(Nokia)|(OSRE\\/)|(Opera (Mini|Mobi))|(w(eb)?OSBrowser)|(UCWEB)|(Windows Phone)|(XBLWP)|(ZuneWP)/))return!1;if(navigator.userAgent.match(/MSIE 10.0/))return!0;var e t=document n=t.head||t.getElementsByTagName(\"head\")[0] r=t.createElement(\"style\") s=t.implementation||{hasFeature:function(){return!1}};r.type=\"text/css\" n.insertBefore(r n.firstChild) e=r.sheet||r.styleSheet;var i=s.hasFeature(\"CSS2\" \"\")?function(t){if(!e||!t)return!1;var n=!1;try{e.insertRule(t 0) n=!/unknown/i.test(e.cssRules[0].cssText) e.deleteRule(e.cssRules.length-1)}catch(r){}return n}:function(t){return e&&t?(e.cssText=t 0!==e.cssText.length&&!/unknown/i.test(e.cssText)&&0===e.cssText.replace(/\\r+|\\n+/g \"\").indexOf(t.split(\" \")[0])):!1};return i('@font-face{ font-family:\"font\";src:\"font.ttf\"; }')}();e&&(document.getElementsByTagName(\"html\")[0].className+=\" ff\") function(){var e=document.documentElement.style;(\"flexBasis\"in e||\"WebkitFlexBasis\"in e||\"msFlexBasis\"in e)&&(document.documentElement.className+=\" flex\")}();var t n r s i a o={} u=function(){var e=document.documentElement.clientWidth r=document.documentElement.clientHeight s=window.innerWidth i=window.innerHeight a=s>1.5*e;t=a?e:s n=a?r:i} c=function(e){var t=document.createElement(\"link\");t.setAttribute(\"rel\" \"stylesheet\") t.setAttribute(\"type\" \"text/css\") t.setAttribute(\"href\" r+e+s+\".css\") t.setAttribute(\"media\" a[e]) i.parentNode.insertBefore(t i) delete a[e]} l=function(e r s){r&&!s&&(t>=r||n>=r)&&c(e) s&&!r&&(s>=t||s>=n)&&c(e) r&&s&&(t>=r||n>=r)&&(s>=t||s>=n)&&c(e)} f=function(e){if(o[e])return o[e];var t=e.match(/\\(min\\-width:[\\s]*([\\s]*[0-9\\.]+)(px|em)[\\s]*\\)/) n=e.match(/\\(max\\-width:[\\s]*([\\s]*[0-9\\.]+)(px|em)[\\s]*\\)/) r=t&&parseFloat(t[1])||null s=n&&parseFloat(n[1])||null;return o[e]=[r s] o[e]} m=function(){var e=0;for(var t in a)e++;return e} d=function(){m()||window.removeEventListener(\"resize\" h !1);for(var e in a){var t=a[e] n=f(t);l(e n[0] n[1])}} h=function(){u() d()} v=function(e t){a=e r=t.path+(\"/\"!==t.path.substr(-1)?\"/\":\"\") s=t.postfix i=t.insertBefore u() d() window.addEventListener(\"resize\" h !1)};return{stylesheetLoaderInit:v}}(); var stylesheets = {\"compact\":\"(max-width: 599px)\" \"tablet\":\"(min-width: 600px)\" \"wide\":\"(min-width: 1008px)\"}; bootstrapUI.stylesheetLoaderInit(stylesheets { path: 'http://static.bbci.co.uk/news/1.99.0479/stylesheets/services/news' postfix: '' insertBefore: insertPoint }); var loadRequire = function(){ var js_paths = {\"jquery-1.9\":\"vendor\\/jquery-1\\/jquery\" \"jquery-1\":\"http:\\/\\/static.bbci.co.uk\\/frameworks\\/jquery\\/0.3.0\\/sharedmodules\\/jquery-1.7.2\" \"demi-1\":\"http:\\/\\/static.bbci.co.uk\\/frameworks\\/demi\\/0.10.0\\/sharedmodules\\/demi-1\" \"swfobject-2\":\"http:\\/\\/static.bbci.co.uk\\/frameworks\\/swfobject\\/0.1.10\\/sharedmodules\\/swfobject-2\" \"jquery\":\"vendor\\/jquery-2\\/jquery.min\" \"domReady\":\"vendor\\/require\\/domReady\" \"translation\":\"module\\/translations\\/en-GB\" \"bump-3\":\"\\/\\/emp.bbci.co.uk\\/emp\\/bump-3\\/bump-3\"}; js_paths.navigation = 'module/nav/navManager'; requirejs.config({ baseUrl: 'http://static.bbci.co.uk/news/1.99.0479/js' map: { 'vendor/locator': { 'module/bootstrap': 'vendor/locator/bootstrap' 'locator/stats': 'vendor/locator/stats' 'locator/locatorView': 'vendor/locator/locatorView' } } paths: js_paths waitSeconds: 30 }); define('config' function () { return config; }); require([\"compiled\\/all\"] function() {\n",
      " require(['domReady'] function (domReady) { domReady(function () { require([\"module\\/dotcom\\/handlerAdapter\" \"module\\/rumAdaptor\" \"module\\/stats\\/statsSubscriberAdapter\" \"module\\/alternativeJsStrategy\\/controller\" \"module\\/iconLoaderAdapter\" \"module\\/polyfill\\/location.origin\" \"module\\/components\\/breakingNewsAdapter\" \"module\\/indexTitleAdaptor\" \"module\\/navigation\\/handlerAdaptor\" \"module\\/noTouchDetectionForCss\" \"module\\/components\\/responsiveImage\" \"module\\/components\\/timestampAdaptor\" \"module\\/tableScrollAdapter\" \"module\\/components\\/mediaPlayer\\/mainAdapter\" \"module\\/stats\\/statsBindingAdapter\" \"module\\/hotspot\\/handlerAdapter\"] function() { require([\"module\\/strategiserAdaptor\"]); }); }); }); });\n",
      " }; loadRequire(); } else { var l = document.createElement('link'); l.href = 'http://static.bbci.co.uk/news/1.99.0479/icons/generated/icons.fallback.css'; l.rel = 'stylesheet'; document.getElementsByTagName('head')[0].appendChild(l); }   /*<![CDATA[*/ bbcdotcom.init({adsToDisplay:['leaderboard' 'sponsor_section' 'mpu' 'outbrain_ar_5' 'outbrain_ar_7' 'outbrain_ar_8' 'outbrain_ar_9' 'native' 'mpu_bottom' 'adsense' 'inread']}); /*]]>*/  \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/ (function() { if (window.bbcdotcom && bbcdotcom.config.isActive('ads')) { googletag.cmd.push(function() { googletag.display('bbccom_interstitial'); }); } }()); /*]]>*/  /*<![CDATA[*/ (function() { var wallpaper; if (window.bbcdotcom && bbcdotcom.config.isActive('ads')) { if (bbcdotcom.config.isAsync()) { googletag.cmd.push(function() { googletag.display('bbccom_wallpaper'); }); } else { googletag.display(\"wallpaper\"); } wallpaper = bbcdotcom.adverts.adRegister.getAd('wallpaper'); if (wallpaper !== null && wallpaper !== undefined) { wallpaper.setDomElement('bbccom_wallpaper'); } } }()); /*]]>*/  /*<![CDATA[*/ (function() { if (window.bbcdotcom && bbcdotcom.config.isActive('ads')) { document.write(unescape('%3Cscript id=\"gnlAdsEnabled\" class=\"bbccom_display_none\"%3E%3C/script%3E')); } if (window.bbcdotcom && bbcdotcom.config.isActive('analytics')) { document.write(unescape('%3Cscript id=\"gnlAnalyticsEnabled\" class=\"bbccom_display_none\"%3E%3C/script%3E')); } if (window.bbcdotcom && bbcdotcom.config.isActive('continuousPlay')) { document.write(unescape('%3Cscript id=\"gnlContinuousPlayEnabled\" class=\"bbccom_display_none\"%3E%3C/script%3E')); } }()); /*]]>*/      <![CDATA[ <section> <div id=\"bbccookies\" class=\"bbccookies-banner orb-banner-wrapper bbccookies-d\"> <div id=\"bbccookies-prompt\" class=\"orb-banner b-g-p b-r b-f\"> <h2 class=\"orb-banner-title\"> Cookies on the BBC website </h2> <p class=\"orb-banner-content\" dir=\"ltr\"> The BBC has updated its cookie policy. We use cookies to ensure that we give you the best experience on our website. This includes cookies from third party social media websites if you visit a page which contains embedded content from social media. Such third party cookies may track your use of the BBC website.<span class=\"bbccookies-international-message\"> We and our partners also use cookies to ensure we show you advertising that is relevant to you.</span> If you continue without changing your settings we'll assume that you are happy to receive all cookies on the BBC website. However you can change your cookie settings at any time. </p> <ul class=\"orb-banner-options\"> <li id=\"bbccookies-continue\"> <button type=\"button\" id=\"bbccookies-continue-button\">Continue</button> </li> <li id=\"bbccookies-settings\"> <a href=\"/privacy/cookies/managing/cookie-settings.html\">Change settings</a> </li> <li id=\"bbccookies-more\"><a href=\"/privacy/cookies/bbc\">Find out more</a></li></ul> </div> </div> </section> ]]> /*<![CDATA[*/ (function(){if(bbccookies._showPrompt()){var g=document b=g.getElementById(\"blq-pre-mast\") e=g.getElementById(\"blq-bbccookies-tmpl\") a f;if(b&&g.createElement){a=g.createElement(\"div\");f=e.innerHTML;f=f.replace(\"<\"+\"![CDATA[\" \"\").replace(\"]]\"+\">\" \"\");a.innerHTML=f;b.appendChild(a);blqCookieContinueButton=g.getElementById(\"bbccookies-continue-button\");blqCookieContinueButton.onclick=function(){a.parentNode.removeChild(a);return false};bbccookies._setPolicy(bbccookies.readPolicy())}var c=g.getElementById(\"bbccookies\");if(c&&!window.orb.fig(\"uk\")){c.className=c.className.replace(/\\bbbccookies-d\\b/ \"\");c.className=c.className+(\" bbccookies-w\")}}})(); /*]]>*/ /*<![CDATA[*/ if (bbccookies.isAllowed('s1')) { require(['istats-1'] function (istats) { istats.invoke(); }); } /*]]>*/  /*<![CDATA[*/ if (bbccookies.isAllowed('s1')) { (function () { require(['istats-1'] function (istats) { istatsTrackingUrl = istats.getDefaultURL(); if (istats.isEnabled() && bbcFlagpoles_istats === 'ON') { sitestat(istatsTrackingUrl); } else { window.ns_pixelUrl = istatsTrackingUrl; /* used by Flash library to track */ } function sitestat(n) { var j = document f = j.location b = \"\"; if (j.cookie.indexOf(\"st_ux=\") != -1) { var k = j.cookie.split(\";\"); var e = \"st_ux\" h = document.domain a = \"/\"; if (typeof ns_ != \"undefined\" && typeof ns_.ux != \"undefined\") { e = ns_.ux.cName || e; h = ns_.ux.cDomain || h; a = ns_.ux.cPath || a } for (var g = 0 f = k.length; g < f; g++) { var m = k[g].indexOf(\"st_ux=\"); if (m != -1) { b = \"&\" + decodeURI(k[g].substring(m + 6)) } } bbccookies.set(e + \"=; expires=\" + new Date(new Date().getTime() - 60).toGMTString() + \"; path=\" + a + \"; domain=\" + h); } window.ns_pixelUrl = n; } }); })(); } else { window.istats = {enabled: false}; } /*]]>*/  \n",
      "             Accessibility links  Skip to content Accessibility Help        BBC iD    require(['idcta/statusbar'] function(statusbar) { new statusbar.Statusbar({\"id\":\"idcta-statusbar\" \"publiclyCacheable\":true}); });     BBC navigation   News   News   Sport   Weather   Shop   Earth   Travel   Capital   iPlayer   Culture   Autos   Future   TV   Radio   CBBC   CBeebies   Food   Arts   Make It Digital   iWonder   Bitesize   Music   Nature   Earth   Local   Travel  Menu           Search the BBC         <![CDATA[ <div id=\"orb-panel-<%= panelname %>\" class=\"orb-panel\" aria-labelledby=\"orb-nav-<%= panelname %>\"> <div class=\"orb-panel-content b-g-p b-r\"> <%= panelcontent %> </div> </div> ]]>     \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "BBC News\n",
      "\n",
      "\n",
      "\n",
      "News navigation\n",
      "\n",
      " Sections \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Home\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Video\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "World\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "UK\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Business\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Tech\n",
      "\n",
      "selected \n",
      "\n",
      "\n",
      "Science\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Magazine\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Entertainment & Arts\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Health\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "In Pictures\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Also in the News\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Special Reports\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Explainers\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "The Reporters\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Have Your Say\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('leaderboard' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Technology\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('sponsor_section' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "   \n",
      "\n",
      "Technology\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('sponsor_section' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "   \n",
      "\n",
      "An hour to catch the coding bug\n",
      "\n",
      "By Mark Ward\n",
      "Technology correspondent BBC News\n",
      "\n",
      "\n",
      "\n",
      " 3 March 2014\n",
      "\n",
      "From the section Technology\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Image caption\n",
      "\n",
      " We did our Hour of Code on a lazy Sunday morning\n",
      " \n",
      "\n",
      "Okay 60 minutes and counting. Here we go.I've got an hour to convince my kids that programming is for them.Well sort of.I'm putting my twin 10-year-old boys Toby and Callum through the Hour of Code - a campaign that seeks to ignite an interest in programming - the part we're doing using specially created web-based exercises. The campaign begun in the US has landed in the UK where it also coincides with government calls for as many children as possible to get coding.\n",
      "\n",
      "\n",
      " /**/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('mpu' [1 2 3]);\n",
      " }\n",
      " })();\n",
      " /**/\n",
      " \n",
      "\n",
      "Programming is being pushed because in an ever more technological world it can only be a good thing to give people a peep into what goes on behind the touch screen cash point and website. The Hour of Code is supposed to be the start of that journey and I like many other parents feel it's one my children should be embarking on. I do feel like a clock somewhere is ticking and unless they get started with this essential skill they'll be left behind. \"In the future kids are going to be doing programming \" said Callum when I asked him why it was worth learning how to code. \"We need to learn so we can do stuff with the computer otherwise it will be a blank page and never work.\"Zombie dance\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Image caption\n",
      "\n",
      " The coding exercises involve familiar characters such as the Angry Birds\n",
      " \n",
      "\n",
      " \n",
      " It's the getting started for both parents and their offspring that the Hour is intended to help with. I'm probably like most parents in that I have no significant qualification in computer science. All I can offer my boys is a lifetime of tinkering backed up over the past 18 months with online courses in Python HTML CSS Javascript and the like. There's good precedents for the value of something like the Hour of Code. I've quizzed every chief technology officer (CTO) developer or IT worker I've met in the past couple of weeks about what got them started and every one knew exactly the moment they got it. Their eyes lit up as they talked about typing in code listings from magazines working through every Dos command or designing their own blocky 8-bit game characters.And finally at the back of my mind are all those statistics about the shortages of skilled IT staff and my hope that if this works then their future career options will be much wider than they would be without this skill.So no pressure then.Yesterday morning we gave it a go. I was keen for it to be fun rather than feel like school as there's nothing more likely to turn them off than for it to be sold as good for them. I think we struck the right note of informality - Cal did it in his onesie. It went OK no better than that. Pretty good. We worked through all the exercises getting angry birds to mash pigs and zombies to chomp sunflowers. The coding is done by dragging blocks representing different commands into a work area and building the blocks into a tower of coherent instructions.The block-building system is based on the Scratch programming language build by MIT's Mitch Resnick. The exercises start easy - just getting an angry bird to hop on to a pig. By the end we were using \"If… else\" statements and loops to help a zombie navigate a tricky maze to reach the sunflower.This went down well with Callum. \"Cool! It's scanning for a path \" he said as the zombie worked its way towards the hapless flower.Mistakes were made but we learned from them we debated over which way to make the birds and zombies turn and the time went really fast. Toby was surprised to find that this counted as programming.\"I thought coding was just a lot of people tapping in letter and numbers until they got it right \" he said. Next stepsAnd yet I felt it was a bit too easy. I wanted to make the coding connection to real life more tangible. So as we had about 15 minutes of our Hour of Code left we went further.This time we used the MIT App Inventor to build a basic program that would run on the tablets they own. The app inventor uses the same \"drag the block\" method to build a program and following the instructions we had soon created an app that turned anything typed in text into speech. \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Image caption\n",
      "\n",
      " The App Inventor uses the same block dragging system as the Hour of Code exercises\n",
      " \n",
      "\n",
      "We got it working on Cal's tablet and soon they were getting that gadget to call out lots of phrases. Almost inevitably as they are 10 years old a lot of these phrases involved the words \"willy\" and \"bum\". But they had a lot of fun with it and it brought home to them how straight-forward coding can be. In just over an hour they went from being pretty much novices to creating an Android app - a basic one that trades on the expertise of the people that built the coding tools but it was an accomplishment nonetheless.Did they catch the coding bug as a result? Maybe later in the day they were programming each other after one of their regular wrestling matches left Toby lying exhausted on the floor. Suddenly Cal called out commands such as \"roll left\" and Toby started obeying even to the point of crashing into the sofa when too many roll commands were given. Then Toby had his turn and did the same they even worked out that they had to compensate for the changes in left and right as they rolled. So I think that hour started something. Both with them and with me. Building that Android app made me realise that it is straight-forward. That my lack of formal qualifications do not matter as much as I thought. And maybe that's the point of the hour. Making people realise that it is not scary and difficult. You just have to find an hour and give it a try. You can even do it in your onesie.\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " Share this story About sharing\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Email\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Facebook\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Twitter\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "WhatsApp\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Linkedin\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "  More on this story        \n",
      " Video\n",
      " Computer coding taught in Estonian primary schools    8 January 2014            Year of Code - PR fiasco or vital mission?    12 February 2014            Are teachers ready for the coding revolution?    23 January 2014         \n",
      "\n",
      "  Related Internet links         UK Hour of Code           MIT App Inventor           MIT Scratch        \n",
      "The BBC is not responsible for the content of external Internet sites\n",
      "\n",
      "\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('outbrain_ar_5' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('outbrain_ar_7' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('outbrain_ar_8' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Top Stories\n",
      "\n",
      "Russia 'plans sanctions against Turkey'\n",
      "Russia is preparing wide-ranging economic sanctions against Turkey after the downing of one of its jets Prime Minister Dmitry Medvedev says.\n",
      "26 November 2015\n",
      "\n",
      "\n",
      "Brussels threat level reduced\n",
      "26 November 2015\n",
      "\n",
      "\n",
      "Trump mocks disabled reporter\n",
      "26 November 2015\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('mpu' [4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " \n",
      " Features & Analysis\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " Video\n",
      "3:23\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Silent slaughter\n",
      "Capturing daily life in Raqqa under Islamic State \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Say what?\n",
      "Is this the subject with the most baffling jargon?\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "The other crisis\n",
      "Why Greeks are exhuming their parents' bodies\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Spiral of violence \n",
      "Death toll from jihadist groups continues to rise\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Back to Africa\n",
      "Young professionals leave London and head to Ghana\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Thanksgiving humour\n",
      "How black white Mexican Jewish Asian and other families celebrate\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Firms behind bars\n",
      "The businesses offering hope to Mexican prisoners\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "After the Taliban\n",
      "Kunduz a city still scarred and in shock\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "From spy to BFG\n",
      "Mark Rylance on the biggest film roles of his career\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('native' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('mpu_bottom' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('outbrain_ar_9' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('adsense' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      " /*<![CDATA[*/\n",
      " (function() {\n",
      " if (window.bbcdotcom && bbcdotcom.adverts && bbcdotcom.adverts.slotAsync) {\n",
      " bbcdotcom.adverts.slotAsync('inread' [1 2 3 4]);\n",
      " }\n",
      " })();\n",
      " /*]]>*/\n",
      " \n",
      "\n",
      "\n",
      "\n",
      "   \n",
      "\n",
      "News navigation\n",
      "\n",
      "Sections\n",
      "\n",
      "\n",
      "\n",
      "Home\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Video\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "World\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "World Home\n",
      "\n",
      "Africa \n",
      "\n",
      "Asia \n",
      "\n",
      "Australia \n",
      "\n",
      "Europe \n",
      "\n",
      "Latin America \n",
      "\n",
      "Middle East \n",
      "\n",
      "US & Canada \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "UK\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "UK Home\n",
      "\n",
      "England \n",
      "\n",
      "N. Ireland \n",
      "\n",
      "Scotland \n",
      "\n",
      "Wales \n",
      "\n",
      "Politics \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Business\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Business Home\n",
      "\n",
      "Market Data \n",
      "\n",
      "Markets \n",
      "\n",
      "Economy \n",
      "\n",
      "Companies \n",
      "\n",
      "Entrepreneurship \n",
      "\n",
      "Technology of Business \n",
      "\n",
      "Business of Sport \n",
      "\n",
      "Knowledge economy \n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Tech\n",
      "\n",
      "selected \n",
      "\n",
      "\n",
      "Science\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Magazine\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Entertainment & Arts\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Health\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "In Pictures\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Also in the News\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Special Reports\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Explainers\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "The Reporters\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "Have Your Say\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "BBC News Services\n",
      "\n",
      "\n",
      "On your mobile\n",
      "\n",
      "\n",
      "On your connected TV\n",
      "\n",
      "\n",
      "Get news alerts\n",
      "\n",
      "\n",
      "Contact BBC News\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "       Explore the BBC    News   News   Sport   Weather   Shop   Earth   Travel   Capital   iPlayer   Culture   Autos   Future   TV   Radio   CBBC   CBeebies   Food   Arts   Make It Digital   iWonder   Bitesize   Music   Nature   Earth   Local   Travel            Terms of Use   About the BBC   Privacy Policy   Cookies   Accessibility Help   Parental Guidance   Contact the BBC   Advertise with us   Ad choices    Copyright © 2015 BBC. The BBC is not responsible for the content of external sites. Read about our approach to external linking.       /*<![CDATA[*/ if (window.bbcdotcom && window.bbcdotcom.analytics) { bbcdotcom.analytics.page(); } if (window.bbcdotcom && bbcdotcom.currencyProviders) { bbcdotcom.currencyProviders.write(); } /*]]>*/  /*<![CDATA[*/ if (window.bbcdotcom && bbcdotcom.currencyProviders) { bbcdotcom.currencyProviders.postWrite(); } /*]]>*/  /*<![CDATA[*/ /** * ASNYC waits to make any gpt requests until the bottom of the page */ (function() { var gads = document.createElement('script'); gads.async = true; gads.type = 'text/javascript'; var useSSL = 'https:' == document.location.protocol; gads.src = (useSSL ? 'https:' : 'http:') + '//www.googletagservices.com/tag/js/gpt.js'; var node = document.getElementsByTagName('script')[0]; node.parentNode.insertBefore(gads node); })(); /*]]>*/  /*<![CDATA[*/ if (window.bbcdotcom && bbcdotcom.data && bbcdotcom.data.stats && bbcdotcom.data.stats === 1 && bbcdotcom.utils && window.location.pathname === '/' && window.bbccookies && bbccookies.readPolicy('performance') ) { var wwhpEdition = bbcdotcom.utils.getMetaPropertyContent('wwhp-edition'); var _sf_async_config={}; /** CONFIGURATION START **/ _sf_async_config.uid = 50924; _sf_async_config.domain = \"bbc.co.uk\"; _sf_async_config.title = \"Homepage\"+(wwhpEdition !== '' ? ' - '+wwhpEdition : ''); _sf_async_config.sections = \"Homepage\"+(wwhpEdition !== '' ? ' Homepage - '+wwhpEdition : ''); _sf_async_config.region = wwhpEdition; _sf_async_config.path = \"/\"+(wwhpEdition !== '' ? '?'+wwhpEdition : ''); /** CONFIGURATION END **/ (function(){ function loadChartbeat() { window._sf_endpt=(new Date()).getTime(); var e = document.createElement(\"script\"); e.setAttribute(\"language\" \"javascript\"); e.setAttribute(\"type\" \"text/javascript\"); e.setAttribute('src' '//static.chartbeat.com/js/chartbeat.js'); document.body.appendChild(e); } var oldonload = window.onload; window.onload = (typeof window.onload != \"function\") ? loadChartbeat : function() { oldonload(); loadChartbeat(); }; })(); } /*]]>*/    document.write('<' + 'script id=\"orb-js-script\" data-assetpath=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/\" src=\"http://static.bbci.co.uk/frameworks/barlesque/2.93.13/orb/4/script/orb.min.js\"><' + '/script>');   (function() {\n",
      " 'use strict';\n",
      " var promoManager = {\n",
      " url: '' \n",
      " promoLoaded: false \n",
      " makeUrl: function (theme site win) {\n",
      " var loc = win? win.location : window.location \n",
      " proto = loc.protocol \n",
      " host = loc.host \n",
      " url = proto + '//' + ((proto.match(/s:/i) && !host.match(/^www\\.(int|test)\\./i))? 'ssl.' : 'www.') \n",
      " themes = ['light' 'dark'];\n",
      " if ( host.match(/^(?:www|ssl|m)\\.(int|test|stage|live)\\.bbc\\./i) ) {\n",
      " url += RegExp.$1 + '.';\n",
      " }\n",
      " else if ( host.match(/^pal\\.sandbox\\./i) ) {\n",
      " url += 'test.';\n",
      " }\n",
      " theme = themes[ +(theme === themes[0]) ];\n",
      " \n",
      " return url + 'bbc.co.uk/navpromo/card/' + site + '/' + theme;\n",
      " } \n",
      " init: function(node) {\n",
      " var disabledByCookie = (document.cookie.indexOf('ckns_orb_nopromo=1') > -1) \n",
      " that = this;\n",
      " \n",
      " if (window.promomanagerOverride) {\n",
      " for (var p in promomanagerOverride) {\n",
      " that[p] = promomanagerOverride[p];\n",
      " }\n",
      " }\n",
      " \n",
      " if ( window.orb.fig('uk') && !disabledByCookie ) {\n",
      " require(['orb/async/_footerpromo' 'istats-1'] function(promo istats) {\n",
      " var virtualSite = istats.getSite() || 'default';\n",
      " that.url = (window.promomanagerOverride || that).makeUrl('light' virtualSite);\n",
      " if (that.url) { \n",
      " promo.load(that.url node {\n",
      " onSuccess: function(e) {\n",
      " if(e.status === 'success') {\n",
      " node.parentNode.className = node.parentNode.className + ' orb-footer-promo-loaded';\n",
      " promoManager.promoLoaded = true;\n",
      " promoManager.event('promo-loaded').fire(e);\n",
      " }\n",
      " } \n",
      " onError: function() {\n",
      " istats.log('error' 'orb-footer-promo-failed');\n",
      " bbccookies.set('ckns_orb_nopromo=1; expires=' + new Date(new Date().getTime() + 1000 * 60 * 10).toGMTString() + ';path=/;');\n",
      " }\n",
      " }); \n",
      " }\n",
      " });\n",
      " }\n",
      " }\n",
      " };\n",
      " \n",
      " \n",
      " define('orb/promomanager' ['orb/lib/_event'] function (event) {\n",
      " event.mixin(promoManager);\n",
      " return promoManager;\n",
      " });\n",
      " \n",
      " require(['orb/promomanager'] function (promoManager) {\n",
      " promoManager.init(document.getElementById('navp-orb-footer-promo'));\n",
      " })\n",
      "})();\n",
      "   if (typeof require !== 'undefined') { require(['istats-1'] function(istats){ istats.track('external' { region: document.getElementsByTagName('body')[0] }); istats.track('download' { region: document.getElementsByTagName('body')[0] }); }); }    window.old_onload = window.onload; window.onload = function() { if(window.old_onload) { window.old_onload(); } window.loaded = true; };  \n",
      "\n",
      " var _sf_async_config={};\n",
      " /** CONFIGURATION START **/\n",
      " _sf_async_config.uid = \"50924\";\n",
      " _sf_async_config.domain = \"www.bbc.co.uk\";\n",
      " _sf_async_config.sections = \"News News - technology News - STY News - technology - STY\";\n",
      " <!-- if page is an index add the edition to the path -->\n",
      " _sf_async_config.path = \"bbc.co.uk/news/technology-26415021\";\n",
      " (function() {\n",
      " var noCookies = true;\n",
      " var cookiePrefix = '_chartbeat';\n",
      " if (\"object\" === typeof bbccookies && typeof bbccookies.readPolicy == 'function') {\n",
      " noCookies = !bbccookies.readPolicy().performance;\n",
      " }\n",
      " if (noCookies && document.cookie.indexOf(cookiePrefix) !== -1) {\n",
      " //Find and remove cookies whose names begin with '_chartbeat'\n",
      " var cookieSplit = document.cookie.split(';');\n",
      " var cookieLength = cookieSplit.length;\n",
      " while (cookieLength--) {\n",
      " var cookie = cookieSplit[cookieLength].replace(/^\\s+|\\s+$/g '');\n",
      " var cookieName = cookie.split('=')[0];\n",
      " if (cookieName.indexOf(cookiePrefix) === 0) {\n",
      " document.cookie = cookieName + '=; expires=Thu 01 Jan 1970 00:00:00 GMT; path=/;';\n",
      " }\n",
      " }\n",
      " }\n",
      " _sf_async_config.noCookies = noCookies;\n",
      " }());\n",
      " /** CONFIGURATION END **/\n",
      " (function(){\n",
      " function loadChartbeat() {\n",
      " window._sf_endpt=(new Date()).getTime();\n",
      " var e = document.createElement(\"script\");\n",
      " e.setAttribute(\"language\" \"javascript\");\n",
      " e.setAttribute(\"type\" \"text/javascript\");\n",
      " e.setAttribute('src' '//static.chartbeat.com/js/chartbeat.js');\n",
      " document.body.appendChild(e);\n",
      " }\n",
      " var oldonload = window.onload;\n",
      " window.onload = (typeof window.onload != \"function\") ?\n",
      " loadChartbeat : function() { oldonload(); loadChartbeat(); };\n",
      " }());\n",
      "\n",
      "\n",
      "\n",
      "\n",
      "(function(){\n",
      " window.bbcnewsperformance = {};\n",
      " var perf = window.performance;\n",
      " function firstScrollTimer() {\n",
      " document.removeEventListener('scroll' firstScrollTimer);\n",
      " perf.mark('firstScroll');\n",
      " perf.measure('scrolltime' 'firstScroll');\n",
      " var timing = perf.getEntriesByName('scrolltime');\n",
      " bbcnewsperformance.firstScrollTime = timing[0].startTime;\n",
      " }\n",
      " function primaryImageTimer(src) {\n",
      " var timing = perf.getEntriesByName(src);\n",
      " bbcnewsperformance.primaryImageTime = timing[0].responseEnd;\n",
      " }\n",
      " if (perf) {\n",
      " if (perf.mark && perf.measure) {\n",
      " document.addEventListener('scroll' firstScrollTimer);\n",
      " }\n",
      " if (perf.getEntriesByName) {\n",
      " var primaryImage = document.querySelector('.story-body__inner img');\n",
      " if (primaryImage) {\n",
      " var src = primaryImage.getAttribute('src');\n",
      " primaryImage.addEventListener('load' primaryImageTimer.bind(this src));\n",
      " }\n",
      " }\n",
      " }\n",
      " var random = Math.random();\n",
      " var rate = 1;\n",
      " if (rate && (random < rate)) {\n",
      " var accountId = \"X5H9R-GT47V-WJULQ-CWND4-S7WY8\";\n",
      " // mpulse vendor code\n",
      " if(window.BOOMR && window.BOOMR.version){return;}\n",
      " var dom doc where iframe = document.createElement('iframe');\n",
      " iframe.src = \"javascript:false\";\n",
      " iframe.title = \"\"; iframe.role=\"presentation\";\n",
      " (iframe.frameElement || iframe).style.cssText = \"width:0;height:0;border:0;display:none;\";\n",
      " where = document.getElementsByTagName('script')[0];\n",
      " where.parentNode.insertBefore(iframe where);\n",
      " try {\n",
      " doc = iframe.contentWindow.document;\n",
      " } catch(e) {\n",
      " dom = document.domain;\n",
      " iframe.src=\"javascript:var d=document.open();d.domain='\"+dom+\"';void(0);\";\n",
      " doc = iframe.contentWindow.document;\n",
      " }\n",
      " doc.open()._l = function() {\n",
      " var js = this.createElement(\"script\");\n",
      " if(dom) this.domain = dom;\n",
      " js.id = \"boomr-if-as\";\n",
      " js.src = '//c.go-mpulse.net/boomerang/' +\n",
      " accountId;\n",
      " BOOMR_lstart=new Date().getTime();\n",
      " this.body.appendChild(js);\n",
      " };\n",
      " doc.write('<body onload=\"document._l();\">');\n",
      " doc.close();\n",
      " // mpulse vendor code - end\n",
      " }\n",
      "})();\n",
      "\n",
      "\n",
      " \n",
      "\n"
     ]
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "E:\\Anaconda3\\lib\\site-packages\\bs4\\__init__.py:166: UserWarning: No parser was explicitly specified, so I'm using the best available HTML parser for this system (\"lxml\"). This usually isn't a problem, but if you run this code on another system, or in a different virtual environment, it may use a different parser and behave differently.\n",
      "\n",
      "To get rid of this warning, change this:\n",
      "\n",
      " BeautifulSoup([your markup])\n",
      "\n",
      "to this:\n",
      "\n",
      " BeautifulSoup([your markup], \"lxml\")\n",
      "\n",
      "  markup_type=markup_type))\n"
     ]
    }
   ],
   "source": [
    "print(clean_html1(html))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "We got rid of the HTML tags, but we still have lots of \"non text\" - mainly javascript code.\n",
    "We can still use beautifulsoup to navigate the HTML DOM structure and filter out the script blocks - this will be effective in this case.\n",
    "\n",
    "But we can go faster and use the justext library.  This is developed specifically to remove boilerplate from html strings.\n",
    "It uses a very nice machine learning algorithm which is documented in its homepage.\n",
    "\n",
    "Make sure you install the library first:\n",
    "\n",
    "% pip install justext\n",
    "\n",
    "Now let's try it:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "import justext\n",
    "\n",
    "def clean_html2(html):\n",
    "    paragraphs = justext.justext(html, justext.get_stoplist('English'))\n",
    "    return \"\\n\".join([p.text for p in paragraphs if not p.is_boilerplate])\n",
    "\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Let us try this second version of clean_html:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "I'm putting my twin 10-year-old boys Toby and Callum through the Hour of Code - a campaign that seeks to ignite an interest in programming - the part we're doing using specially created web-based exercises.\n",
      "The campaign begun in the US has landed in the UK where it also coincides with government calls for as many children as possible to get coding.\n",
      "Programming is being pushed because in an ever more technological world it can only be a good thing to give people a peep into what goes on behind the touch screen cash point and website.\n",
      "The Hour of Code is supposed to be the start of that journey and I like many other parents feel it's one my children should be embarking on. I do feel like a clock somewhere is ticking and unless they get started with this essential skill they'll be left behind.\n",
      "\"In the future kids are going to be doing programming \" said Callum when I asked him why it was worth learning how to code. \"We need to learn so we can do stuff with the computer otherwise it will be a blank page and never work.\"\n",
      "Zombie dance\n",
      "Image caption The coding exercises involve familiar characters such as the Angry Birds\n",
      "It's the getting started for both parents and their offspring that the Hour is intended to help with. I'm probably like most parents in that I have no significant qualification in computer science. All I can offer my boys is a lifetime of tinkering backed up over the past 18 months with online courses in Python HTML CSS Javascript and the like.\n",
      "There's good precedents for the value of something like the Hour of Code. I've quizzed every chief technology officer (CTO) developer or IT worker I've met in the past couple of weeks about what got them started and every one knew exactly the moment they got it. Their eyes lit up as they talked about typing in code listings from magazines working through every Dos command or designing their own blocky 8-bit game characters.\n",
      "And finally at the back of my mind are all those statistics about the shortages of skilled IT staff and my hope that if this works then their future career options will be much wider than they would be without this skill.\n",
      "So no pressure then.\n",
      "Yesterday morning we gave it a go. I was keen for it to be fun rather than feel like school as there's nothing more likely to turn them off than for it to be sold as good for them. I think we struck the right note of informality - Cal did it in his onesie.\n",
      "It went OK no better than that. Pretty good. We worked through all the exercises getting angry birds to mash pigs and zombies to chomp sunflowers. The coding is done by dragging blocks representing different commands into a work area and building the blocks into a tower of coherent instructions.\n",
      "The block-building system is based on the Scratch programming language build by MIT's Mitch Resnick.\n",
      "The exercises start easy - just getting an angry bird to hop on to a pig. By the end we were using \"If… else\" statements and loops to help a zombie navigate a tricky maze to reach the sunflower.\n",
      "This went down well with Callum. \"Cool! It's scanning for a path \" he said as the zombie worked its way towards the hapless flower.\n",
      "Mistakes were made but we learned from them we debated over which way to make the birds and zombies turn and the time went really fast.\n",
      "Toby was surprised to find that this counted as programming.\n",
      "\"I thought coding was just a lot of people tapping in letter and numbers until they got it right \" he said.\n",
      "Next steps\n",
      "And yet I felt it was a bit too easy. I wanted to make the coding connection to real life more tangible. So as we had about 15 minutes of our Hour of Code left we went further.\n",
      "This time we used the MIT App Inventor to build a basic program that would run on the tablets they own.\n",
      "The app inventor uses the same \"drag the block\" method to build a program and following the instructions we had soon created an app that turned anything typed in text into speech.\n",
      "Image caption The App Inventor uses the same block dragging system as the Hour of Code exercises\n",
      "We got it working on Cal's tablet and soon they were getting that gadget to call out lots of phrases. Almost inevitably as they are 10 years old a lot of these phrases involved the words \"willy\" and \"bum\".\n",
      "But they had a lot of fun with it and it brought home to them how straight-forward coding can be. In just over an hour they went from being pretty much novices to creating an Android app - a basic one that trades on the expertise of the people that built the coding tools but it was an accomplishment nonetheless.\n",
      "Did they catch the coding bug as a result?\n",
      "Maybe later in the day they were programming each other after one of their regular wrestling matches left Toby lying exhausted on the floor. Suddenly Cal called out commands such as \"roll left\" and Toby started obeying even to the point of crashing into the sofa when too many roll commands were given.\n",
      "Then Toby had his turn and did the same they even worked out that they had to compensate for the changes in left and right as they rolled.\n",
      "So I think that hour started something. Both with them and with me. Building that Android app made me realise that it is straight-forward. That my lack of formal qualifications do not matter as much as I thought. And maybe that's the point of the hour. Making people realise that it is not scary and difficult. You just have to find an hour and give it a try. You can even do it in your onesie.\n"
     ]
    }
   ],
   "source": [
    "print(clean_html2(html))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Tokenizing"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Now that we have clean text, let us tokenize it into a list of words.\n",
    "\n",
    "We will use nltk tokenizer to do this.  Make sure you have nltk installed, and that you invoke nltk.download() to download the datasets that come with it.\n",
    "\n",
    "Then let us try the tokenizer."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "We found 1091 tokens\n"
     ]
    }
   ],
   "source": [
    "import nltk\n",
    "\n",
    "tokens = nltk.word_tokenize(clean_html2(html))\n",
    "\n",
    "print(\"We found %s tokens\" % (len(tokens)))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "The output of justext is organized in paragraphs.  We converted them as one line of text each."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "['I', \"'m\", 'putting', 'my', 'twin', '10-year-old', 'boys', 'Toby', 'and', 'Callum', 'through', 'the', 'Hour', 'of', 'Code', '-', 'a', 'campaign', 'that', 'seeks', 'to', 'ignite', 'an', 'interest', 'in', 'programming', '-', 'the', 'part', 'we', \"'re\", 'doing', 'using', 'specially', 'created', 'web-based', 'exercises', '.']\n"
     ]
    }
   ],
   "source": [
    "paragraphs = clean_html2(html).split(\"\\n\")\n",
    "p0 = paragraphs[0]\n",
    "print(nltk.word_tokenize(p0))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Note how abbreviations in English are tokenized (\"I'm\" becomes [\"I\", \"'m\"])."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.5.0"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 0
}
